import * as pulumi from "@pulumi/pulumi";
/**
 * Get information on a Certificate issued by a AWS Certificate Manager Private Certificate Authority.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.acmpca.getCertificate({
 *     arn: "arn:aws:acm-pca:us-east-1:123456789012:certificate-authority/12345678-1234-1234-1234-123456789012/certificate/1234b4a0d73e2056789bdbe77d5b1a23",
 *     certificateAuthorityArn: "arn:aws:acm-pca:us-east-1:123456789012:certificate-authority/12345678-1234-1234-1234-123456789012",
 * }, { async: true }));
 * ```
 */
export declare function getCertificate(args: GetCertificateArgs, opts?: pulumi.InvokeOptions): Promise<GetCertificateResult>;
/**
 * A collection of arguments for invoking getCertificate.
 */
export interface GetCertificateArgs {
    /**
     * Amazon Resource Name (ARN) of the certificate issued by the private certificate authority.
     */
    readonly arn: string;
    /**
     * Amazon Resource Name (ARN) of the certificate authority.
     */
    readonly certificateAuthorityArn: string;
}
/**
 * A collection of values returned by getCertificate.
 */
export interface GetCertificateResult {
    readonly arn: string;
    /**
     * The PEM-encoded certificate value.
     */
    readonly certificate: string;
    readonly certificateAuthorityArn: string;
    /**
     * The PEM-encoded certificate chain that includes any intermediate certificates and chains up to root CA.
     */
    readonly certificateChain: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
}
