import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an API Gateway API Key.
 *
 * > **NOTE:** Since the API Gateway usage plans feature was launched on August 11, 2016, usage plans are now **required** to associate an API key with an API stage.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const myDemoApiKey = new aws.apigateway.ApiKey("MyDemoApiKey", {});
 * ```
 *
 * ## Import
 *
 * API Gateway Keys can be imported using the `id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:apigateway/apiKey:ApiKey my_demo_key 8bklk8bl1k3sB38D9B3l0enyWT8c09B30lkq0blk
 * ```
 */
export declare class ApiKey extends pulumi.CustomResource {
    /**
     * Get an existing ApiKey resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ApiKeyState, opts?: pulumi.CustomResourceOptions): ApiKey;
    /**
     * Returns true if the given object is an instance of ApiKey.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApiKey;
    /**
     * Amazon Resource Name (ARN)
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The creation date of the API key
     */
    readonly createdDate: pulumi.Output<string>;
    /**
     * The API key description. Defaults to "Managed by Pulumi".
     */
    readonly description: pulumi.Output<string>;
    /**
     * Specifies whether the API key can be used by callers. Defaults to `true`.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * The last update date of the API key
     */
    readonly lastUpdatedDate: pulumi.Output<string>;
    /**
     * The name of the API key
     */
    readonly name: pulumi.Output<string>;
    /**
     * Key-value map of resource tags
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The value of the API key. If not specified, it will be automatically generated by AWS on creation.
     */
    readonly value: pulumi.Output<string>;
    /**
     * Create a ApiKey resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ApiKeyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ApiKey resources.
 */
export interface ApiKeyState {
    /**
     * Amazon Resource Name (ARN)
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The creation date of the API key
     */
    readonly createdDate?: pulumi.Input<string>;
    /**
     * The API key description. Defaults to "Managed by Pulumi".
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Specifies whether the API key can be used by callers. Defaults to `true`.
     */
    readonly enabled?: pulumi.Input<boolean>;
    /**
     * The last update date of the API key
     */
    readonly lastUpdatedDate?: pulumi.Input<string>;
    /**
     * The name of the API key
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Key-value map of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The value of the API key. If not specified, it will be automatically generated by AWS on creation.
     */
    readonly value?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ApiKey resource.
 */
export interface ApiKeyArgs {
    /**
     * The API key description. Defaults to "Managed by Pulumi".
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Specifies whether the API key can be used by callers. Defaults to `true`.
     */
    readonly enabled?: pulumi.Input<boolean>;
    /**
     * The name of the API key
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Key-value map of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The value of the API key. If not specified, it will be automatically generated by AWS on creation.
     */
    readonly value?: pulumi.Input<string>;
}
