import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Use this data source to get the custom domain name for use with AWS API Gateway.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.apigateway.getDomainName({
 *     domainName: "api.example.com",
 * }, { async: true }));
 * ```
 */
export declare function getDomainName(args: GetDomainNameArgs, opts?: pulumi.InvokeOptions): Promise<GetDomainNameResult>;
/**
 * A collection of arguments for invoking getDomainName.
 */
export interface GetDomainNameArgs {
    /**
     * The fully-qualified domain name to look up. If no domain name is found, an error will be returned.
     */
    readonly domainName: string;
    /**
     * Key-value map of tags for the resource.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getDomainName.
 */
export interface GetDomainNameResult {
    /**
     * The ARN of the found custom domain name.
     */
    readonly arn: string;
    /**
     * The ARN for an AWS-managed certificate that is used by edge-optimized endpoint for this domain name.
     */
    readonly certificateArn: string;
    /**
     * The name of the certificate that is used by edge-optimized endpoint for this domain name.
     */
    readonly certificateName: string;
    /**
     * The upload date associated with the domain certificate.
     */
    readonly certificateUploadDate: string;
    /**
     * The hostname created by Cloudfront to represent the distribution that implements this domain name mapping.
     */
    readonly cloudfrontDomainName: string;
    /**
     * For convenience, the hosted zone ID (`Z2FDTNDATAQYW2`) that can be used to create a Route53 alias record for the distribution.
     */
    readonly cloudfrontZoneId: string;
    readonly domainName: string;
    /**
     * List of objects with the endpoint configuration of this domain name.
     */
    readonly endpointConfigurations: outputs.apigateway.GetDomainNameEndpointConfiguration[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The ARN for an AWS-managed certificate that is used for validating the regional domain name.
     */
    readonly regionalCertificateArn: string;
    /**
     * The user-friendly name of the certificate that is used by regional endpoint for this domain name.
     */
    readonly regionalCertificateName: string;
    /**
     * The hostname for the custom domain's regional endpoint.
     */
    readonly regionalDomainName: string;
    /**
     * The hosted zone ID that can be used to create a Route53 alias record for the regional endpoint.
     */
    readonly regionalZoneId: string;
    /**
     * The security policy for the domain name.
     */
    readonly securityPolicy: string;
    /**
     * Key-value map of tags for the resource.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
