import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides an API Gateway Usage Plan.
 *
 * ## Import
 *
 * AWS API Gateway Usage Plan can be imported using the `id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:apigateway/usagePlan:UsagePlan myusageplan <usage_plan_id>
 * ```
 */
export declare class UsagePlan extends pulumi.CustomResource {
    /**
     * Get an existing UsagePlan resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UsagePlanState, opts?: pulumi.CustomResourceOptions): UsagePlan;
    /**
     * Returns true if the given object is an instance of UsagePlan.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UsagePlan;
    /**
     * The associated API stages of the usage plan.
     */
    readonly apiStages: pulumi.Output<outputs.apigateway.UsagePlanApiStage[] | undefined>;
    /**
     * Amazon Resource Name (ARN)
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The description of a usage plan.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the usage plan.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The AWS Marketplace product identifier to associate with the usage plan as a SaaS product on AWS Marketplace.
     */
    readonly productCode: pulumi.Output<string | undefined>;
    /**
     * The quota settings of the usage plan.
     */
    readonly quotaSettings: pulumi.Output<outputs.apigateway.UsagePlanQuotaSettings | undefined>;
    /**
     * Key-value map of resource tags
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The throttling limits of the usage plan.
     */
    readonly throttleSettings: pulumi.Output<outputs.apigateway.UsagePlanThrottleSettings | undefined>;
    /**
     * Create a UsagePlan resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: UsagePlanArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering UsagePlan resources.
 */
export interface UsagePlanState {
    /**
     * The associated API stages of the usage plan.
     */
    readonly apiStages?: pulumi.Input<pulumi.Input<inputs.apigateway.UsagePlanApiStage>[]>;
    /**
     * Amazon Resource Name (ARN)
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The description of a usage plan.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The name of the usage plan.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The AWS Marketplace product identifier to associate with the usage plan as a SaaS product on AWS Marketplace.
     */
    readonly productCode?: pulumi.Input<string>;
    /**
     * The quota settings of the usage plan.
     */
    readonly quotaSettings?: pulumi.Input<inputs.apigateway.UsagePlanQuotaSettings>;
    /**
     * Key-value map of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The throttling limits of the usage plan.
     */
    readonly throttleSettings?: pulumi.Input<inputs.apigateway.UsagePlanThrottleSettings>;
}
/**
 * The set of arguments for constructing a UsagePlan resource.
 */
export interface UsagePlanArgs {
    /**
     * The associated API stages of the usage plan.
     */
    readonly apiStages?: pulumi.Input<pulumi.Input<inputs.apigateway.UsagePlanApiStage>[]>;
    /**
     * The description of a usage plan.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The name of the usage plan.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The AWS Marketplace product identifier to associate with the usage plan as a SaaS product on AWS Marketplace.
     */
    readonly productCode?: pulumi.Input<string>;
    /**
     * The quota settings of the usage plan.
     */
    readonly quotaSettings?: pulumi.Input<inputs.apigateway.UsagePlanQuotaSettings>;
    /**
     * Key-value map of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The throttling limits of the usage plan.
     */
    readonly throttleSettings?: pulumi.Input<inputs.apigateway.UsagePlanThrottleSettings>;
}
