import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an API Gateway Usage Plan Key.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = new aws.apigateway.RestApi("test", {});
 * // ...
 * const myusageplan = new aws.apigateway.UsagePlan("myusageplan", {apiStages: [{
 *     apiId: test.id,
 *     stage: aws_api_gateway_deployment.foo.stage_name,
 * }]});
 * const mykey = new aws.apigateway.ApiKey("mykey", {});
 * const main = new aws.apigateway.UsagePlanKey("main", {
 *     keyId: mykey.id,
 *     keyType: "API_KEY",
 *     usagePlanId: myusageplan.id,
 * });
 * ```
 *
 * ## Import
 *
 * AWS API Gateway Usage Plan Key can be imported using the `USAGE-PLAN-ID/USAGE-PLAN-KEY-ID`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:apigateway/usagePlanKey:UsagePlanKey key 12345abcde/zzz
 * ```
 */
export declare class UsagePlanKey extends pulumi.CustomResource {
    /**
     * Get an existing UsagePlanKey resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UsagePlanKeyState, opts?: pulumi.CustomResourceOptions): UsagePlanKey;
    /**
     * Returns true if the given object is an instance of UsagePlanKey.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UsagePlanKey;
    /**
     * The identifier of the API key resource.
     */
    readonly keyId: pulumi.Output<string>;
    /**
     * The type of the API key resource. Currently, the valid key type is API_KEY.
     */
    readonly keyType: pulumi.Output<string>;
    /**
     * The name of a usage plan key.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Id of the usage plan resource representing to associate the key to.
     */
    readonly usagePlanId: pulumi.Output<string>;
    /**
     * The value of a usage plan key.
     */
    readonly value: pulumi.Output<string>;
    /**
     * Create a UsagePlanKey resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UsagePlanKeyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering UsagePlanKey resources.
 */
export interface UsagePlanKeyState {
    /**
     * The identifier of the API key resource.
     */
    readonly keyId?: pulumi.Input<string>;
    /**
     * The type of the API key resource. Currently, the valid key type is API_KEY.
     */
    readonly keyType?: pulumi.Input<string>;
    /**
     * The name of a usage plan key.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The Id of the usage plan resource representing to associate the key to.
     */
    readonly usagePlanId?: pulumi.Input<string>;
    /**
     * The value of a usage plan key.
     */
    readonly value?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a UsagePlanKey resource.
 */
export interface UsagePlanKeyArgs {
    /**
     * The identifier of the API key resource.
     */
    readonly keyId: pulumi.Input<string>;
    /**
     * The type of the API key resource. Currently, the valid key type is API_KEY.
     */
    readonly keyType: pulumi.Input<string>;
    /**
     * The Id of the usage plan resource representing to associate the key to.
     */
    readonly usagePlanId: pulumi.Input<string>;
}
