import * as pulumi from "@pulumi/pulumi";
/**
 * Provides details about multiple Amazon API Gateway Version 2 APIs.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.apigatewayv2.getApis({
 *     protocolType: "HTTP",
 * }, { async: true }));
 * ```
 */
export declare function getApis(args?: GetApisArgs, opts?: pulumi.InvokeOptions): Promise<GetApisResult>;
/**
 * A collection of arguments for invoking getApis.
 */
export interface GetApisArgs {
    /**
     * The API name.
     */
    readonly name?: string;
    /**
     * The API protocol.
     */
    readonly protocolType?: string;
    /**
     * A map of tags, each pair of which must exactly match
     * a pair on the desired APIs.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getApis.
 */
export interface GetApisResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Set of API identifiers.
     */
    readonly ids: string[];
    readonly name?: string;
    readonly protocolType?: string;
    readonly tags?: {
        [key: string]: string;
    };
}
