import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * The Autoscaling Groups data source allows access to the list of AWS
 * ASGs within a specific region. This will allow you to pass a list of AutoScaling Groups to other resources.
 */
export declare function getAmiIds(args?: GetAmiIdsArgs, opts?: pulumi.InvokeOptions): Promise<GetAmiIdsResult>;
/**
 * A collection of arguments for invoking getAmiIds.
 */
export interface GetAmiIdsArgs {
    /**
     * A filter used to scope the list e.g. by tags. See [related docs](http://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_Filter.html).
     */
    readonly filters?: inputs.autoscaling.GetAmiIdsFilter[];
}
/**
 * A collection of values returned by getAmiIds.
 */
export interface GetAmiIdsResult {
    /**
     * A list of the Autoscaling Groups Arns in the current region.
     */
    readonly arns: string[];
    readonly filters?: outputs.autoscaling.GetAmiIdsFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A list of the Autoscaling Groups in the current region.
     */
    readonly names: string[];
}
