import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get information on an existing backup selection.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = aws.backup.getSelection({
 *     planId: data.aws_backup_plan.example.id,
 *     selectionId: "selection-id-example",
 * });
 * ```
 */
export declare function getSelection(args: GetSelectionArgs, opts?: pulumi.InvokeOptions): Promise<GetSelectionResult>;
/**
 * A collection of arguments for invoking getSelection.
 */
export interface GetSelectionArgs {
    /**
     * The backup plan ID associated with the selection of resources.
     */
    readonly planId: string;
    /**
     * The backup selection ID.
     */
    readonly selectionId: string;
}
/**
 * A collection of values returned by getSelection.
 */
export interface GetSelectionResult {
    /**
     * The ARN of the IAM role that AWS Backup uses to authenticate when restoring and backing up the target resource. See the [AWS Backup Developer Guide](https://docs.aws.amazon.com/aws-backup/latest/devguide/access-control.html#managed-policies) for additional information about using AWS managed policies or creating custom policies attached to the IAM role.
     */
    readonly iamRoleArn: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The display name of a resource selection document.
     */
    readonly name: string;
    readonly planId: string;
    /**
     * An array of strings that either contain Amazon Resource Names (ARNs) or match patterns of resources to assign to a backup plan..
     */
    readonly resources: string[];
    readonly selectionId: string;
}
