import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an AWS Backup Region Settings resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = new aws.backup.RegionSettings("test", {
 *     resourceTypeOptInPreference: {
 *         Aurora: true,
 *         DynamoDB: true,
 *         EBS: true,
 *         EC2: true,
 *         EFS: true,
 *         FSx: true,
 *         RDS: true,
 *         "Storage Gateway": true,
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * Backup Region Settings can be imported using the `region`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:backup/regionSettings:RegionSettings test us-west-2
 * ```
 */
export declare class RegionSettings extends pulumi.CustomResource {
    /**
     * Get an existing RegionSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RegionSettingsState, opts?: pulumi.CustomResourceOptions): RegionSettings;
    /**
     * Returns true if the given object is an instance of RegionSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RegionSettings;
    /**
     * A map of services along with the opt-in preferences for the Region.
     */
    readonly resourceTypeOptInPreference: pulumi.Output<{
        [key: string]: boolean;
    }>;
    /**
     * Create a RegionSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RegionSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RegionSettings resources.
 */
export interface RegionSettingsState {
    /**
     * A map of services along with the opt-in preferences for the Region.
     */
    readonly resourceTypeOptInPreference?: pulumi.Input<{
        [key: string]: pulumi.Input<boolean>;
    }>;
}
/**
 * The set of arguments for constructing a RegionSettings resource.
 */
export interface RegionSettingsArgs {
    /**
     * A map of services along with the opt-in preferences for the Region.
     */
    readonly resourceTypeOptInPreference: pulumi.Input<{
        [key: string]: pulumi.Input<boolean>;
    }>;
}
