import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a CloudWatch Logs destination resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const testDestination = new aws.cloudwatch.LogDestination("testDestination", {
 *     roleArn: aws_iam_role.iam_for_cloudwatch.arn,
 *     targetArn: aws_kinesis_stream.kinesis_for_cloudwatch.arn,
 * });
 * ```
 *
 * ## Import
 *
 * CloudWatch Logs destinations can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:cloudwatch/logDestination:LogDestination test_destination test_destination
 * ```
 */
export declare class LogDestination extends pulumi.CustomResource {
    /**
     * Get an existing LogDestination resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LogDestinationState, opts?: pulumi.CustomResourceOptions): LogDestination;
    /**
     * Returns true if the given object is an instance of LogDestination.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LogDestination;
    /**
     * The Amazon Resource Name (ARN) specifying the log destination.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A name for the log destination
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ARN of an IAM role that grants Amazon CloudWatch Logs permissions to put data into the target
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * The ARN of the target Amazon Kinesis stream resource for the destination
     */
    readonly targetArn: pulumi.Output<string>;
    /**
     * Create a LogDestination resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LogDestinationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LogDestination resources.
 */
export interface LogDestinationState {
    /**
     * The Amazon Resource Name (ARN) specifying the log destination.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * A name for the log destination
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The ARN of an IAM role that grants Amazon CloudWatch Logs permissions to put data into the target
     */
    readonly roleArn?: pulumi.Input<string>;
    /**
     * The ARN of the target Amazon Kinesis stream resource for the destination
     */
    readonly targetArn?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a LogDestination resource.
 */
export interface LogDestinationArgs {
    /**
     * A name for the log destination
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The ARN of an IAM role that grants Amazon CloudWatch Logs permissions to put data into the target
     */
    readonly roleArn: pulumi.Input<string>;
    /**
     * The ARN of the target Amazon Kinesis stream resource for the destination
     */
    readonly targetArn: pulumi.Input<string>;
}
