import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a CloudWatch Log Stream resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const yada = new aws.cloudwatch.LogGroup("yada", {});
 * const foo = new aws.cloudwatch.LogStream("foo", {logGroupName: yada.name});
 * ```
 *
 * ## Import
 *
 * Cloudwatch Log Stream can be imported using the stream's `log_group_name` and `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:cloudwatch/logStream:LogStream foo Yada:SampleLogStream1234
 * ```
 */
export declare class LogStream extends pulumi.CustomResource {
    /**
     * Get an existing LogStream resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LogStreamState, opts?: pulumi.CustomResourceOptions): LogStream;
    /**
     * Returns true if the given object is an instance of LogStream.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LogStream;
    /**
     * The Amazon Resource Name (ARN) specifying the log stream.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the log group under which the log stream is to be created.
     */
    readonly logGroupName: pulumi.Output<string>;
    /**
     * The name of the log stream. Must not be longer than 512 characters and must not contain `:`
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a LogStream resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LogStreamArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LogStream resources.
 */
export interface LogStreamState {
    /**
     * The Amazon Resource Name (ARN) specifying the log stream.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The name of the log group under which the log stream is to be created.
     */
    readonly logGroupName?: pulumi.Input<string>;
    /**
     * The name of the log stream. Must not be longer than 512 characters and must not contain `:`
     */
    readonly name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a LogStream resource.
 */
export interface LogStreamArgs {
    /**
     * The name of the log group under which the log stream is to be created.
     */
    readonly logGroupName: pulumi.Input<string>;
    /**
     * The name of the log stream. Must not be longer than 512 characters and must not contain `:`
     */
    readonly name?: pulumi.Input<string>;
}
