import { output as outputs } from "../types";
import { Region } from "..";
/**
 * The access key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
 */
export declare let accessKey: string | undefined;
export declare let allowedAccountIds: string[] | undefined;
export declare let assumeRole: outputs.config.AssumeRole | undefined;
/**
 * Configuration block with settings to default resource tags across all resources.
 */
export declare let defaultTags: outputs.config.DefaultTags | undefined;
export declare let endpoints: outputs.config.Endpoints[] | undefined;
export declare let forbiddenAccountIds: string[] | undefined;
/**
 * Configuration block with settings to ignore resource tags across all resources.
 */
export declare let ignoreTags: outputs.config.IgnoreTags | undefined;
/**
 * Explicitly allow the provider to perform "insecure" SSL requests. If omitted,default value is `false`
 */
export declare let insecure: boolean | undefined;
/**
 * The maximum number of times an AWS API request is being executed. If the API request still fails, an error is thrown.
 */
export declare let maxRetries: number | undefined;
/**
 * The profile for API operations. If not set, the default profile created with `aws configure` will be used.
 */
export declare let profile: string | undefined;
/**
 * The region where AWS operations will take place. Examples are us-east-1, us-west-2, etc.
 */
export declare let region: Region | undefined;
/**
 * Set this to true to force the request to use path-style addressing, i.e., http://s3.amazonaws.com/BUCKET/KEY. By
 * default, the S3 client will use virtual hosted bucket addressing when possible (http://BUCKET.s3.amazonaws.com/KEY).
 * Specific to the Amazon S3 service.
 */
export declare let s3ForcePathStyle: boolean | undefined;
/**
 * The secret key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
 */
export declare let secretKey: string | undefined;
/**
 * The path to the shared credentials file. If not set this defaults to ~/.aws/credentials.
 */
export declare let sharedCredentialsFile: string | undefined;
/**
 * Skip the credentials validation via STS API. Used for AWS API implementations that do not have STS
 * available/implemented.
 */
export declare let skipCredentialsValidation: boolean | undefined;
/**
 * Skip getting the supported EC2 platforms. Used by users that don't have ec2:DescribeAccountAttributes permissions.
 */
export declare let skipGetEc2Platforms: boolean | undefined;
export declare let skipMetadataApiCheck: boolean | undefined;
/**
 * Skip static validation of region name. Used by users of alternative AWS-like APIs or users w/ access to regions that are
 * not public (yet).
 */
export declare let skipRegionValidation: boolean | undefined;
/**
 * Skip requesting the account ID. Used for AWS API implementations that do not have IAM/STS API and/or metadata API.
 */
export declare let skipRequestingAccountId: boolean | undefined;
/**
 * session token. A session token is only required if you are using temporary security credentials.
 */
export declare let token: string | undefined;
