import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a DAX Subnet Group resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.dax.SubnetGroup("example", {subnetIds: [
 *     aws_subnet.example1.id,
 *     aws_subnet.example2.id,
 * ]});
 * ```
 *
 * ## Import
 *
 * DAX Subnet Group can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:dax/subnetGroup:SubnetGroup example my_dax_sg
 * ```
 */
export declare class SubnetGroup extends pulumi.CustomResource {
    /**
     * Get an existing SubnetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SubnetGroupState, opts?: pulumi.CustomResourceOptions): SubnetGroup;
    /**
     * Returns true if the given object is an instance of SubnetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SubnetGroup;
    /**
     * A description of the subnet group.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the subnet group.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A list of VPC subnet IDs for the subnet group.
     */
    readonly subnetIds: pulumi.Output<string[]>;
    /**
     * VPC ID of the subnet group.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a SubnetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SubnetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SubnetGroup resources.
 */
export interface SubnetGroupState {
    /**
     * A description of the subnet group.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The name of the subnet group.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A list of VPC subnet IDs for the subnet group.
     */
    readonly subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * VPC ID of the subnet group.
     */
    readonly vpcId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a SubnetGroup resource.
 */
export interface SubnetGroupArgs {
    /**
     * A description of the subnet group.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The name of the subnet group.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A list of VPC subnet IDs for the subnet group.
     */
    readonly subnetIds: pulumi.Input<pulumi.Input<string>[]>;
}
