import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieve information about a Direct Connect Gateway.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.directconnect.getGateway({
 *     name: "example",
 * }, { async: true }));
 * ```
 */
export declare function getGateway(args: GetGatewayArgs, opts?: pulumi.InvokeOptions): Promise<GetGatewayResult>;
/**
 * A collection of arguments for invoking getGateway.
 */
export interface GetGatewayArgs {
    /**
     * The name of the gateway to retrieve.
     */
    readonly name: string;
}
/**
 * A collection of values returned by getGateway.
 */
export interface GetGatewayResult {
    /**
     * The ASN on the Amazon side of the connection.
     */
    readonly amazonSideAsn: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
    /**
     * AWS Account ID of the gateway.
     */
    readonly ownerAccountId: string;
}
