import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a DMS (Data Migration Service) replication subnet group resource. DMS replication subnet groups can be created, updated, deleted, and imported.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * // Create a new replication subnet group
 * const test = new aws.dms.ReplicationSubnetGroup("test", {
 *     replicationSubnetGroupDescription: "Test replication subnet group",
 *     replicationSubnetGroupId: "test-dms-replication-subnet-group-tf",
 *     subnetIds: ["subnet-12345678"],
 *     tags: {
 *         Name: "test",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * Replication subnet groups can be imported using the `replication_subnet_group_id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:dms/replicationSubnetGroup:ReplicationSubnetGroup test test-dms-replication-subnet-group-tf
 * ```
 */
export declare class ReplicationSubnetGroup extends pulumi.CustomResource {
    /**
     * Get an existing ReplicationSubnetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ReplicationSubnetGroupState, opts?: pulumi.CustomResourceOptions): ReplicationSubnetGroup;
    /**
     * Returns true if the given object is an instance of ReplicationSubnetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ReplicationSubnetGroup;
    readonly replicationSubnetGroupArn: pulumi.Output<string>;
    /**
     * The description for the subnet group.
     */
    readonly replicationSubnetGroupDescription: pulumi.Output<string>;
    /**
     * The name for the replication subnet group. This value is stored as a lowercase string.
     */
    readonly replicationSubnetGroupId: pulumi.Output<string>;
    /**
     * A list of the EC2 subnet IDs for the subnet group.
     */
    readonly subnetIds: pulumi.Output<string[]>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The ID of the VPC the subnet group is in.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a ReplicationSubnetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ReplicationSubnetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ReplicationSubnetGroup resources.
 */
export interface ReplicationSubnetGroupState {
    readonly replicationSubnetGroupArn?: pulumi.Input<string>;
    /**
     * The description for the subnet group.
     */
    readonly replicationSubnetGroupDescription?: pulumi.Input<string>;
    /**
     * The name for the replication subnet group. This value is stored as a lowercase string.
     */
    readonly replicationSubnetGroupId?: pulumi.Input<string>;
    /**
     * A list of the EC2 subnet IDs for the subnet group.
     */
    readonly subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The ID of the VPC the subnet group is in.
     */
    readonly vpcId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ReplicationSubnetGroup resource.
 */
export interface ReplicationSubnetGroupArgs {
    /**
     * The description for the subnet group.
     */
    readonly replicationSubnetGroupDescription: pulumi.Input<string>;
    /**
     * The name for the replication subnet group. This value is stored as a lowercase string.
     */
    readonly replicationSubnetGroupId: pulumi.Input<string>;
    /**
     * A list of the EC2 subnet IDs for the subnet group.
     */
    readonly subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
