import * as pulumi from "@pulumi/pulumi";
/**
 * Information about DocumentDB orderable DB instances.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = pulumi.output(aws.docdb.getOrderableDbInstance({
 *     engine: "docdb",
 *     engineVersion: "3.6.0",
 *     licenseModel: "na",
 *     preferredInstanceClasses: [
 *         "db.r5.large",
 *         "db.r4.large",
 *         "db.t3.medium",
 *     ],
 * }, { async: true }));
 * ```
 */
export declare function getOrderableDbInstance(args?: GetOrderableDbInstanceArgs, opts?: pulumi.InvokeOptions): Promise<GetOrderableDbInstanceResult>;
/**
 * A collection of arguments for invoking getOrderableDbInstance.
 */
export interface GetOrderableDbInstanceArgs {
    /**
     * DB engine. Default: `docdb`
     */
    readonly engine?: string;
    /**
     * Version of the DB engine.
     */
    readonly engineVersion?: string;
    /**
     * DB instance class. Examples of classes are `db.r5.12xlarge`, `db.r5.24xlarge`, `db.r5.2xlarge`, `db.r5.4xlarge`, `db.r5.large`, `db.r5.xlarge`, and `db.t3.medium`. (Conflicts with `preferredInstanceClasses`.)
     */
    readonly instanceClass?: string;
    /**
     * License model. Default: `na`
     */
    readonly licenseModel?: string;
    /**
     * Ordered list of preferred DocumentDB DB instance classes. The first match in this list will be returned. If no preferred matches are found and the original search returned more than one result, an error is returned. (Conflicts with `instanceClass`.)
     */
    readonly preferredInstanceClasses?: string[];
    /**
     * Enable to show only VPC.
     */
    readonly vpc?: boolean;
}
/**
 * A collection of values returned by getOrderableDbInstance.
 */
export interface GetOrderableDbInstanceResult {
    /**
     * Availability zones where the instance is available.
     */
    readonly availabilityZones: string[];
    readonly engine?: string;
    readonly engineVersion: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly instanceClass: string;
    readonly licenseModel?: string;
    readonly preferredInstanceClasses?: string[];
    readonly vpc: boolean;
}
