import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides information about a DynamoDB table.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const tableName = pulumi.output(aws.dynamodb.getTable({
 *     name: "tableName",
 * }, { async: true }));
 * ```
 */
export declare function getTable(args: GetTableArgs, opts?: pulumi.InvokeOptions): Promise<GetTableResult>;
/**
 * A collection of arguments for invoking getTable.
 */
export interface GetTableArgs {
    /**
     * The name of the DynamoDB table.
     */
    readonly name: string;
    readonly serverSideEncryption?: inputs.dynamodb.GetTableServerSideEncryption;
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getTable.
 */
export interface GetTableResult {
    readonly arn: string;
    readonly attributes: outputs.dynamodb.GetTableAttribute[];
    readonly billingMode: string;
    readonly globalSecondaryIndexes: outputs.dynamodb.GetTableGlobalSecondaryIndex[];
    readonly hashKey: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly localSecondaryIndexes: outputs.dynamodb.GetTableLocalSecondaryIndex[];
    readonly name: string;
    readonly pointInTimeRecovery: outputs.dynamodb.GetTablePointInTimeRecovery;
    readonly rangeKey: string;
    readonly readCapacity: number;
    readonly replicas: outputs.dynamodb.GetTableReplica[];
    readonly serverSideEncryption: outputs.dynamodb.GetTableServerSideEncryption;
    readonly streamArn: string;
    readonly streamEnabled: boolean;
    readonly streamLabel: string;
    readonly streamViewType: string;
    readonly tags: {
        [key: string]: string;
    };
    readonly ttl: outputs.dynamodb.GetTableTtl;
    readonly writeCapacity: number;
}
