import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a resource to manage whether default EBS encryption is enabled for your AWS account in the current AWS region. To manage the default KMS key for the region, see the `aws.ebs.DefaultKmsKey` resource.
 *
 * > **NOTE:** Removing this resource disables default EBS encryption.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ebs.EncryptionByDefault("example", {
 *     enabled: true,
 * });
 * ```
 */
export declare class EncryptionByDefault extends pulumi.CustomResource {
    /**
     * Get an existing EncryptionByDefault resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: EncryptionByDefaultState, opts?: pulumi.CustomResourceOptions): EncryptionByDefault;
    /**
     * Returns true if the given object is an instance of EncryptionByDefault.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EncryptionByDefault;
    /**
     * Whether or not default EBS encryption is enabled. Valid values are `true` or `false`. Defaults to `true`.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * Create a EncryptionByDefault resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: EncryptionByDefaultArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering EncryptionByDefault resources.
 */
export interface EncryptionByDefaultState {
    /**
     * Whether or not default EBS encryption is enabled. Valid values are `true` or `false`. Defaults to `true`.
     */
    readonly enabled?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a EncryptionByDefault resource.
 */
export interface EncryptionByDefaultArgs {
    /**
     * Whether or not default EBS encryption is enabled. Valid values are `true` or `false`. Defaults to `true`.
     */
    readonly enabled?: pulumi.Input<boolean>;
}
