import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a way to check whether default EBS encryption is enabled for your AWS account in the current AWS region.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const current = pulumi.output(aws.ebs.getEncryptionByDefault({ async: true }));
 * ```
 */
export declare function getEncryptionByDefault(opts?: pulumi.InvokeOptions): Promise<GetEncryptionByDefaultResult>;
/**
 * A collection of values returned by getEncryptionByDefault.
 */
export interface GetEncryptionByDefaultResult {
    /**
     * Whether or not default EBS encryption is enabled. Returns as `true` or `false`.
     */
    readonly enabled: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
}
