import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Use this data source to get a list of EBS Snapshot IDs matching the specified
 * criteria.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const ebsVolumes = pulumi.output(aws.ebs.getSnapshotIds({
 *     filters: [
 *         {
 *             name: "volume-size",
 *             values: ["40"],
 *         },
 *         {
 *             name: "tag:Name",
 *             values: ["Example"],
 *         },
 *     ],
 *     owners: ["self"],
 * }, { async: true }));
 * ```
 */
export declare function getSnapshotIds(args?: GetSnapshotIdsArgs, opts?: pulumi.InvokeOptions): Promise<GetSnapshotIdsResult>;
/**
 * A collection of arguments for invoking getSnapshotIds.
 */
export interface GetSnapshotIdsArgs {
    /**
     * One or more name/value pairs to filter off of. There are
     * several valid keys, for a full reference, check out
     * [describe-volumes in the AWS CLI reference][1].
     */
    readonly filters?: inputs.ebs.GetSnapshotIdsFilter[];
    /**
     * Returns the snapshots owned by the specified owner id. Multiple owners can be specified.
     */
    readonly owners?: string[];
    /**
     * One or more AWS accounts IDs that can create volumes from the snapshot.
     */
    readonly restorableByUserIds?: string[];
}
/**
 * A collection of values returned by getSnapshotIds.
 */
export interface GetSnapshotIdsResult {
    readonly filters?: outputs.ebs.GetSnapshotIdsFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Set of EBS snapshot IDs, sorted by creation time in descending order.
     */
    readonly ids: string[];
    readonly owners?: string[];
    readonly restorableByUserIds?: string[];
}
