import * as pulumi from "@pulumi/pulumi";
/**
 * Adds launch permission to Amazon Machine Image (AMI) from another AWS account.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ec2.AmiLaunchPermission("example", {
 *     accountId: "123456789012",
 *     imageId: "ami-12345678",
 * });
 * ```
 *
 * ## Import
 *
 * AWS AMI Launch Permission can be imported using the `ACCOUNT-ID/IMAGE-ID`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/amiLaunchPermission:AmiLaunchPermission example 123456789012/ami-12345678
 * ```
 */
export declare class AmiLaunchPermission extends pulumi.CustomResource {
    /**
     * Get an existing AmiLaunchPermission resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AmiLaunchPermissionState, opts?: pulumi.CustomResourceOptions): AmiLaunchPermission;
    /**
     * Returns true if the given object is an instance of AmiLaunchPermission.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AmiLaunchPermission;
    /**
     * An AWS Account ID to add launch permissions.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * A region-unique name for the AMI.
     */
    readonly imageId: pulumi.Output<string>;
    /**
     * Create a AmiLaunchPermission resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AmiLaunchPermissionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AmiLaunchPermission resources.
 */
export interface AmiLaunchPermissionState {
    /**
     * An AWS Account ID to add launch permissions.
     */
    readonly accountId?: pulumi.Input<string>;
    /**
     * A region-unique name for the AMI.
     */
    readonly imageId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AmiLaunchPermission resource.
 */
export interface AmiLaunchPermissionArgs {
    /**
     * An AWS Account ID to add launch permissions.
     */
    readonly accountId: pulumi.Input<string>;
    /**
     * A region-unique name for the AMI.
     */
    readonly imageId: pulumi.Input<string>;
}
