import * as pulumi from "@pulumi/pulumi";
/**
 * Manages an EC2 Availability Zone Group, such as updating its opt-in status.
 *
 * > **NOTE:** This is an advanced resource. The provider will automatically assume management of the EC2 Availability Zone Group without import and perform no actions on removal from configuration.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ec2.AvailabilityZoneGroup("example", {
 *     groupName: "us-west-2-lax-1",
 *     optInStatus: "opted-in",
 * });
 * ```
 *
 * ## Import
 *
 * EC2 Availability Zone Groups can be imported using the group name, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/availabilityZoneGroup:AvailabilityZoneGroup example us-west-2-lax-1
 * ```
 */
export declare class AvailabilityZoneGroup extends pulumi.CustomResource {
    /**
     * Get an existing AvailabilityZoneGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AvailabilityZoneGroupState, opts?: pulumi.CustomResourceOptions): AvailabilityZoneGroup;
    /**
     * Returns true if the given object is an instance of AvailabilityZoneGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AvailabilityZoneGroup;
    /**
     * Name of the Availability Zone Group.
     */
    readonly groupName: pulumi.Output<string>;
    /**
     * Indicates whether to enable or disable Availability Zone Group. Valid values: `opted-in` or `not-opted-in`.
     */
    readonly optInStatus: pulumi.Output<string>;
    /**
     * Create a AvailabilityZoneGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AvailabilityZoneGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AvailabilityZoneGroup resources.
 */
export interface AvailabilityZoneGroupState {
    /**
     * Name of the Availability Zone Group.
     */
    readonly groupName?: pulumi.Input<string>;
    /**
     * Indicates whether to enable or disable Availability Zone Group. Valid values: `opted-in` or `not-opted-in`.
     */
    readonly optInStatus?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AvailabilityZoneGroup resource.
 */
export interface AvailabilityZoneGroupArgs {
    /**
     * Name of the Availability Zone Group.
     */
    readonly groupName: pulumi.Input<string>;
    /**
     * Indicates whether to enable or disable Availability Zone Group. Valid values: `opted-in` or `not-opted-in`.
     */
    readonly optInStatus: pulumi.Input<string>;
}
