import * as pulumi from "@pulumi/pulumi";
/**
 * Manages an EC2 Carrier Gateway. See the AWS [documentation](https://docs.aws.amazon.com/vpc/latest/userguide/Carrier_Gateway.html) for more information.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ec2.CarrierGateway("example", {
 *     vpcId: aws_vpc.example.id,
 *     tags: {
 *         Name: "example-carrier-gateway",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * `aws_ec2_carrier_gateway` can be imported using the carrier gateway's ID, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/carrierGateway:CarrierGateway example cgw-12345
 * ```
 */
export declare class CarrierGateway extends pulumi.CustomResource {
    /**
     * Get an existing CarrierGateway resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CarrierGatewayState, opts?: pulumi.CustomResourceOptions): CarrierGateway;
    /**
     * Returns true if the given object is an instance of CarrierGateway.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CarrierGateway;
    /**
     * The ARN of the carrier gateway.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The AWS account ID of the owner of the carrier gateway.
     */
    readonly ownerId: pulumi.Output<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The ID of the VPC to associate with the carrier gateway.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a CarrierGateway resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CarrierGatewayArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CarrierGateway resources.
 */
export interface CarrierGatewayState {
    /**
     * The ARN of the carrier gateway.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The AWS account ID of the owner of the carrier gateway.
     */
    readonly ownerId?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The ID of the VPC to associate with the carrier gateway.
     */
    readonly vpcId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a CarrierGateway resource.
 */
export interface CarrierGatewayArgs {
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The ID of the VPC to associate with the carrier gateway.
     */
    readonly vpcId: pulumi.Input<string>;
}
