"use strict";
// *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
// *** Do not edit by hand unless you're certain you know what you are doing! ***
Object.defineProperty(exports, "__esModule", { value: true });
const pulumi = require("@pulumi/pulumi");
const utilities = require("../utilities");
/**
 * Provides an Elastic IP resource.
 *
 * > **Note:** EIP may require IGW to exist prior to association. Use `dependsOn` to set an explicit dependency on the IGW.
 *
 * > **Note:** Do not use `networkInterface` to associate the EIP to `aws.lb.LoadBalancer` or `aws.ec2.NatGateway` resources. Instead use the `allocationId` available in those resources to allow AWS to manage the association, otherwise you will see `AuthFailure` errors.
 *
 * ## Example Usage
 *
 * Single EIP associated with an instance:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const lb = new aws.ec2.Eip("lb", {
 *     instance: aws_instance.web.id,
 *     vpc: true,
 * });
 * ```
 *
 * Multiple EIPs associated with a single network interface:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const multi_ip = new aws.ec2.NetworkInterface("multi-ip", {
 *     subnetId: aws_subnet.main.id,
 *     privateIps: [
 *         "10.0.0.10",
 *         "10.0.0.11",
 *     ],
 * });
 * const one = new aws.ec2.Eip("one", {
 *     vpc: true,
 *     networkInterface: multi_ip.id,
 *     associateWithPrivateIp: "10.0.0.10",
 * });
 * const two = new aws.ec2.Eip("two", {
 *     vpc: true,
 *     networkInterface: multi_ip.id,
 *     associateWithPrivateIp: "10.0.0.11",
 * });
 * ```
 *
 * Attaching an EIP to an Instance with a pre-assigned private ip (VPC Only):
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const _default = new aws.ec2.Vpc("default", {
 *     cidrBlock: "10.0.0.0/16",
 *     enableDnsHostnames: true,
 * });
 * const gw = new aws.ec2.InternetGateway("gw", {vpcId: _default.id});
 * const tfTestSubnet = new aws.ec2.Subnet("tfTestSubnet", {
 *     vpcId: _default.id,
 *     cidrBlock: "10.0.0.0/24",
 *     mapPublicIpOnLaunch: true,
 * }, {
 *     dependsOn: [gw],
 * });
 * const foo = new aws.ec2.Instance("foo", {
 *     ami: "ami-5189a661",
 *     instanceType: "t2.micro",
 *     privateIp: "10.0.0.12",
 *     subnetId: tfTestSubnet.id,
 * });
 * const bar = new aws.ec2.Eip("bar", {
 *     vpc: true,
 *     instance: foo.id,
 *     associateWithPrivateIp: "10.0.0.12",
 * }, {
 *     dependsOn: [gw],
 * });
 * ```
 *
 * Allocating EIP from the BYOIP pool:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const byoip_ip = new aws.ec2.Eip("byoip-ip", {
 *     publicIpv4Pool: "ipv4pool-ec2-012345",
 *     vpc: true,
 * });
 * ```
 *
 * ## Import
 *
 * EIPs in a VPC can be imported using their Allocation ID, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/eip:Eip bar eipalloc-00a10e96
 * ```
 *
 *  EIPs in EC2 Classic can be imported using their Public IP, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/eip:Eip bar 52.0.0.0
 * ```
 *
 *  [1]https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateAddress.html
 */
class Eip extends pulumi.CustomResource {
    constructor(name, argsOrState, opts) {
        let inputs = {};
        opts = opts || {};
        if (opts.id) {
            const state = argsOrState;
            inputs["allocationId"] = state ? state.allocationId : undefined;
            inputs["associateWithPrivateIp"] = state ? state.associateWithPrivateIp : undefined;
            inputs["associationId"] = state ? state.associationId : undefined;
            inputs["carrierIp"] = state ? state.carrierIp : undefined;
            inputs["customerOwnedIp"] = state ? state.customerOwnedIp : undefined;
            inputs["customerOwnedIpv4Pool"] = state ? state.customerOwnedIpv4Pool : undefined;
            inputs["domain"] = state ? state.domain : undefined;
            inputs["instance"] = state ? state.instance : undefined;
            inputs["networkBorderGroup"] = state ? state.networkBorderGroup : undefined;
            inputs["networkInterface"] = state ? state.networkInterface : undefined;
            inputs["privateDns"] = state ? state.privateDns : undefined;
            inputs["privateIp"] = state ? state.privateIp : undefined;
            inputs["publicDns"] = state ? state.publicDns : undefined;
            inputs["publicIp"] = state ? state.publicIp : undefined;
            inputs["publicIpv4Pool"] = state ? state.publicIpv4Pool : undefined;
            inputs["tags"] = state ? state.tags : undefined;
            inputs["vpc"] = state ? state.vpc : undefined;
        }
        else {
            const args = argsOrState;
            inputs["associateWithPrivateIp"] = args ? args.associateWithPrivateIp : undefined;
            inputs["customerOwnedIpv4Pool"] = args ? args.customerOwnedIpv4Pool : undefined;
            inputs["instance"] = args ? args.instance : undefined;
            inputs["networkBorderGroup"] = args ? args.networkBorderGroup : undefined;
            inputs["networkInterface"] = args ? args.networkInterface : undefined;
            inputs["publicIpv4Pool"] = args ? args.publicIpv4Pool : undefined;
            inputs["tags"] = args ? args.tags : undefined;
            inputs["vpc"] = args ? args.vpc : undefined;
            inputs["allocationId"] = undefined /*out*/;
            inputs["associationId"] = undefined /*out*/;
            inputs["carrierIp"] = undefined /*out*/;
            inputs["customerOwnedIp"] = undefined /*out*/;
            inputs["domain"] = undefined /*out*/;
            inputs["privateDns"] = undefined /*out*/;
            inputs["privateIp"] = undefined /*out*/;
            inputs["publicDns"] = undefined /*out*/;
            inputs["publicIp"] = undefined /*out*/;
        }
        if (!opts.version) {
            opts = pulumi.mergeOptions(opts, { version: utilities.getVersion() });
        }
        super(Eip.__pulumiType, name, inputs, opts);
    }
    /**
     * Get an existing Eip resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name, id, state, opts) {
        return new Eip(name, state, Object.assign(Object.assign({}, opts), { id: id }));
    }
    /**
     * Returns true if the given object is an instance of Eip.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj) {
        if (obj === undefined || obj === null) {
            return false;
        }
        return obj['__pulumiType'] === Eip.__pulumiType;
    }
}
exports.Eip = Eip;
/** @internal */
Eip.__pulumiType = 'aws:ec2/eip:Eip';
//# sourceMappingURL=eip.js.map