import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides information for multiple EC2 Customer-Owned IP Pools, such as their identifiers.
 */
export declare function getCoipPools(args?: GetCoipPoolsArgs, opts?: pulumi.InvokeOptions): Promise<GetCoipPoolsResult>;
/**
 * A collection of arguments for invoking getCoipPools.
 */
export interface GetCoipPoolsArgs {
    /**
     * Custom filter block as described below.
     */
    readonly filters?: inputs.ec2.GetCoipPoolsFilter[];
    /**
     * A mapping of tags, each pair of which must exactly match
     * a pair on the desired aws_ec2_coip_pools.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getCoipPools.
 */
export interface GetCoipPoolsResult {
    readonly filters?: outputs.ec2.GetCoipPoolsFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Set of COIP Pool Identifiers
     */
    readonly poolIds: string[];
    readonly tags: {
        [key: string]: string;
    };
}
