import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides details about an EC2 Local Gateway.
 *
 * ## Example Usage
 *
 * The following example shows how one might accept a local gateway id as a variable.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const config = new pulumi.Config();
 * const localGatewayId = config.requireObject("localGatewayId");
 * const selected = aws.ec2.getLocalGateway({
 *     id: localGatewayId,
 * });
 * ```
 */
export declare function getLocalGateway(args?: GetLocalGatewayArgs, opts?: pulumi.InvokeOptions): Promise<GetLocalGatewayResult>;
/**
 * A collection of arguments for invoking getLocalGateway.
 */
export interface GetLocalGatewayArgs {
    /**
     * Custom filter block as described below.
     */
    readonly filters?: inputs.ec2.GetLocalGatewayFilter[];
    /**
     * The id of the specific Local Gateway to retrieve.
     */
    readonly id?: string;
    /**
     * The current state of the desired Local Gateway.
     * Can be either `"pending"` or `"available"`.
     */
    readonly state?: string;
    /**
     * A mapping of tags, each pair of which must exactly match
     * a pair on the desired Local Gateway.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getLocalGateway.
 */
export interface GetLocalGatewayResult {
    readonly filters?: outputs.ec2.GetLocalGatewayFilter[];
    readonly id: string;
    /**
     * Amazon Resource Name (ARN) of Outpost
     */
    readonly outpostArn: string;
    /**
     * AWS account identifier that owns the Local Gateway.
     */
    readonly ownerId: string;
    /**
     * State of the local gateway.
     */
    readonly state: string;
    readonly tags: {
        [key: string]: string;
    };
}
