import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides details about an EC2 Local Gateway Virtual Interface Group. More information can be found in the [Outposts User Guide](https://docs.aws.amazon.com/outposts/latest/userguide/outposts-networking-components.html#routing).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = aws.ec2.getLocalGatewayVirtualInterfaceGroup({
 *     localGatewayId: data.aws_ec2_local_gateway.example.id,
 * });
 * ```
 */
export declare function getLocalGatewayVirtualInterfaceGroup(args?: GetLocalGatewayVirtualInterfaceGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetLocalGatewayVirtualInterfaceGroupResult>;
/**
 * A collection of arguments for invoking getLocalGatewayVirtualInterfaceGroup.
 */
export interface GetLocalGatewayVirtualInterfaceGroupArgs {
    /**
     * One or more configuration blocks containing name-values filters. See the [EC2 API Reference](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayVirtualInterfaceGroups.html) for supported filters. Detailed below.
     */
    readonly filters?: inputs.ec2.GetLocalGatewayVirtualInterfaceGroupFilter[];
    /**
     * Identifier of EC2 Local Gateway Virtual Interface Group.
     */
    readonly id?: string;
    /**
     * Identifier of EC2 Local Gateway.
     */
    readonly localGatewayId?: string;
    /**
     * Key-value map of resource tags, each pair of which must exactly match a pair on the desired local gateway route table.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getLocalGatewayVirtualInterfaceGroup.
 */
export interface GetLocalGatewayVirtualInterfaceGroupResult {
    readonly filters?: outputs.ec2.GetLocalGatewayVirtualInterfaceGroupFilter[];
    readonly id: string;
    readonly localGatewayId: string;
    /**
     * Set of EC2 Local Gateway Virtual Interface identifiers.
     */
    readonly localGatewayVirtualInterfaceIds: string[];
    readonly tags: {
        [key: string]: string;
    };
}
