import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Use this data source to get information about a Network Interface.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const bar = pulumi.output(aws.ec2.getNetworkInterface({
 *     id: "eni-01234567",
 * }, { async: true }));
 * ```
 */
export declare function getNetworkInterface(args?: GetNetworkInterfaceArgs, opts?: pulumi.InvokeOptions): Promise<GetNetworkInterfaceResult>;
/**
 * A collection of arguments for invoking getNetworkInterface.
 */
export interface GetNetworkInterfaceArgs {
    /**
     * One or more name/value pairs to filter off of. There are several valid keys, for a full reference, check out [describe-network-interfaces](https://docs.aws.amazon.com/cli/latest/reference/ec2/describe-network-interfaces.html) in the AWS CLI reference.
     */
    readonly filters?: inputs.ec2.GetNetworkInterfaceFilter[];
    /**
     * The identifier for the network interface.
     */
    readonly id?: string;
    /**
     * Any tags assigned to the network interface.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getNetworkInterface.
 */
export interface GetNetworkInterfaceResult {
    /**
     * The association information for an Elastic IP address (IPv4) associated with the network interface. See supported fields below.
     */
    readonly associations: outputs.ec2.GetNetworkInterfaceAssociation[];
    readonly attachments: outputs.ec2.GetNetworkInterfaceAttachment[];
    /**
     * The Availability Zone.
     */
    readonly availabilityZone: string;
    /**
     * Description of the network interface.
     */
    readonly description: string;
    readonly filters?: outputs.ec2.GetNetworkInterfaceFilter[];
    readonly id: string;
    /**
     * The type of interface.
     */
    readonly interfaceType: string;
    /**
     * List of IPv6 addresses to assign to the ENI.
     */
    readonly ipv6Addresses: string[];
    /**
     * The MAC address.
     */
    readonly macAddress: string;
    /**
     * The Amazon Resource Name (ARN) of the Outpost.
     */
    readonly outpostArn: string;
    /**
     * The AWS account ID of the owner of the network interface.
     */
    readonly ownerId: string;
    /**
     * The private DNS name.
     */
    readonly privateDnsName: string;
    /**
     * The private IPv4 address of the network interface within the subnet.
     */
    readonly privateIp: string;
    /**
     * The private IPv4 addresses associated with the network interface.
     */
    readonly privateIps: string[];
    /**
     * The ID of the entity that launched the instance on your behalf.
     */
    readonly requesterId: string;
    /**
     * The list of security groups for the network interface.
     */
    readonly securityGroups: string[];
    /**
     * The ID of the subnet.
     */
    readonly subnetId: string;
    /**
     * Any tags assigned to the network interface.
     */
    readonly tags: {
        [key: string]: string;
    };
    /**
     * The ID of the VPC.
     */
    readonly vpcId: string;
}
