import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Use this data source to get IDs and VPC membership of Security Groups that are created
 * outside of this provider.
 */
export declare function getSecurityGroups(args?: GetSecurityGroupsArgs, opts?: pulumi.InvokeOptions): Promise<GetSecurityGroupsResult>;
/**
 * A collection of arguments for invoking getSecurityGroups.
 */
export interface GetSecurityGroupsArgs {
    /**
     * One or more name/value pairs to use as filters. There are several valid keys, for a full reference, check out [describe-security-groups in the AWS CLI reference][1].
     */
    readonly filters?: inputs.ec2.GetSecurityGroupsFilter[];
    /**
     * A map of tags, each pair of which must exactly match for desired security groups.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getSecurityGroups.
 */
export interface GetSecurityGroupsResult {
    /**
     * ARNs of the matched security groups.
     */
    readonly arns: string[];
    readonly filters?: outputs.ec2.GetSecurityGroupsFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * IDs of the matches security groups.
     */
    readonly ids: string[];
    readonly tags: {
        [key: string]: string;
    };
    /**
     * The VPC IDs of the matched security groups. The data source's tag or filter *will span VPCs* unless the `vpc-id` filter is also used.
     */
    readonly vpcIds: string[];
}
