import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides information for multiple EC2 Transit Gateway Route Tables, such as their identifiers.
 *
 * ## Example Usage
 *
 * The following shows outputing all Transit Gateway Route Table Ids.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleTransitGatewayRouteTables = aws.ec2.getTransitGatewayRouteTables({});
 * export const example = data.aws_ec2_transit_gateway_route_table.example.ids;
 * ```
 */
export declare function getTransitGatewayRouteTables(args?: GetTransitGatewayRouteTablesArgs, opts?: pulumi.InvokeOptions): Promise<GetTransitGatewayRouteTablesResult>;
/**
 * A collection of arguments for invoking getTransitGatewayRouteTables.
 */
export interface GetTransitGatewayRouteTablesArgs {
    /**
     * Custom filter block as described below.
     */
    readonly filters?: inputs.ec2.GetTransitGatewayRouteTablesFilter[];
    /**
     * A mapping of tags, each pair of which must exactly match
     * a pair on the desired transit gateway route table.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getTransitGatewayRouteTables.
 */
export interface GetTransitGatewayRouteTablesResult {
    readonly filters?: outputs.ec2.GetTransitGatewayRouteTablesFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Set of Transit Gateway Route Table identifiers.
     */
    readonly ids: string[];
    readonly tags: {
        [key: string]: string;
    };
}
