import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * `aws.ec2.Vpc` provides details about a specific VPC.
 *
 * This resource can prove useful when a module accepts a vpc id as
 * an input variable and needs to, for example, determine the CIDR block of that
 * VPC.
 */
export declare function getVpc(args?: GetVpcArgs, opts?: pulumi.InvokeOptions): Promise<GetVpcResult>;
/**
 * A collection of arguments for invoking getVpc.
 */
export interface GetVpcArgs {
    /**
     * The cidr block of the desired VPC.
     */
    readonly cidrBlock?: string;
    /**
     * Boolean constraint on whether the desired VPC is
     * the default VPC for the region.
     */
    readonly default?: boolean;
    /**
     * The DHCP options id of the desired VPC.
     */
    readonly dhcpOptionsId?: string;
    /**
     * Custom filter block as described below.
     */
    readonly filters?: inputs.ec2.GetVpcFilter[];
    /**
     * The id of the specific VPC to retrieve.
     */
    readonly id?: string;
    /**
     * The current state of the desired VPC.
     * Can be either `"pending"` or `"available"`.
     */
    readonly state?: string;
    /**
     * A map of tags, each pair of which must exactly match
     * a pair on the desired VPC.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getVpc.
 */
export interface GetVpcResult {
    /**
     * Amazon Resource Name (ARN) of VPC
     */
    readonly arn: string;
    /**
     * The CIDR block for the association.
     */
    readonly cidrBlock: string;
    readonly cidrBlockAssociations: outputs.ec2.GetVpcCidrBlockAssociation[];
    readonly default: boolean;
    readonly dhcpOptionsId: string;
    /**
     * Whether or not the VPC has DNS hostname support
     */
    readonly enableDnsHostnames: boolean;
    /**
     * Whether or not the VPC has DNS support
     */
    readonly enableDnsSupport: boolean;
    readonly filters?: outputs.ec2.GetVpcFilter[];
    readonly id: string;
    /**
     * The allowed tenancy of instances launched into the
     * selected VPC. May be any of `"default"`, `"dedicated"`, or `"host"`.
     */
    readonly instanceTenancy: string;
    /**
     * The association ID for the IPv6 CIDR block.
     */
    readonly ipv6AssociationId: string;
    /**
     * The IPv6 CIDR block.
     */
    readonly ipv6CidrBlock: string;
    /**
     * The ID of the main route table associated with this VPC.
     */
    readonly mainRouteTableId: string;
    /**
     * The ID of the AWS account that owns the VPC.
     */
    readonly ownerId: string;
    /**
     * The State of the association.
     */
    readonly state: string;
    readonly tags: {
        [key: string]: string;
    };
}
