import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Use this data source to get IDs of Amazon VPC peering connections
 * To get more details on each connection, use the data resource `aws.ec2.VpcPeeringConnection`
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const pcs = aws.ec2.getVpcPeeringConnections({
 *     filters: [{
 *         name: "requester-vpc-info.vpc-id",
 *         values: [aws_vpc.foo.id],
 *     }],
 * });
 * const pc = .map(__index => aws.ec2.getVpcPeeringConnection({
 *     id: _arg0_.ids[__index],
 * }));
 * ```
 */
export declare function getVpcPeeringConnections(args?: GetVpcPeeringConnectionsArgs, opts?: pulumi.InvokeOptions): Promise<GetVpcPeeringConnectionsResult>;
/**
 * A collection of arguments for invoking getVpcPeeringConnections.
 */
export interface GetVpcPeeringConnectionsArgs {
    /**
     * Custom filter block as described below.
     */
    readonly filters?: inputs.ec2.GetVpcPeeringConnectionsFilter[];
    /**
     * A mapping of tags, each pair of which must exactly match
     * a pair on the desired VPC Peering Connection.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getVpcPeeringConnections.
 */
export interface GetVpcPeeringConnectionsResult {
    readonly filters?: outputs.ec2.GetVpcPeeringConnectionsFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The IDs of the VPC Peering Connections.
     */
    readonly ids: string[];
    readonly tags: {
        [key: string]: string;
    };
}
