import * as pulumi from "@pulumi/pulumi";
/**
 * Manages an EC2 Local Gateway Route Table VPC Association. More information can be found in the [Outposts User Guide](https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html#vpc-associations).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleLocalGatewayRouteTable = aws.ec2.getLocalGatewayRouteTable({
 *     outpostArn: "arn:aws:outposts:us-west-2:123456789012:outpost/op-1234567890abcdef",
 * });
 * const exampleVpc = new aws.ec2.Vpc("exampleVpc", {cidrBlock: "10.0.0.0/16"});
 * const exampleLocalGatewayRouteTableVpcAssociation = new aws.ec2.LocalGatewayRouteTableVpcAssociation("exampleLocalGatewayRouteTableVpcAssociation", {
 *     localGatewayRouteTableId: exampleLocalGatewayRouteTable.then(exampleLocalGatewayRouteTable => exampleLocalGatewayRouteTable.id),
 *     vpcId: exampleVpc.id,
 * });
 * ```
 *
 * ## Import
 *
 * `aws_ec2_local_gateway_route_table_vpc_association` can be imported by using the Local Gateway Route Table VPC Association identifier, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/localGatewayRouteTableVpcAssociation:LocalGatewayRouteTableVpcAssociation example lgw-vpc-assoc-1234567890abcdef
 * ```
 */
export declare class LocalGatewayRouteTableVpcAssociation extends pulumi.CustomResource {
    /**
     * Get an existing LocalGatewayRouteTableVpcAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LocalGatewayRouteTableVpcAssociationState, opts?: pulumi.CustomResourceOptions): LocalGatewayRouteTableVpcAssociation;
    /**
     * Returns true if the given object is an instance of LocalGatewayRouteTableVpcAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocalGatewayRouteTableVpcAssociation;
    readonly localGatewayId: pulumi.Output<string>;
    /**
     * Identifier of EC2 Local Gateway Route Table.
     */
    readonly localGatewayRouteTableId: pulumi.Output<string>;
    /**
     * Key-value map of resource tags.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Identifier of EC2 VPC.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a LocalGatewayRouteTableVpcAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocalGatewayRouteTableVpcAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LocalGatewayRouteTableVpcAssociation resources.
 */
export interface LocalGatewayRouteTableVpcAssociationState {
    readonly localGatewayId?: pulumi.Input<string>;
    /**
     * Identifier of EC2 Local Gateway Route Table.
     */
    readonly localGatewayRouteTableId?: pulumi.Input<string>;
    /**
     * Key-value map of resource tags.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Identifier of EC2 VPC.
     */
    readonly vpcId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a LocalGatewayRouteTableVpcAssociation resource.
 */
export interface LocalGatewayRouteTableVpcAssociationArgs {
    /**
     * Identifier of EC2 Local Gateway Route Table.
     */
    readonly localGatewayRouteTableId: pulumi.Input<string>;
    /**
     * Key-value map of resource tags.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Identifier of EC2 VPC.
     */
    readonly vpcId: pulumi.Input<string>;
}
