import * as pulumi from "@pulumi/pulumi";
/**
 * Attach an Elastic network interface (ENI) resource with EC2 instance.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = new aws.ec2.NetworkInterfaceAttachment("test", {
 *     instanceId: aws_instance.test.id,
 *     networkInterfaceId: aws_network_interface.test.id,
 *     deviceIndex: 0,
 * });
 * ```
 */
export declare class NetworkInterfaceAttachment extends pulumi.CustomResource {
    /**
     * Get an existing NetworkInterfaceAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: NetworkInterfaceAttachmentState, opts?: pulumi.CustomResourceOptions): NetworkInterfaceAttachment;
    /**
     * Returns true if the given object is an instance of NetworkInterfaceAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NetworkInterfaceAttachment;
    /**
     * The ENI Attachment ID.
     */
    readonly attachmentId: pulumi.Output<string>;
    /**
     * Network interface index (int).
     */
    readonly deviceIndex: pulumi.Output<number>;
    /**
     * Instance ID to attach.
     */
    readonly instanceId: pulumi.Output<string>;
    /**
     * ENI ID to attach.
     */
    readonly networkInterfaceId: pulumi.Output<string>;
    /**
     * The status of the Network Interface Attachment.
     */
    readonly status: pulumi.Output<string>;
    /**
     * Create a NetworkInterfaceAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: NetworkInterfaceAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering NetworkInterfaceAttachment resources.
 */
export interface NetworkInterfaceAttachmentState {
    /**
     * The ENI Attachment ID.
     */
    readonly attachmentId?: pulumi.Input<string>;
    /**
     * Network interface index (int).
     */
    readonly deviceIndex?: pulumi.Input<number>;
    /**
     * Instance ID to attach.
     */
    readonly instanceId?: pulumi.Input<string>;
    /**
     * ENI ID to attach.
     */
    readonly networkInterfaceId?: pulumi.Input<string>;
    /**
     * The status of the Network Interface Attachment.
     */
    readonly status?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a NetworkInterfaceAttachment resource.
 */
export interface NetworkInterfaceAttachmentArgs {
    /**
     * Network interface index (int).
     */
    readonly deviceIndex: pulumi.Input<number>;
    /**
     * Instance ID to attach.
     */
    readonly instanceId: pulumi.Input<string>;
    /**
     * ENI ID to attach.
     */
    readonly networkInterfaceId: pulumi.Input<string>;
}
