import * as pulumi from "@pulumi/pulumi";
/**
 * > **Note:** There is only a single subscription allowed per account.
 *
 * To help you understand the charges for your Spot instances, Amazon EC2 provides a data feed that describes your Spot instance usage and pricing.
 * This data feed is sent to an Amazon S3 bucket that you specify when you subscribe to the data feed.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const defaultBucket = new aws.s3.Bucket("defaultBucket", {});
 * const defaultSpotDatafeedSubscription = new aws.ec2.SpotDatafeedSubscription("defaultSpotDatafeedSubscription", {
 *     bucket: defaultBucket.bucket,
 *     prefix: "my_subdirectory",
 * });
 * ```
 *
 * ## Import
 *
 * A Spot Datafeed Subscription can be imported using the word `spot-datafeed-subscription`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/spotDatafeedSubscription:SpotDatafeedSubscription mysubscription spot-datafeed-subscription
 * ```
 */
export declare class SpotDatafeedSubscription extends pulumi.CustomResource {
    /**
     * Get an existing SpotDatafeedSubscription resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SpotDatafeedSubscriptionState, opts?: pulumi.CustomResourceOptions): SpotDatafeedSubscription;
    /**
     * Returns true if the given object is an instance of SpotDatafeedSubscription.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SpotDatafeedSubscription;
    /**
     * The Amazon S3 bucket in which to store the Spot instance data feed.
     */
    readonly bucket: pulumi.Output<string>;
    /**
     * Path of folder inside bucket to place spot pricing data.
     */
    readonly prefix: pulumi.Output<string | undefined>;
    /**
     * Create a SpotDatafeedSubscription resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SpotDatafeedSubscriptionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SpotDatafeedSubscription resources.
 */
export interface SpotDatafeedSubscriptionState {
    /**
     * The Amazon S3 bucket in which to store the Spot instance data feed.
     */
    readonly bucket?: pulumi.Input<string>;
    /**
     * Path of folder inside bucket to place spot pricing data.
     */
    readonly prefix?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a SpotDatafeedSubscription resource.
 */
export interface SpotDatafeedSubscriptionArgs {
    /**
     * The Amazon S3 bucket in which to store the Spot instance data feed.
     */
    readonly bucket: pulumi.Input<string>;
    /**
     * Path of folder inside bucket to place spot pricing data.
     */
    readonly prefix?: pulumi.Input<string>;
}
