import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an Traffic mirror filter.\
 * Read [limits and considerations](https://docs.aws.amazon.com/vpc/latest/mirroring/traffic-mirroring-considerations.html) for traffic mirroring
 *
 * ## Example Usage
 *
 * To create a basic traffic mirror filter
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const foo = new aws.ec2.TrafficMirrorFilter("foo", {
 *     description: "traffic mirror filter - example",
 *     networkServices: ["amazon-dns"],
 * });
 * ```
 *
 * ## Import
 *
 * Traffic mirror filter can be imported using the `id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/trafficMirrorFilter:TrafficMirrorFilter foo tmf-0fbb93ddf38198f64
 * ```
 */
export declare class TrafficMirrorFilter extends pulumi.CustomResource {
    /**
     * Get an existing TrafficMirrorFilter resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: TrafficMirrorFilterState, opts?: pulumi.CustomResourceOptions): TrafficMirrorFilter;
    /**
     * Returns true if the given object is an instance of TrafficMirrorFilter.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TrafficMirrorFilter;
    /**
     * The ARN of the traffic mirror filter.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A description of the filter.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * List of amazon network services that should be mirrored. Valid values: `amazon-dns`.
     */
    readonly networkServices: pulumi.Output<string[] | undefined>;
    /**
     * Key-value map of resource tags.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a TrafficMirrorFilter resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TrafficMirrorFilterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering TrafficMirrorFilter resources.
 */
export interface TrafficMirrorFilterState {
    /**
     * The ARN of the traffic mirror filter.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * A description of the filter.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * List of amazon network services that should be mirrored. Valid values: `amazon-dns`.
     */
    readonly networkServices?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Key-value map of resource tags.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a TrafficMirrorFilter resource.
 */
export interface TrafficMirrorFilterArgs {
    /**
     * A description of the filter.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * List of amazon network services that should be mirrored. Valid values: `amazon-dns`.
     */
    readonly networkServices?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Key-value map of resource tags.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
