import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a VPC DHCP Options Association resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const dnsResolver = new aws.ec2.VpcDhcpOptionsAssociation("dnsResolver", {
 *     vpcId: aws_vpc.foo.id,
 *     dhcpOptionsId: aws_vpc_dhcp_options.foo.id,
 * });
 * ```
 * ## Remarks
 *
 * * You can only associate one DHCP Options Set to a given VPC ID.
 * * Removing the DHCP Options Association automatically sets AWS's `default` DHCP Options Set to the VPC.
 *
 * ## Import
 *
 * DHCP associations can be imported by providing the VPC ID associated with the options
 *
 * ```sh
 *  $ pulumi import aws:ec2/vpcDhcpOptionsAssociation:VpcDhcpOptionsAssociation imported vpc-0f001273ec18911b1
 * ```
 */
export declare class VpcDhcpOptionsAssociation extends pulumi.CustomResource {
    /**
     * Get an existing VpcDhcpOptionsAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: VpcDhcpOptionsAssociationState, opts?: pulumi.CustomResourceOptions): VpcDhcpOptionsAssociation;
    /**
     * Returns true if the given object is an instance of VpcDhcpOptionsAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcDhcpOptionsAssociation;
    /**
     * The ID of the DHCP Options Set to associate to the VPC.
     */
    readonly dhcpOptionsId: pulumi.Output<string>;
    /**
     * The ID of the VPC to which we would like to associate a DHCP Options Set.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a VpcDhcpOptionsAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcDhcpOptionsAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering VpcDhcpOptionsAssociation resources.
 */
export interface VpcDhcpOptionsAssociationState {
    /**
     * The ID of the DHCP Options Set to associate to the VPC.
     */
    readonly dhcpOptionsId?: pulumi.Input<string>;
    /**
     * The ID of the VPC to which we would like to associate a DHCP Options Set.
     */
    readonly vpcId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a VpcDhcpOptionsAssociation resource.
 */
export interface VpcDhcpOptionsAssociationArgs {
    /**
     * The ID of the DHCP Options Set to associate to the VPC.
     */
    readonly dhcpOptionsId: pulumi.Input<string>;
    /**
     * The ID of the VPC to which we would like to associate a DHCP Options Set.
     */
    readonly vpcId: pulumi.Input<string>;
}
