import * as pulumi from "@pulumi/pulumi";
/**
 * Manages a VPC Endpoint Route Table Association
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ec2.VpcEndpointRouteTableAssociation("example", {
 *     routeTableId: aws_route_table.example.id,
 *     vpcEndpointId: aws_vpc_endpoint.example.id,
 * });
 * ```
 *
 * ## Import
 *
 * VPC Endpoint Route Table Associations can be imported using `vpc_endpoint_id` together with `route_table_id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2/vpcEndpointRouteTableAssociation:VpcEndpointRouteTableAssociation example vpce-aaaaaaaa/rtb-bbbbbbbb
 * ```
 */
export declare class VpcEndpointRouteTableAssociation extends pulumi.CustomResource {
    /**
     * Get an existing VpcEndpointRouteTableAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: VpcEndpointRouteTableAssociationState, opts?: pulumi.CustomResourceOptions): VpcEndpointRouteTableAssociation;
    /**
     * Returns true if the given object is an instance of VpcEndpointRouteTableAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcEndpointRouteTableAssociation;
    /**
     * Identifier of the EC2 Route Table to be associated with the VPC Endpoint.
     */
    readonly routeTableId: pulumi.Output<string>;
    /**
     * Identifier of the VPC Endpoint with which the EC2 Route Table will be associated.
     */
    readonly vpcEndpointId: pulumi.Output<string>;
    /**
     * Create a VpcEndpointRouteTableAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcEndpointRouteTableAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering VpcEndpointRouteTableAssociation resources.
 */
export interface VpcEndpointRouteTableAssociationState {
    /**
     * Identifier of the EC2 Route Table to be associated with the VPC Endpoint.
     */
    readonly routeTableId?: pulumi.Input<string>;
    /**
     * Identifier of the VPC Endpoint with which the EC2 Route Table will be associated.
     */
    readonly vpcEndpointId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a VpcEndpointRouteTableAssociation resource.
 */
export interface VpcEndpointRouteTableAssociationArgs {
    /**
     * Identifier of the EC2 Route Table to be associated with the VPC Endpoint.
     */
    readonly routeTableId: pulumi.Input<string>;
    /**
     * Identifier of the VPC Endpoint with which the EC2 Route Table will be associated.
     */
    readonly vpcEndpointId: pulumi.Input<string>;
}
