import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a resource to allow a principal to discover a VPC endpoint service.
 *
 * > **NOTE on VPC Endpoint Services and VPC Endpoint Service Allowed Principals:** This provider provides
 * both a standalone VPC Endpoint Service Allowed Principal resource
 * and a VPC Endpoint Service resource with an `allowedPrincipals` attribute. Do not use the same principal ARN in both
 * a VPC Endpoint Service resource and a VPC Endpoint Service Allowed Principal resource. Doing so will cause a conflict
 * and will overwrite the association.
 *
 * ## Example Usage
 *
 * Basic usage:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const current = aws.getCallerIdentity({});
 * const allowMeToFoo = new aws.ec2.VpcEndpointServiceAllowedPrinciple("allowMeToFoo", {
 *     vpcEndpointServiceId: aws_vpc_endpoint_service.foo.id,
 *     principalArn: current.then(current => current.arn),
 * });
 * ```
 */
export declare class VpcEndpointServiceAllowedPrinciple extends pulumi.CustomResource {
    /**
     * Get an existing VpcEndpointServiceAllowedPrinciple resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: VpcEndpointServiceAllowedPrincipleState, opts?: pulumi.CustomResourceOptions): VpcEndpointServiceAllowedPrinciple;
    /**
     * Returns true if the given object is an instance of VpcEndpointServiceAllowedPrinciple.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcEndpointServiceAllowedPrinciple;
    /**
     * The ARN of the principal to allow permissions.
     */
    readonly principalArn: pulumi.Output<string>;
    /**
     * The ID of the VPC endpoint service to allow permission.
     */
    readonly vpcEndpointServiceId: pulumi.Output<string>;
    /**
     * Create a VpcEndpointServiceAllowedPrinciple resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcEndpointServiceAllowedPrincipleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering VpcEndpointServiceAllowedPrinciple resources.
 */
export interface VpcEndpointServiceAllowedPrincipleState {
    /**
     * The ARN of the principal to allow permissions.
     */
    readonly principalArn?: pulumi.Input<string>;
    /**
     * The ID of the VPC endpoint service to allow permission.
     */
    readonly vpcEndpointServiceId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a VpcEndpointServiceAllowedPrinciple resource.
 */
export interface VpcEndpointServiceAllowedPrincipleArgs {
    /**
     * The ARN of the principal to allow permissions.
     */
    readonly principalArn: pulumi.Input<string>;
    /**
     * The ID of the VPC endpoint service to allow permission.
     */
    readonly vpcEndpointServiceId: pulumi.Input<string>;
}
