import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Get information on an EC2 Transit Gateway's attachment to a Direct Connect Gateway.
 *
 * ## Example Usage
 * ### By Transit Gateway and Direct Connect Gateway Identifiers
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = aws.ec2transitgateway.getDirectConnectGatewayAttachment({
 *     transitGatewayId: aws_ec2_transit_gateway.example.id,
 *     dxGatewayId: aws_dx_gateway.example.id,
 * });
 * ```
 */
export declare function getDirectConnectGatewayAttachment(args?: GetDirectConnectGatewayAttachmentArgs, opts?: pulumi.InvokeOptions): Promise<GetDirectConnectGatewayAttachmentResult>;
/**
 * A collection of arguments for invoking getDirectConnectGatewayAttachment.
 */
export interface GetDirectConnectGatewayAttachmentArgs {
    /**
     * Identifier of the Direct Connect Gateway.
     */
    readonly dxGatewayId?: string;
    /**
     * Configuration block(s) for filtering. Detailed below.
     */
    readonly filters?: inputs.ec2transitgateway.GetDirectConnectGatewayAttachmentFilter[];
    /**
     * A map of tags, each pair of which must exactly match a pair on the desired Transit Gateway Direct Connect Gateway Attachment.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Identifier of the EC2 Transit Gateway.
     */
    readonly transitGatewayId?: string;
}
/**
 * A collection of values returned by getDirectConnectGatewayAttachment.
 */
export interface GetDirectConnectGatewayAttachmentResult {
    readonly dxGatewayId?: string;
    readonly filters?: outputs.ec2transitgateway.GetDirectConnectGatewayAttachmentFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Key-value tags for the EC2 Transit Gateway Attachment
     */
    readonly tags: {
        [key: string]: string;
    };
    readonly transitGatewayId?: string;
}
