import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Get information on an EC2 Transit Gateway Peering Attachment.
 *
 * ## Example Usage
 * ### By Filter
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.ec2transitgateway.getPeeringAttachment({
 *     filters: [{
 *         name: "transit-gateway-attachment-id",
 *         values: ["tgw-attach-12345678"],
 *     }],
 * }, { async: true }));
 * ```
 * ### By Identifier
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const attachment = pulumi.output(aws.ec2transitgateway.getPeeringAttachment({
 *     id: "tgw-attach-12345678",
 * }, { async: true }));
 * ```
 */
export declare function getPeeringAttachment(args?: GetPeeringAttachmentArgs, opts?: pulumi.InvokeOptions): Promise<GetPeeringAttachmentResult>;
/**
 * A collection of arguments for invoking getPeeringAttachment.
 */
export interface GetPeeringAttachmentArgs {
    /**
     * One or more configuration blocks containing name-values filters. Detailed below.
     */
    readonly filters?: inputs.ec2transitgateway.GetPeeringAttachmentFilter[];
    /**
     * Identifier of the EC2 Transit Gateway Peering Attachment.
     */
    readonly id?: string;
    /**
     * A mapping of tags, each pair of which must exactly match
     * a pair on the specific EC2 Transit Gateway Peering Attachment to retrieve.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getPeeringAttachment.
 */
export interface GetPeeringAttachmentResult {
    readonly filters?: outputs.ec2transitgateway.GetPeeringAttachmentFilter[];
    readonly id: string;
    /**
     * Identifier of the peer AWS account
     */
    readonly peerAccountId: string;
    /**
     * Identifier of the peer AWS region
     */
    readonly peerRegion: string;
    /**
     * Identifier of the peer EC2 Transit Gateway
     */
    readonly peerTransitGatewayId: string;
    readonly tags: {
        [key: string]: string;
    };
    /**
     * Identifier of the local EC2 Transit Gateway
     */
    readonly transitGatewayId: string;
}
