import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Get information on an EC2 Transit Gateway VPC Attachment.
 *
 * ## Example Usage
 * ### By Filter
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.ec2transitgateway.getVpcAttachment({
 *     filters: [{
 *         name: "vpc-id",
 *         values: ["vpc-12345678"],
 *     }],
 * }, { async: true }));
 * ```
 * ### By Identifier
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.ec2transitgateway.getVpcAttachment({
 *     id: "tgw-attach-12345678",
 * }, { async: true }));
 * ```
 */
export declare function getVpcAttachment(args?: GetVpcAttachmentArgs, opts?: pulumi.InvokeOptions): Promise<GetVpcAttachmentResult>;
/**
 * A collection of arguments for invoking getVpcAttachment.
 */
export interface GetVpcAttachmentArgs {
    /**
     * One or more configuration blocks containing name-values filters. Detailed below.
     */
    readonly filters?: inputs.ec2transitgateway.GetVpcAttachmentFilter[];
    /**
     * Identifier of the EC2 Transit Gateway VPC Attachment.
     */
    readonly id?: string;
    /**
     * Key-value tags for the EC2 Transit Gateway VPC Attachment
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getVpcAttachment.
 */
export interface GetVpcAttachmentResult {
    /**
     * Whether Appliance Mode support is enabled.
     */
    readonly applianceModeSupport: string;
    /**
     * Whether DNS support is enabled.
     */
    readonly dnsSupport: string;
    readonly filters?: outputs.ec2transitgateway.GetVpcAttachmentFilter[];
    /**
     * EC2 Transit Gateway VPC Attachment identifier
     */
    readonly id: string;
    /**
     * Whether IPv6 support is enabled.
     */
    readonly ipv6Support: string;
    /**
     * Identifiers of EC2 Subnets.
     */
    readonly subnetIds: string[];
    /**
     * Key-value tags for the EC2 Transit Gateway VPC Attachment
     */
    readonly tags: {
        [key: string]: string;
    };
    /**
     * EC2 Transit Gateway identifier
     */
    readonly transitGatewayId: string;
    /**
     * Identifier of EC2 VPC.
     */
    readonly vpcId: string;
    /**
     * Identifier of the AWS account that owns the EC2 VPC.
     */
    readonly vpcOwnerId: string;
}
