import * as pulumi from "@pulumi/pulumi";
/**
 * Manages an EC2 Transit Gateway Route Table.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ec2transitgateway.RouteTable("example", {transitGatewayId: aws_ec2_transit_gateway.example.id});
 * ```
 *
 * ## Import
 *
 * `aws_ec2_transit_gateway_route_table` can be imported by using the EC2 Transit Gateway Route Table identifier, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2transitgateway/routeTable:RouteTable example tgw-rtb-12345678
 * ```
 */
export declare class RouteTable extends pulumi.CustomResource {
    /**
     * Get an existing RouteTable resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RouteTableState, opts?: pulumi.CustomResourceOptions): RouteTable;
    /**
     * Returns true if the given object is an instance of RouteTable.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RouteTable;
    /**
     * EC2 Transit Gateway Route Table Amazon Resource Name (ARN).
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Boolean whether this is the default association route table for the EC2 Transit Gateway.
     */
    readonly defaultAssociationRouteTable: pulumi.Output<boolean>;
    /**
     * Boolean whether this is the default propagation route table for the EC2 Transit Gateway.
     */
    readonly defaultPropagationRouteTable: pulumi.Output<boolean>;
    /**
     * Key-value tags for the EC2 Transit Gateway Route Table.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Identifier of EC2 Transit Gateway.
     */
    readonly transitGatewayId: pulumi.Output<string>;
    /**
     * Create a RouteTable resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RouteTableArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RouteTable resources.
 */
export interface RouteTableState {
    /**
     * EC2 Transit Gateway Route Table Amazon Resource Name (ARN).
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Boolean whether this is the default association route table for the EC2 Transit Gateway.
     */
    readonly defaultAssociationRouteTable?: pulumi.Input<boolean>;
    /**
     * Boolean whether this is the default propagation route table for the EC2 Transit Gateway.
     */
    readonly defaultPropagationRouteTable?: pulumi.Input<boolean>;
    /**
     * Key-value tags for the EC2 Transit Gateway Route Table.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Identifier of EC2 Transit Gateway.
     */
    readonly transitGatewayId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a RouteTable resource.
 */
export interface RouteTableArgs {
    /**
     * Key-value tags for the EC2 Transit Gateway Route Table.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Identifier of EC2 Transit Gateway.
     */
    readonly transitGatewayId: pulumi.Input<string>;
}
