import * as pulumi from "@pulumi/pulumi";
import { ARN } from "..";
/**
 * Manages an EC2 Transit Gateway.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ec2transitgateway.TransitGateway("example", {
 *     description: "example",
 * });
 * ```
 *
 * ## Import
 *
 * `aws_ec2_transit_gateway` can be imported by using the EC2 Transit Gateway identifier, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ec2transitgateway/transitGateway:TransitGateway example tgw-12345678
 * ```
 */
export declare class TransitGateway extends pulumi.CustomResource {
    /**
     * Get an existing TransitGateway resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: TransitGatewayState, opts?: pulumi.CustomResourceOptions): TransitGateway;
    /**
     * Returns true if the given object is an instance of TransitGateway.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TransitGateway;
    /**
     * Private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is `64512` to `65534` for 16-bit ASNs and `4200000000` to `4294967294` for 32-bit ASNs. Default value: `64512`.
     */
    readonly amazonSideAsn: pulumi.Output<number | undefined>;
    /**
     * EC2 Transit Gateway Amazon Resource Name (ARN)
     */
    readonly arn: pulumi.Output<ARN>;
    /**
     * Identifier of the default association route table
     */
    readonly associationDefaultRouteTableId: pulumi.Output<string>;
    /**
     * Whether resource attachment requests are automatically accepted. Valid values: `disable`, `enable`. Default value: `disable`.
     */
    readonly autoAcceptSharedAttachments: pulumi.Output<string | undefined>;
    /**
     * Whether resource attachments are automatically associated with the default association route table. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly defaultRouteTableAssociation: pulumi.Output<string | undefined>;
    /**
     * Whether resource attachments automatically propagate routes to the default propagation route table. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly defaultRouteTablePropagation: pulumi.Output<string | undefined>;
    /**
     * Description of the EC2 Transit Gateway.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Whether DNS support is enabled. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly dnsSupport: pulumi.Output<string | undefined>;
    /**
     * Identifier of the AWS account that owns the EC2 Transit Gateway
     */
    readonly ownerId: pulumi.Output<string>;
    /**
     * Identifier of the default propagation route table
     */
    readonly propagationDefaultRouteTableId: pulumi.Output<string>;
    /**
     * Key-value tags for the EC2 Transit Gateway.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Whether VPN Equal Cost Multipath Protocol support is enabled. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly vpnEcmpSupport: pulumi.Output<string | undefined>;
    /**
     * Create a TransitGateway resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TransitGatewayArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering TransitGateway resources.
 */
export interface TransitGatewayState {
    /**
     * Private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is `64512` to `65534` for 16-bit ASNs and `4200000000` to `4294967294` for 32-bit ASNs. Default value: `64512`.
     */
    readonly amazonSideAsn?: pulumi.Input<number>;
    /**
     * EC2 Transit Gateway Amazon Resource Name (ARN)
     */
    readonly arn?: pulumi.Input<ARN>;
    /**
     * Identifier of the default association route table
     */
    readonly associationDefaultRouteTableId?: pulumi.Input<string>;
    /**
     * Whether resource attachment requests are automatically accepted. Valid values: `disable`, `enable`. Default value: `disable`.
     */
    readonly autoAcceptSharedAttachments?: pulumi.Input<string>;
    /**
     * Whether resource attachments are automatically associated with the default association route table. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly defaultRouteTableAssociation?: pulumi.Input<string>;
    /**
     * Whether resource attachments automatically propagate routes to the default propagation route table. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly defaultRouteTablePropagation?: pulumi.Input<string>;
    /**
     * Description of the EC2 Transit Gateway.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Whether DNS support is enabled. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly dnsSupport?: pulumi.Input<string>;
    /**
     * Identifier of the AWS account that owns the EC2 Transit Gateway
     */
    readonly ownerId?: pulumi.Input<string>;
    /**
     * Identifier of the default propagation route table
     */
    readonly propagationDefaultRouteTableId?: pulumi.Input<string>;
    /**
     * Key-value tags for the EC2 Transit Gateway.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Whether VPN Equal Cost Multipath Protocol support is enabled. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly vpnEcmpSupport?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a TransitGateway resource.
 */
export interface TransitGatewayArgs {
    /**
     * Private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is `64512` to `65534` for 16-bit ASNs and `4200000000` to `4294967294` for 32-bit ASNs. Default value: `64512`.
     */
    readonly amazonSideAsn?: pulumi.Input<number>;
    /**
     * Whether resource attachment requests are automatically accepted. Valid values: `disable`, `enable`. Default value: `disable`.
     */
    readonly autoAcceptSharedAttachments?: pulumi.Input<string>;
    /**
     * Whether resource attachments are automatically associated with the default association route table. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly defaultRouteTableAssociation?: pulumi.Input<string>;
    /**
     * Whether resource attachments automatically propagate routes to the default propagation route table. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly defaultRouteTablePropagation?: pulumi.Input<string>;
    /**
     * Description of the EC2 Transit Gateway.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * Whether DNS support is enabled. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly dnsSupport?: pulumi.Input<string>;
    /**
     * Key-value tags for the EC2 Transit Gateway.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Whether VPN Equal Cost Multipath Protocol support is enabled. Valid values: `disable`, `enable`. Default value: `enable`.
     */
    readonly vpnEcmpSupport?: pulumi.Input<string>;
}
