import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a Public Elastic Container Registry Repository.
 *
 * ## Import
 *
 * ECR Public Repositories can be imported using the `repository_name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ecrpublic/repository:Repository example example
 * ```
 */
export declare class Repository extends pulumi.CustomResource {
    /**
     * Get an existing Repository resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RepositoryState, opts?: pulumi.CustomResourceOptions): Repository;
    /**
     * Returns true if the given object is an instance of Repository.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Repository;
    /**
     * Full ARN of the repository.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Catalog data configuration for the repository. See below for schema.
     */
    readonly catalogData: pulumi.Output<outputs.ecrpublic.RepositoryCatalogData | undefined>;
    readonly forceDestroy: pulumi.Output<boolean | undefined>;
    /**
     * The registry ID where the repository was created.
     */
    readonly registryId: pulumi.Output<string>;
    /**
     * Name of the repository.
     */
    readonly repositoryName: pulumi.Output<string>;
    readonly repositoryUri: pulumi.Output<string>;
    /**
     * Create a Repository resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RepositoryArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Repository resources.
 */
export interface RepositoryState {
    /**
     * Full ARN of the repository.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Catalog data configuration for the repository. See below for schema.
     */
    readonly catalogData?: pulumi.Input<inputs.ecrpublic.RepositoryCatalogData>;
    readonly forceDestroy?: pulumi.Input<boolean>;
    /**
     * The registry ID where the repository was created.
     */
    readonly registryId?: pulumi.Input<string>;
    /**
     * Name of the repository.
     */
    readonly repositoryName?: pulumi.Input<string>;
    readonly repositoryUri?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Repository resource.
 */
export interface RepositoryArgs {
    /**
     * Catalog data configuration for the repository. See below for schema.
     */
    readonly catalogData?: pulumi.Input<inputs.ecrpublic.RepositoryCatalogData>;
    readonly forceDestroy?: pulumi.Input<boolean>;
    /**
     * Name of the repository.
     */
    readonly repositoryName: pulumi.Input<string>;
}
