import * as pulumi from "@pulumi/pulumi";
/**
 * The ECS task definition data source allows access to details of
 * a specific AWS ECS task definition.
 */
export declare function getTaskDefinition(args: GetTaskDefinitionArgs, opts?: pulumi.InvokeOptions): Promise<GetTaskDefinitionResult>;
/**
 * A collection of arguments for invoking getTaskDefinition.
 */
export interface GetTaskDefinitionArgs {
    /**
     * The family for the latest ACTIVE revision, family and revision (family:revision) for a specific revision in the family, the ARN of the task definition to access to.
     */
    readonly taskDefinition: string;
}
/**
 * A collection of values returned by getTaskDefinition.
 */
export interface GetTaskDefinitionResult {
    /**
     * The family of this task definition
     */
    readonly family: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The Docker networking mode to use for the containers in this task.
     */
    readonly networkMode: string;
    /**
     * The revision of this task definition
     */
    readonly revision: number;
    /**
     * The status of this task definition
     */
    readonly status: string;
    readonly taskDefinition: string;
    /**
     * The ARN of the IAM role that containers in this task can assume
     */
    readonly taskRoleArn: string;
}
