import * as pulumi from "@pulumi/pulumi";
/**
 * Provides information about multiple Elastic File System (EFS) Access Points.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = pulumi.output(aws.efs.getAccessPoints({
 *     fileSystemId: "fs-12345678",
 * }, { async: true }));
 * ```
 */
export declare function getAccessPoints(args: GetAccessPointsArgs, opts?: pulumi.InvokeOptions): Promise<GetAccessPointsResult>;
/**
 * A collection of arguments for invoking getAccessPoints.
 */
export interface GetAccessPointsArgs {
    /**
     * EFS File System identifier.
     */
    readonly fileSystemId: string;
}
/**
 * A collection of values returned by getAccessPoints.
 */
export interface GetAccessPointsResult {
    /**
     * Set of Amazon Resource Names (ARNs).
     */
    readonly arns: string[];
    readonly fileSystemId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Set of identifiers.
     */
    readonly ids: string[];
}
