import * as pulumi from "@pulumi/pulumi";
/**
 * Get an authentication token to communicate with an EKS cluster.
 *
 * Uses IAM credentials from the AWS provider to generate a temporary token that is compatible with
 * [AWS IAM Authenticator](https://github.com/kubernetes-sigs/aws-iam-authenticator) authentication.
 * This can be used to authenticate to an EKS cluster or to a cluster that has the AWS IAM Authenticator
 * server configured.
 */
export declare function getClusterAuth(args: GetClusterAuthArgs, opts?: pulumi.InvokeOptions): Promise<GetClusterAuthResult>;
/**
 * A collection of arguments for invoking getClusterAuth.
 */
export interface GetClusterAuthArgs {
    /**
     * The name of the cluster
     */
    readonly name: string;
}
/**
 * A collection of values returned by getClusterAuth.
 */
export interface GetClusterAuthResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
    /**
     * The token to use to authenticate with the cluster.
     */
    readonly token: string;
}
