import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Retrieve information about an Elastic Beanstalk Application.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = aws.elasticbeanstalk.getApplication({
 *     name: "example",
 * });
 * export const arn = example.then(example => example.arn);
 * export const description = example.then(example => example.description);
 * ```
 */
export declare function getApplication(args: GetApplicationArgs, opts?: pulumi.InvokeOptions): Promise<GetApplicationResult>;
/**
 * A collection of arguments for invoking getApplication.
 */
export interface GetApplicationArgs {
    /**
     * The name of the application
     */
    readonly name: string;
}
/**
 * A collection of values returned by getApplication.
 */
export interface GetApplicationResult {
    readonly appversionLifecycle: outputs.elasticbeanstalk.GetApplicationAppversionLifecycle;
    /**
     * The Amazon Resource Name (ARN) of the application.
     */
    readonly arn: string;
    /**
     * Short description of the application
     */
    readonly description: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
}
