import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides an Gamelift Build resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = new aws.gamelift.Build("test", {
 *     operatingSystem: "WINDOWS_2012",
 *     storageLocation: {
 *         bucket: aws_s3_bucket.test.bucket,
 *         key: aws_s3_bucket_object.test.key,
 *         roleArn: aws_iam_role.test.arn,
 *     },
 * }, {
 *     dependsOn: [aws_iam_role_policy.test],
 * });
 * ```
 *
 * ## Import
 *
 * Gamelift Builds cannot be imported at this time.
 */
export declare class Build extends pulumi.CustomResource {
    /**
     * Get an existing Build resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: BuildState, opts?: pulumi.CustomResourceOptions): Build;
    /**
     * Returns true if the given object is an instance of Build.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Build;
    /**
     * Gamelift Build ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Name of the build
     */
    readonly name: pulumi.Output<string>;
    /**
     * Operating system that the game server binaries are built to run on. e.g. `WINDOWS_2012`, `AMAZON_LINUX` or `AMAZON_LINUX_2`.
     */
    readonly operatingSystem: pulumi.Output<string>;
    /**
     * Information indicating where your game build files are stored. See below.
     */
    readonly storageLocation: pulumi.Output<outputs.gamelift.BuildStorageLocation>;
    /**
     * Key-value map of resource tags
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Version that is associated with this build.
     */
    readonly version: pulumi.Output<string | undefined>;
    /**
     * Create a Build resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BuildArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Build resources.
 */
export interface BuildState {
    /**
     * Gamelift Build ARN.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Name of the build
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Operating system that the game server binaries are built to run on. e.g. `WINDOWS_2012`, `AMAZON_LINUX` or `AMAZON_LINUX_2`.
     */
    readonly operatingSystem?: pulumi.Input<string>;
    /**
     * Information indicating where your game build files are stored. See below.
     */
    readonly storageLocation?: pulumi.Input<inputs.gamelift.BuildStorageLocation>;
    /**
     * Key-value map of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Version that is associated with this build.
     */
    readonly version?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Build resource.
 */
export interface BuildArgs {
    /**
     * Name of the build
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Operating system that the game server binaries are built to run on. e.g. `WINDOWS_2012`, `AMAZON_LINUX` or `AMAZON_LINUX_2`.
     */
    readonly operatingSystem: pulumi.Input<string>;
    /**
     * Information indicating where your game build files are stored. See below.
     */
    readonly storageLocation: pulumi.Input<inputs.gamelift.BuildStorageLocation>;
    /**
     * Key-value map of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Version that is associated with this build.
     */
    readonly version?: pulumi.Input<string>;
}
