import * as pulumi from "@pulumi/pulumi";
/**
 * Parses an Amazon Resource Name (ARN) into its constituent parts.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const dbInstance = pulumi.output(aws.getArn({
 *     arn: "arn:aws:rds:eu-west-1:123456789012:db:mysql-db",
 * }, { async: true }));
 * ```
 */
export declare function getArn(args: GetArnArgs, opts?: pulumi.InvokeOptions): Promise<GetArnResult>;
/**
 * A collection of arguments for invoking getArn.
 */
export interface GetArnArgs {
    /**
     * The ARN to parse.
     */
    readonly arn: string;
}
/**
 * A collection of values returned by getArn.
 */
export interface GetArnResult {
    /**
     * The [ID](https://docs.aws.amazon.com/general/latest/gr/acct-identifiers.html) of the AWS account that owns the resource, without the hyphens.
     */
    readonly account: string;
    readonly arn: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The partition that the resource is in.
     */
    readonly partition: string;
    /**
     * The region the resource resides in.
     * Note that the ARNs for some resources do not require a region, so this component might be omitted.
     */
    readonly region: string;
    /**
     * The content of this part of the ARN varies by service.
     * It often includes an indicator of the type of resource—for example, an IAM user or Amazon RDS database —followed by a slash (/) or a colon (:), followed by the resource name itself.
     */
    readonly resource: string;
    /**
     * The [service namespace](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#genref-aws-service-namespaces) that identifies the AWS product.
     */
    readonly service: string;
}
