import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Use this data source to generate a Glue script from a Directed Acyclic Graph (DAG).
 *
 * ## Example Usage
 */
export declare function getScript(args: GetScriptArgs, opts?: pulumi.InvokeOptions): Promise<GetScriptResult>;
/**
 * A collection of arguments for invoking getScript.
 */
export interface GetScriptArgs {
    /**
     * A list of the edges in the DAG. Defined below.
     */
    readonly dagEdges: inputs.glue.GetScriptDagEdge[];
    /**
     * A list of the nodes in the DAG. Defined below.
     */
    readonly dagNodes: inputs.glue.GetScriptDagNode[];
    /**
     * The programming language of the resulting code from the DAG. Defaults to `PYTHON`. Valid values are `PYTHON` and `SCALA`.
     */
    readonly language?: string;
}
/**
 * A collection of values returned by getScript.
 */
export interface GetScriptResult {
    readonly dagEdges: outputs.glue.GetScriptDagEdge[];
    readonly dagNodes: outputs.glue.GetScriptDagNode[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly language?: string;
    /**
     * The Python script generated from the DAG when the `language` argument is set to `PYTHON`.
     */
    readonly pythonScript: string;
    /**
     * The Scala code generated from the DAG when the `language` argument is set to `SCALA`.
     */
    readonly scalaCode: string;
}
