import * as pulumi from "@pulumi/pulumi";
/**
 * > **Note:** There is only a single account alias per AWS account.
 *
 * Manages the account alias for the AWS Account.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const alias = new aws.iam.AccountAlias("alias", {
 *     accountAlias: "my-account-alias",
 * });
 * ```
 *
 * ## Import
 *
 * The current Account Alias can be imported using the `account_alias`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:iam/accountAlias:AccountAlias alias my-account-alias
 * ```
 */
export declare class AccountAlias extends pulumi.CustomResource {
    /**
     * Get an existing AccountAlias resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AccountAliasState, opts?: pulumi.CustomResourceOptions): AccountAlias;
    /**
     * Returns true if the given object is an instance of AccountAlias.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccountAlias;
    /**
     * The account alias
     */
    readonly accountAlias: pulumi.Output<string>;
    /**
     * Create a AccountAlias resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AccountAliasArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AccountAlias resources.
 */
export interface AccountAliasState {
    /**
     * The account alias
     */
    readonly accountAlias?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AccountAlias resource.
 */
export interface AccountAliasArgs {
    /**
     * The account alias
     */
    readonly accountAlias: pulumi.Input<string>;
}
