import * as pulumi from "@pulumi/pulumi";
/**
 * The IAM Account Alias data source allows access to the account alias
 * for the effective account in which this provider is working.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const current = aws.iam.getAccountAlias({});
 * export const accountId = current.then(current => current.accountAlias);
 * ```
 */
export declare function getAccountAlias(opts?: pulumi.InvokeOptions): Promise<GetAccountAliasResult>;
/**
 * A collection of values returned by getAccountAlias.
 */
export interface GetAccountAliasResult {
    /**
     * The alias associated with the AWS account.
     */
    readonly accountAlias: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
}
