import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an IAM SAML provider.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * import * from "fs";
 *
 * const _default = new aws.iam.SamlProvider("default", {samlMetadataDocument: fs.readFileSync("saml-metadata.xml")});
 * ```
 *
 * ## Import
 *
 * IAM SAML Providers can be imported using the `arn`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:iam/samlProvider:SamlProvider default arn:aws:iam::123456789012:saml-provider/SAMLADFS
 * ```
 */
export declare class SamlProvider extends pulumi.CustomResource {
    /**
     * Get an existing SamlProvider resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SamlProviderState, opts?: pulumi.CustomResourceOptions): SamlProvider;
    /**
     * Returns true if the given object is an instance of SamlProvider.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SamlProvider;
    /**
     * The ARN assigned by AWS for this provider.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the provider to create.
     */
    readonly name: pulumi.Output<string>;
    /**
     * An XML document generated by an identity provider that supports SAML 2.0.
     */
    readonly samlMetadataDocument: pulumi.Output<string>;
    /**
     * The expiration date and time for the SAML provider in RFC1123 format, e.g. `Mon, 02 Jan 2006 15:04:05 MST`.
     */
    readonly validUntil: pulumi.Output<string>;
    /**
     * Create a SamlProvider resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SamlProviderArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SamlProvider resources.
 */
export interface SamlProviderState {
    /**
     * The ARN assigned by AWS for this provider.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The name of the provider to create.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * An XML document generated by an identity provider that supports SAML 2.0.
     */
    readonly samlMetadataDocument?: pulumi.Input<string>;
    /**
     * The expiration date and time for the SAML provider in RFC1123 format, e.g. `Mon, 02 Jan 2006 15:04:05 MST`.
     */
    readonly validUntil?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a SamlProvider resource.
 */
export interface SamlProviderArgs {
    /**
     * The name of the provider to create.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * An XML document generated by an identity provider that supports SAML 2.0.
     */
    readonly samlMetadataDocument: pulumi.Input<string>;
}
