import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Use this data source to get an Identity Store Group.
 */
export declare function getGroup(args: GetGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetGroupResult>;
/**
 * A collection of arguments for invoking getGroup.
 */
export interface GetGroupArgs {
    /**
     * Configuration block(s) for filtering. Currently, the AWS Identity Store API supports only 1 filter. Detailed below.
     */
    readonly filters: inputs.identitystore.GetGroupFilter[];
    /**
     * The identifier for a group in the Identity Store.
     */
    readonly groupId?: string;
    /**
     * The Identity Store ID associated with the Single Sign-On Instance.
     */
    readonly identityStoreId: string;
}
/**
 * A collection of values returned by getGroup.
 */
export interface GetGroupResult {
    /**
     * The group's display name value.
     */
    readonly displayName: string;
    readonly filters: outputs.identitystore.GetGroupFilter[];
    readonly groupId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly identityStoreId: string;
}
