import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Use this data source to get an Identity Store User.
 */
export declare function getUser(args: GetUserArgs, opts?: pulumi.InvokeOptions): Promise<GetUserResult>;
/**
 * A collection of arguments for invoking getUser.
 */
export interface GetUserArgs {
    /**
     * Configuration block(s) for filtering. Currently, the AWS Identity Store API supports only 1 filter. Detailed below.
     */
    readonly filters: inputs.identitystore.GetUserFilter[];
    /**
     * The Identity Store ID associated with the Single Sign-On Instance.
     */
    readonly identityStoreId: string;
    /**
     * The identifier for a user in the Identity Store.
     */
    readonly userId?: string;
}
/**
 * A collection of values returned by getUser.
 */
export interface GetUserResult {
    readonly filters: outputs.identitystore.GetUserFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly identityStoreId: string;
    readonly userId: string;
    /**
     * The user's user name value.
     */
    readonly userName: string;
}
