import * as pulumi from "@pulumi/pulumi";
/**
 * Provides details about an Image Builder Component.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.imagebuilder.getComponent({
 *     arn: "arn:aws:imagebuilder:us-west-2:aws:component/amazon-cloudwatch-agent-linux/1.0.0",
 * }, { async: true }));
 * ```
 */
export declare function getComponent(args: GetComponentArgs, opts?: pulumi.InvokeOptions): Promise<GetComponentResult>;
/**
 * A collection of arguments for invoking getComponent.
 */
export interface GetComponentArgs {
    /**
     * Amazon Resource Name (ARN) of the component.
     */
    readonly arn: string;
    /**
     * Key-value map of resource tags for the component.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getComponent.
 */
export interface GetComponentResult {
    readonly arn: string;
    /**
     * Change description of the component.
     */
    readonly changeDescription: string;
    /**
     * Data of the component.
     */
    readonly data: string;
    /**
     * Date the component was created.
     */
    readonly dateCreated: string;
    /**
     * Description of the component.
     */
    readonly description: string;
    /**
     * Encryption status of the component.
     */
    readonly encrypted: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Amazon Resource Name (ARN) of the Key Management Service (KMS) Key used to encrypt the component.
     */
    readonly kmsKeyId: string;
    /**
     * Name of the component.
     */
    readonly name: string;
    /**
     * Owner of the component.
     */
    readonly owner: string;
    /**
     * Platform of the component.
     */
    readonly platform: string;
    /**
     * Operating Systems (OSes) supported by the component.
     */
    readonly supportedOsVersions: string[];
    /**
     * Key-value map of resource tags for the component.
     */
    readonly tags: {
        [key: string]: string;
    };
    /**
     * Type of the component.
     */
    readonly type: string;
    /**
     * Version of the component.
     */
    readonly version: string;
}
