import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Provides details about an Image Builder Distribution Configuration.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.imagebuilder.getDistributionConfiguration({
 *     arn: "arn:aws:imagebuilder:us-west-2:aws:distribution-configuration/example",
 * }, { async: true }));
 * ```
 */
export declare function getDistributionConfiguration(args: GetDistributionConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetDistributionConfigurationResult>;
/**
 * A collection of arguments for invoking getDistributionConfiguration.
 */
export interface GetDistributionConfigurationArgs {
    /**
     * Amazon Resource Name (ARN) of the distribution configuration.
     */
    readonly arn: string;
    /**
     * Key-value map of resource tags for the distribution configuration.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getDistributionConfiguration.
 */
export interface GetDistributionConfigurationResult {
    readonly arn: string;
    /**
     * Date the distribution configuration was created.
     */
    readonly dateCreated: string;
    /**
     * Date the distribution configuration was updated.
     */
    readonly dateUpdated: string;
    /**
     * Description to apply to distributed AMI.
     */
    readonly description: string;
    /**
     * Set of distributions.
     */
    readonly distributions: outputs.imagebuilder.GetDistributionConfigurationDistribution[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Name of the distribution configuration.
     */
    readonly name: string;
    /**
     * Key-value map of resource tags for the distribution configuration.
     */
    readonly tags: {
        [key: string]: string;
    };
}
