import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Provides details about an Image Builder Image.
 *
 * ## Example Usage
 * ### Latest
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.imagebuilder.getImage({
 *     arn: "arn:aws:imagebuilder:us-west-2:aws:image/amazon-linux-2-x86/x.x.x",
 * }, { async: true }));
 * ```
 */
export declare function getImage(args: GetImageArgs, opts?: pulumi.InvokeOptions): Promise<GetImageResult>;
/**
 * A collection of arguments for invoking getImage.
 */
export interface GetImageArgs {
    /**
     * Amazon Resource Name (ARN) of the image. The suffix can either be specified with wildcards (`x.x.x`) to fetch the latest build version or a full build version (e.g. `2020.11.26/1`) to fetch an exact version.
     */
    readonly arn: string;
    /**
     * Key-value map of resource tags for the image.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getImage.
 */
export interface GetImageResult {
    readonly arn: string;
    /**
     * Build version Amazon Resource Name (ARN) of the image. This will always have the `#.#.#/#` suffix.
     */
    readonly buildVersionArn: string;
    /**
     * Date the image was created.
     */
    readonly dateCreated: string;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Distribution Configuration.
     */
    readonly distributionConfigurationArn: string;
    /**
     * Whether additional information about the image being created is collected.
     */
    readonly enhancedImageMetadataEnabled: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Amazon Resource Name (ARN) of the Image Builder Infrastructure Recipe.
     */
    readonly imageRecipeArn: string;
    /**
     * List of an object with image tests configuration.
     */
    readonly imageTestsConfigurations: outputs.imagebuilder.GetImageImageTestsConfiguration[];
    /**
     * Amazon Resource Name (ARN) of the Image Builder Infrastructure Configuration.
     */
    readonly infrastructureConfigurationArn: string;
    /**
     * Name of the AMI.
     */
    readonly name: string;
    /**
     * Operating System version of the image.
     */
    readonly osVersion: string;
    /**
     * List of objects with resources created by the image.
     */
    readonly outputResources: outputs.imagebuilder.GetImageOutputResource[];
    /**
     * Platform of the image.
     */
    readonly platform: string;
    /**
     * Key-value map of resource tags for the image.
     */
    readonly tags: {
        [key: string]: string;
    };
    /**
     * Version of the image.
     */
    readonly version: string;
}
