import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Provides details about an Image Builder Image Recipe.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.imagebuilder.getImageRecipe({
 *     arn: "arn:aws:imagebuilder:us-east-1:aws:image-recipe/example/1.0.0",
 * }, { async: true }));
 * ```
 */
export declare function getImageRecipe(args: GetImageRecipeArgs, opts?: pulumi.InvokeOptions): Promise<GetImageRecipeResult>;
/**
 * A collection of arguments for invoking getImageRecipe.
 */
export interface GetImageRecipeArgs {
    /**
     * Amazon Resource Name (ARN) of the image recipe.
     */
    readonly arn: string;
    /**
     * Key-value map of resource tags for the image recipe.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getImageRecipe.
 */
export interface GetImageRecipeResult {
    readonly arn: string;
    /**
     * Set of objects with block device mappings for the the image recipe.
     */
    readonly blockDeviceMappings: outputs.imagebuilder.GetImageRecipeBlockDeviceMapping[];
    /**
     * List of objects with components for the image recipe.
     */
    readonly components: outputs.imagebuilder.GetImageRecipeComponent[];
    /**
     * Date the image recipe was created.
     */
    readonly dateCreated: string;
    /**
     * Description of the image recipe.
     */
    readonly description: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Name of the image recipe.
     */
    readonly name: string;
    /**
     * Owner of the image recipe.
     */
    readonly owner: string;
    /**
     * Platform of the image recipe.
     */
    readonly parentImage: string;
    /**
     * Platform of the image recipe.
     */
    readonly platform: string;
    /**
     * Key-value map of resource tags for the image recipe.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Version of the image recipe.
     */
    readonly version: string;
    /**
     * The working directory used during build and test workflows.
     */
    readonly workingDirectory: string;
}
