import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Provides details about an Image Builder Infrastructure Configuration.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.imagebuilder.getInfrastructureConfiguration({
 *     arn: "arn:aws:imagebuilder:us-west-2:aws:infrastructure-configuration/example",
 * }, { async: true }));
 * ```
 */
export declare function getInfrastructureConfiguration(args: GetInfrastructureConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetInfrastructureConfigurationResult>;
/**
 * A collection of arguments for invoking getInfrastructureConfiguration.
 */
export interface GetInfrastructureConfigurationArgs {
    /**
     * Amazon Resource Name (ARN) of the infrastructure configuration.
     */
    readonly arn: string;
    /**
     * Key-value map of resource tags for the infrastructure created by the infrastructure configuration.
     */
    readonly resourceTags?: {
        [key: string]: string;
    };
    /**
     * Key-value map of resource tags for the infrastructure configuration.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getInfrastructureConfiguration.
 */
export interface GetInfrastructureConfigurationResult {
    readonly arn: string;
    /**
     * Date the infrastructure configuration was updated.
     */
    readonly dateCreated: string;
    readonly dateUpdated: string;
    /**
     * Description of the infrastructure configuration.
     */
    readonly description: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Name of the IAM Instance Profile associated with the configuration.
     */
    readonly instanceProfileName: string;
    /**
     * Set of EC2 Instance Types associated with the configuration.
     */
    readonly instanceTypes: string[];
    /**
     * Name of the EC2 Key Pair associated with the configuration.
     */
    readonly keyPair: string;
    /**
     * Nested list of logging settings.
     */
    readonly loggings: outputs.imagebuilder.GetInfrastructureConfigurationLogging[];
    /**
     * Name of the infrastructure configuration.
     */
    readonly name: string;
    /**
     * Key-value map of resource tags for the infrastructure created by the infrastructure configuration.
     */
    readonly resourceTags: {
        [key: string]: string;
    };
    /**
     * Set of EC2 Security Group identifiers associated with the configuration.
     */
    readonly securityGroupIds: string[];
    /**
     * Amazon Resource Name (ARN) of the SNS Topic associated with the configuration.
     */
    readonly snsTopicArn: string;
    /**
     * Identifier of the EC2 Subnet associated with the configuration.
     */
    readonly subnetId: string;
    /**
     * Key-value map of resource tags for the infrastructure configuration.
     */
    readonly tags: {
        [key: string]: string;
    };
    /**
     * Whether instances are terminated on failure.
     */
    readonly terminateInstanceOnFailure: boolean;
}
