import * as pulumi from "@pulumi/pulumi";
/**
 * Returns a unique endpoint specific to the AWS account making the call.
 */
export declare function getEndpoint(args?: GetEndpointArgs, opts?: pulumi.InvokeOptions): Promise<GetEndpointResult>;
/**
 * A collection of arguments for invoking getEndpoint.
 */
export interface GetEndpointArgs {
    /**
     * Endpoint type. Valid values: `iot:CredentialProvider`, `iot:Data`, `iot:Data-ATS`, `iot:Job`.
     */
    readonly endpointType?: string;
}
/**
 * A collection of values returned by getEndpoint.
 */
export interface GetEndpointResult {
    /**
     * The endpoint based on `endpointType`:
     * * No `endpointType`: Either `iot:Data` or `iot:Data-ATS` [depending on region](https://aws.amazon.com/blogs/iot/aws-iot-core-ats-endpoints/)
     * * `iot:CredentialsProvider`: `IDENTIFIER.credentials.iot.REGION.amazonaws.com`
     * * `iot:Data`: `IDENTIFIER.iot.REGION.amazonaws.com`
     * * `iot:Data-ATS`: `IDENTIFIER-ats.iot.REGION.amazonaws.com`
     * * `iot:Job`: `IDENTIFIER.jobs.iot.REGION.amazonaws.com`
     */
    readonly endpointAddress: string;
    readonly endpointType?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
}
