import * as pulumi from "@pulumi/pulumi";
/**
 * Creates and manages an AWS IoT Thing.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.iot.Thing("example", {
 *     attributes: {
 *         First: "examplevalue",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * IOT Things can be imported using the name, e.g.
 *
 * ```sh
 *  $ pulumi import aws:iot/thing:Thing example example
 * ```
 */
export declare class Thing extends pulumi.CustomResource {
    /**
     * Get an existing Thing resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ThingState, opts?: pulumi.CustomResourceOptions): Thing;
    /**
     * Returns true if the given object is an instance of Thing.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Thing;
    /**
     * The ARN of the thing.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Map of attributes of the thing.
     */
    readonly attributes: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The default client ID.
     */
    readonly defaultClientId: pulumi.Output<string>;
    /**
     * The name of the thing.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The thing type name.
     */
    readonly thingTypeName: pulumi.Output<string | undefined>;
    /**
     * The current version of the thing record in the registry.
     */
    readonly version: pulumi.Output<number>;
    /**
     * Create a Thing resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ThingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Thing resources.
 */
export interface ThingState {
    /**
     * The ARN of the thing.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Map of attributes of the thing.
     */
    readonly attributes?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The default client ID.
     */
    readonly defaultClientId?: pulumi.Input<string>;
    /**
     * The name of the thing.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The thing type name.
     */
    readonly thingTypeName?: pulumi.Input<string>;
    /**
     * The current version of the thing record in the registry.
     */
    readonly version?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a Thing resource.
 */
export interface ThingArgs {
    /**
     * Map of attributes of the thing.
     */
    readonly attributes?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The name of the thing.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The thing type name.
     */
    readonly thingTypeName?: pulumi.Input<string>;
}
