import * as pulumi from "@pulumi/pulumi";
import { ARN } from "..";
/**
 * Attaches Principal to AWS IoT Thing.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * import * from "fs";
 *
 * const example = new aws.iot.Thing("example", {});
 * const cert = new aws.iot.Certificate("cert", {
 *     csr: fs.readFileSync("csr.pem"),
 *     active: true,
 * });
 * const att = new aws.iot.ThingPrincipalAttachment("att", {
 *     principal: cert.arn,
 *     thing: example.name,
 * });
 * ```
 */
export declare class ThingPrincipalAttachment extends pulumi.CustomResource {
    /**
     * Get an existing ThingPrincipalAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ThingPrincipalAttachmentState, opts?: pulumi.CustomResourceOptions): ThingPrincipalAttachment;
    /**
     * Returns true if the given object is an instance of ThingPrincipalAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ThingPrincipalAttachment;
    /**
     * The AWS IoT Certificate ARN or Amazon Cognito Identity ID.
     */
    readonly principal: pulumi.Output<ARN>;
    /**
     * The name of the thing.
     */
    readonly thing: pulumi.Output<string>;
    /**
     * Create a ThingPrincipalAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ThingPrincipalAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ThingPrincipalAttachment resources.
 */
export interface ThingPrincipalAttachmentState {
    /**
     * The AWS IoT Certificate ARN or Amazon Cognito Identity ID.
     */
    readonly principal?: pulumi.Input<ARN>;
    /**
     * The name of the thing.
     */
    readonly thing?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ThingPrincipalAttachment resource.
 */
export interface ThingPrincipalAttachmentArgs {
    /**
     * The AWS IoT Certificate ARN or Amazon Cognito Identity ID.
     */
    readonly principal: pulumi.Input<ARN>;
    /**
     * The name of the thing.
     */
    readonly thing: pulumi.Input<string>;
}
