import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Creates and manages an AWS IoT Thing Type.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const foo = new aws.iot.ThingType("foo", {});
 * ```
 *
 * ## Import
 *
 * IOT Thing Types can be imported using the name, e.g.
 *
 * ```sh
 *  $ pulumi import aws:iot/thingType:ThingType example example
 * ```
 */
export declare class ThingType extends pulumi.CustomResource {
    /**
     * Get an existing ThingType resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ThingTypeState, opts?: pulumi.CustomResourceOptions): ThingType;
    /**
     * Returns true if the given object is an instance of ThingType.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ThingType;
    /**
     * The ARN of the created AWS IoT Thing Type.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Whether the thing type is deprecated. If true, no new things could be associated with this type.
     */
    readonly deprecated: pulumi.Output<boolean | undefined>;
    /**
     * The name of the thing type.
     */
    readonly name: pulumi.Output<string>;
    /**
     * , Configuration block that can contain the following properties of the thing type:
     */
    readonly properties: pulumi.Output<outputs.iot.ThingTypeProperties | undefined>;
    /**
     * Create a ThingType resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ThingTypeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ThingType resources.
 */
export interface ThingTypeState {
    /**
     * The ARN of the created AWS IoT Thing Type.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Whether the thing type is deprecated. If true, no new things could be associated with this type.
     */
    readonly deprecated?: pulumi.Input<boolean>;
    /**
     * The name of the thing type.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * , Configuration block that can contain the following properties of the thing type:
     */
    readonly properties?: pulumi.Input<inputs.iot.ThingTypeProperties>;
}
/**
 * The set of arguments for constructing a ThingType resource.
 */
export interface ThingTypeArgs {
    /**
     * Whether the thing type is deprecated. If true, no new things could be associated with this type.
     */
    readonly deprecated?: pulumi.Input<boolean>;
    /**
     * The name of the thing type.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * , Configuration block that can contain the following properties of the thing type:
     */
    readonly properties?: pulumi.Input<inputs.iot.ThingTypeProperties>;
}
