import * as pulumi from "@pulumi/pulumi";
/**
 * Provides details about a Kinesis Stream Consumer.
 *
 * For more details, see the [Amazon Kinesis Stream Consumer Documentation](https://docs.aws.amazon.com/streams/latest/dev/amazon-kinesis-consumers.html).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = aws.kinesis.getStreamConsumer({
 *     name: "example-consumer",
 *     streamArn: aws_kinesis_stream.example.arn,
 * });
 * ```
 */
export declare function getStreamConsumer(args: GetStreamConsumerArgs, opts?: pulumi.InvokeOptions): Promise<GetStreamConsumerResult>;
/**
 * A collection of arguments for invoking getStreamConsumer.
 */
export interface GetStreamConsumerArgs {
    /**
     * Amazon Resource Name (ARN) of the stream consumer.
     */
    readonly arn?: string;
    /**
     * Name of the stream consumer.
     */
    readonly name?: string;
    /**
     * Amazon Resource Name (ARN) of the data stream the consumer is registered with.
     */
    readonly streamArn: string;
}
/**
 * A collection of values returned by getStreamConsumer.
 */
export interface GetStreamConsumerResult {
    readonly arn: string;
    /**
     * Approximate timestamp in [RFC3339 format](https://tools.ietf.org/html/rfc3339#section-5.8) of when the stream consumer was created.
     */
    readonly creationTimestamp: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
    /**
     * The current status of the stream consumer.
     */
    readonly status: string;
    readonly streamArn: string;
}
