import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get the ARN of a KMS key alias.
 * By using this data source, you can reference key alias
 * without having to hard code the ARN as input.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const s3 = pulumi.output(aws.kms.getAlias({
 *     name: "alias/aws/s3",
 * }, { async: true }));
 * ```
 */
export declare function getAlias(args: GetAliasArgs, opts?: pulumi.InvokeOptions): Promise<GetAliasResult>;
/**
 * A collection of arguments for invoking getAlias.
 */
export interface GetAliasArgs {
    /**
     * The display name of the alias. The name must start with the word "alias" followed by a forward slash (alias/)
     */
    readonly name: string;
}
/**
 * A collection of values returned by getAlias.
 */
export interface GetAliasResult {
    /**
     * The Amazon Resource Name(ARN) of the key alias.
     */
    readonly arn: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
    /**
     * ARN pointed to by the alias.
     */
    readonly targetKeyArn: string;
    /**
     * Key identifier pointed to by the alias.
     */
    readonly targetKeyId: string;
}
