import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get detailed information about
 * the specified KMS Key with flexible key id input.
 * This can be useful to reference key alias
 * without having to hard code the ARN as input.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const byAlias = pulumi.output(aws.kms.getKey({
 *     keyId: "alias/my-key",
 * }, { async: true }));
 * const byId = pulumi.output(aws.kms.getKey({
 *     keyId: "1234abcd-12ab-34cd-56ef-1234567890ab",
 * }, { async: true }));
 * const byAliasArn = pulumi.output(aws.kms.getKey({
 *     keyId: "arn:aws:kms:us-east-1:111122223333:alias/my-key",
 * }, { async: true }));
 * const byKeyArn = pulumi.output(aws.kms.getKey({
 *     keyId: "arn:aws:kms:us-east-1:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab",
 * }, { async: true }));
 * ```
 */
export declare function getKey(args: GetKeyArgs, opts?: pulumi.InvokeOptions): Promise<GetKeyResult>;
/**
 * A collection of arguments for invoking getKey.
 */
export interface GetKeyArgs {
    /**
     * List of grant tokens
     */
    readonly grantTokens?: string[];
    /**
     * Key identifier which can be one of the following format:
     * * Key ID. E.g: `1234abcd-12ab-34cd-56ef-1234567890ab`
     * * Key ARN. E.g.: `arn:aws:kms:us-east-1:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab`
     * * Alias name. E.g.: `alias/my-key`
     * * Alias ARN: E.g.: `arn:aws:kms:us-east-1:111122223333:alias/my-key`
     */
    readonly keyId: string;
}
/**
 * A collection of values returned by getKey.
 */
export interface GetKeyResult {
    readonly arn: string;
    readonly awsAccountId: string;
    readonly creationDate: string;
    readonly customerMasterKeySpec: string;
    readonly deletionDate: string;
    readonly description: string;
    readonly enabled: boolean;
    readonly expirationModel: string;
    readonly grantTokens?: string[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly keyId: string;
    readonly keyManager: string;
    readonly keyState: string;
    readonly keyUsage: string;
    readonly origin: string;
    readonly validTo: string;
}
