import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Get Lake Formation principals designated as data lake administrators and lists of principal permission entries for default create database and default create table permissions.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.lakeformation.getDataLakeSettings({
 *     catalogId: "14916253649",
 * }, { async: true }));
 * ```
 */
export declare function getDataLakeSettings(args?: GetDataLakeSettingsArgs, opts?: pulumi.InvokeOptions): Promise<GetDataLakeSettingsResult>;
/**
 * A collection of arguments for invoking getDataLakeSettings.
 */
export interface GetDataLakeSettingsArgs {
    /**
     * Identifier for the Data Catalog. By default, the account ID.
     */
    readonly catalogId?: string;
}
/**
 * A collection of values returned by getDataLakeSettings.
 */
export interface GetDataLakeSettingsResult {
    /**
     * List of ARNs of AWS Lake Formation principals (IAM users or roles).
     */
    readonly admins: string[];
    readonly catalogId?: string;
    /**
     * Up to three configuration blocks of principal permissions for default create database permissions. Detailed below.
     */
    readonly createDatabaseDefaultPermissions: outputs.lakeformation.GetDataLakeSettingsCreateDatabaseDefaultPermission[];
    /**
     * Up to three configuration blocks of principal permissions for default create table permissions. Detailed below.
     */
    readonly createTableDefaultPermissions: outputs.lakeformation.GetDataLakeSettingsCreateTableDefaultPermission[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * List of the resource-owning account IDs that the caller's account can use to share their user access details (user ARNs).
     */
    readonly trustedResourceOwners: string[];
}
