import * as pulumi from "@pulumi/pulumi";
/**
 * Provides details about a Lake Formation resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.lakeformation.getResource({
 *     arn: "arn:aws:s3:::tf-acc-test-9151654063908211878",
 * }, { async: true }));
 * ```
 */
export declare function getResource(args: GetResourceArgs, opts?: pulumi.InvokeOptions): Promise<GetResourceResult>;
/**
 * A collection of arguments for invoking getResource.
 */
export interface GetResourceArgs {
    /**
     * Amazon Resource Name (ARN) of the resource, an S3 path.
     */
    readonly arn: string;
}
/**
 * A collection of values returned by getResource.
 */
export interface GetResourceResult {
    readonly arn: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The date and time the resource was last modified in [RFC 3339 format](https://tools.ietf.org/html/rfc3339#section-5.8).
     */
    readonly lastModified: string;
    /**
     * Role that the resource was registered with.
     */
    readonly roleArn: string;
}
