import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to invoke custom lambda functions as data source.
 * The lambda function is invoked with [RequestResponse](https://docs.aws.amazon.com/lambda/latest/dg/API_Invoke.html#API_Invoke_RequestSyntax)
 * invocation type.
 */
export declare function getInvocation(args: GetInvocationArgs, opts?: pulumi.InvokeOptions): Promise<GetInvocationResult>;
/**
 * A collection of arguments for invoking getInvocation.
 */
export interface GetInvocationArgs {
    /**
     * The name of the lambda function.
     */
    readonly functionName: string;
    /**
     * A string in JSON format that is passed as payload to the lambda function.
     */
    readonly input: string;
    /**
     * The qualifier (a.k.a version) of the lambda function. Defaults
     * to `$LATEST`.
     */
    readonly qualifier?: string;
}
/**
 * A collection of values returned by getInvocation.
 */
export interface GetInvocationResult {
    readonly functionName: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly input: string;
    readonly qualifier?: string;
    /**
     * String result of the lambda function invocation.
     */
    readonly result: string;
}
