import * as pulumi from "@pulumi/pulumi";
/**
 * Provides details about a specific Amazon Lex Intent.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const orderFlowers = pulumi.output(aws.lex.getIntent({
 *     name: "OrderFlowers",
 *     version: "$LATEST",
 * }, { async: true }));
 * ```
 */
export declare function getIntent(args: GetIntentArgs, opts?: pulumi.InvokeOptions): Promise<GetIntentResult>;
/**
 * A collection of arguments for invoking getIntent.
 */
export interface GetIntentArgs {
    /**
     * The name of the intent. The name is case sensitive.
     */
    readonly name: string;
    /**
     * The version of the intent.
     */
    readonly version?: string;
}
/**
 * A collection of values returned by getIntent.
 */
export interface GetIntentResult {
    /**
     * The ARN of the Lex intent.
     */
    readonly arn: string;
    /**
     * Checksum identifying the version of the intent that was created. The checksum is not
     * included as an argument because the resource will add it automatically when updating the intent.
     */
    readonly checksum: string;
    /**
     * The date when the intent version was created.
     */
    readonly createdDate: string;
    /**
     * A description of the intent.
     */
    readonly description: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The date when the $LATEST version of this intent was updated.
     */
    readonly lastUpdatedDate: string;
    /**
     * The name of the intent, not case sensitive.
     */
    readonly name: string;
    /**
     * A unique identifier for the built-in intent to base this
     * intent on. To find the signature for an intent, see
     * [Standard Built-in Intents](https://developer.amazon.com/public/solutions/alexa/alexa-skills-kit/docs/built-in-intent-ref/standard-intents)
     * in the Alexa Skills Kit.
     */
    readonly parentIntentSignature: string;
    /**
     * The version of the bot.
     */
    readonly version?: string;
}
