import * as pulumi from "@pulumi/pulumi";
/**
 * Get information on an Amazon MSK Configuration.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.msk.getConfiguration({
 *     name: "example",
 * }, { async: true }));
 * ```
 */
export declare function getConfiguration(args: GetConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetConfigurationResult>;
/**
 * A collection of arguments for invoking getConfiguration.
 */
export interface GetConfigurationArgs {
    /**
     * Name of the configuration.
     */
    readonly name: string;
}
/**
 * A collection of values returned by getConfiguration.
 */
export interface GetConfigurationResult {
    /**
     * Amazon Resource Name (ARN) of the configuration.
     */
    readonly arn: string;
    /**
     * Description of the configuration.
     */
    readonly description: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * List of Apache Kafka versions which can use this configuration.
     */
    readonly kafkaVersions: string[];
    /**
     * Latest revision of the configuration.
     */
    readonly latestRevision: number;
    readonly name: string;
    /**
     * Contents of the server.properties file.
     */
    readonly serverProperties: string;
}
