import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides an OpsWorks haproxy layer resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const lb = new aws.opsworks.HaproxyLayer("lb", {
 *     stackId: aws_opsworks_stack.main.id,
 *     statsPassword: "foobarbaz",
 * });
 * ```
 */
export declare class HaproxyLayer extends pulumi.CustomResource {
    /**
     * Get an existing HaproxyLayer resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: HaproxyLayerState, opts?: pulumi.CustomResourceOptions): HaproxyLayer;
    /**
     * Returns true if the given object is an instance of HaproxyLayer.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is HaproxyLayer;
    /**
     * The Amazon Resource Name(ARN) of the layer.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Whether to automatically assign an elastic IP address to the layer's instances.
     */
    readonly autoAssignElasticIps: pulumi.Output<boolean | undefined>;
    /**
     * For stacks belonging to a VPC, whether to automatically assign a public IP address to each of the layer's instances.
     */
    readonly autoAssignPublicIps: pulumi.Output<boolean | undefined>;
    /**
     * Whether to enable auto-healing for the layer.
     */
    readonly autoHealing: pulumi.Output<boolean | undefined>;
    readonly customConfigureRecipes: pulumi.Output<string[] | undefined>;
    readonly customDeployRecipes: pulumi.Output<string[] | undefined>;
    /**
     * The ARN of an IAM profile that will be used for the layer's instances.
     */
    readonly customInstanceProfileArn: pulumi.Output<string | undefined>;
    /**
     * Custom JSON attributes to apply to the layer.
     */
    readonly customJson: pulumi.Output<string | undefined>;
    /**
     * Ids for a set of security groups to apply to the layer's instances.
     */
    readonly customSecurityGroupIds: pulumi.Output<string[] | undefined>;
    readonly customSetupRecipes: pulumi.Output<string[] | undefined>;
    readonly customShutdownRecipes: pulumi.Output<string[] | undefined>;
    readonly customUndeployRecipes: pulumi.Output<string[] | undefined>;
    /**
     * Whether to enable Elastic Load Balancing connection draining.
     */
    readonly drainElbOnShutdown: pulumi.Output<boolean | undefined>;
    /**
     * `ebsVolume` blocks, as described below, will each create an EBS volume and connect it to the layer's instances.
     */
    readonly ebsVolumes: pulumi.Output<outputs.opsworks.HaproxyLayerEbsVolume[] | undefined>;
    /**
     * Name of an Elastic Load Balancer to attach to this layer
     */
    readonly elasticLoadBalancer: pulumi.Output<string | undefined>;
    /**
     * HTTP method to use for instance healthchecks. Defaults to "OPTIONS".
     */
    readonly healthcheckMethod: pulumi.Output<string | undefined>;
    /**
     * URL path to use for instance healthchecks. Defaults to "/".
     */
    readonly healthcheckUrl: pulumi.Output<string | undefined>;
    /**
     * Whether to install OS and package updates on each instance when it boots.
     */
    readonly installUpdatesOnBoot: pulumi.Output<boolean | undefined>;
    /**
     * The time, in seconds, that OpsWorks will wait for Chef to complete after triggering the Shutdown event.
     */
    readonly instanceShutdownTimeout: pulumi.Output<number | undefined>;
    /**
     * A human-readable name for the layer.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The id of the stack the layer will belong to.
     */
    readonly stackId: pulumi.Output<string>;
    /**
     * Whether to enable HAProxy stats.
     */
    readonly statsEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The password to use for HAProxy stats.
     */
    readonly statsPassword: pulumi.Output<string>;
    /**
     * The HAProxy stats URL. Defaults to "/haproxy?stats".
     */
    readonly statsUrl: pulumi.Output<string | undefined>;
    /**
     * The username for HAProxy stats. Defaults to "opsworks".
     */
    readonly statsUser: pulumi.Output<string | undefined>;
    /**
     * Names of a set of system packages to install on the layer's instances.
     */
    readonly systemPackages: pulumi.Output<string[] | undefined>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Whether to use EBS-optimized instances.
     */
    readonly useEbsOptimizedInstances: pulumi.Output<boolean | undefined>;
    /**
     * Create a HaproxyLayer resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: HaproxyLayerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering HaproxyLayer resources.
 */
export interface HaproxyLayerState {
    /**
     * The Amazon Resource Name(ARN) of the layer.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Whether to automatically assign an elastic IP address to the layer's instances.
     */
    readonly autoAssignElasticIps?: pulumi.Input<boolean>;
    /**
     * For stacks belonging to a VPC, whether to automatically assign a public IP address to each of the layer's instances.
     */
    readonly autoAssignPublicIps?: pulumi.Input<boolean>;
    /**
     * Whether to enable auto-healing for the layer.
     */
    readonly autoHealing?: pulumi.Input<boolean>;
    readonly customConfigureRecipes?: pulumi.Input<pulumi.Input<string>[]>;
    readonly customDeployRecipes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ARN of an IAM profile that will be used for the layer's instances.
     */
    readonly customInstanceProfileArn?: pulumi.Input<string>;
    /**
     * Custom JSON attributes to apply to the layer.
     */
    readonly customJson?: pulumi.Input<string>;
    /**
     * Ids for a set of security groups to apply to the layer's instances.
     */
    readonly customSecurityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    readonly customSetupRecipes?: pulumi.Input<pulumi.Input<string>[]>;
    readonly customShutdownRecipes?: pulumi.Input<pulumi.Input<string>[]>;
    readonly customUndeployRecipes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Whether to enable Elastic Load Balancing connection draining.
     */
    readonly drainElbOnShutdown?: pulumi.Input<boolean>;
    /**
     * `ebsVolume` blocks, as described below, will each create an EBS volume and connect it to the layer's instances.
     */
    readonly ebsVolumes?: pulumi.Input<pulumi.Input<inputs.opsworks.HaproxyLayerEbsVolume>[]>;
    /**
     * Name of an Elastic Load Balancer to attach to this layer
     */
    readonly elasticLoadBalancer?: pulumi.Input<string>;
    /**
     * HTTP method to use for instance healthchecks. Defaults to "OPTIONS".
     */
    readonly healthcheckMethod?: pulumi.Input<string>;
    /**
     * URL path to use for instance healthchecks. Defaults to "/".
     */
    readonly healthcheckUrl?: pulumi.Input<string>;
    /**
     * Whether to install OS and package updates on each instance when it boots.
     */
    readonly installUpdatesOnBoot?: pulumi.Input<boolean>;
    /**
     * The time, in seconds, that OpsWorks will wait for Chef to complete after triggering the Shutdown event.
     */
    readonly instanceShutdownTimeout?: pulumi.Input<number>;
    /**
     * A human-readable name for the layer.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The id of the stack the layer will belong to.
     */
    readonly stackId?: pulumi.Input<string>;
    /**
     * Whether to enable HAProxy stats.
     */
    readonly statsEnabled?: pulumi.Input<boolean>;
    /**
     * The password to use for HAProxy stats.
     */
    readonly statsPassword?: pulumi.Input<string>;
    /**
     * The HAProxy stats URL. Defaults to "/haproxy?stats".
     */
    readonly statsUrl?: pulumi.Input<string>;
    /**
     * The username for HAProxy stats. Defaults to "opsworks".
     */
    readonly statsUser?: pulumi.Input<string>;
    /**
     * Names of a set of system packages to install on the layer's instances.
     */
    readonly systemPackages?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Whether to use EBS-optimized instances.
     */
    readonly useEbsOptimizedInstances?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a HaproxyLayer resource.
 */
export interface HaproxyLayerArgs {
    /**
     * Whether to automatically assign an elastic IP address to the layer's instances.
     */
    readonly autoAssignElasticIps?: pulumi.Input<boolean>;
    /**
     * For stacks belonging to a VPC, whether to automatically assign a public IP address to each of the layer's instances.
     */
    readonly autoAssignPublicIps?: pulumi.Input<boolean>;
    /**
     * Whether to enable auto-healing for the layer.
     */
    readonly autoHealing?: pulumi.Input<boolean>;
    readonly customConfigureRecipes?: pulumi.Input<pulumi.Input<string>[]>;
    readonly customDeployRecipes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ARN of an IAM profile that will be used for the layer's instances.
     */
    readonly customInstanceProfileArn?: pulumi.Input<string>;
    /**
     * Custom JSON attributes to apply to the layer.
     */
    readonly customJson?: pulumi.Input<string>;
    /**
     * Ids for a set of security groups to apply to the layer's instances.
     */
    readonly customSecurityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    readonly customSetupRecipes?: pulumi.Input<pulumi.Input<string>[]>;
    readonly customShutdownRecipes?: pulumi.Input<pulumi.Input<string>[]>;
    readonly customUndeployRecipes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Whether to enable Elastic Load Balancing connection draining.
     */
    readonly drainElbOnShutdown?: pulumi.Input<boolean>;
    /**
     * `ebsVolume` blocks, as described below, will each create an EBS volume and connect it to the layer's instances.
     */
    readonly ebsVolumes?: pulumi.Input<pulumi.Input<inputs.opsworks.HaproxyLayerEbsVolume>[]>;
    /**
     * Name of an Elastic Load Balancer to attach to this layer
     */
    readonly elasticLoadBalancer?: pulumi.Input<string>;
    /**
     * HTTP method to use for instance healthchecks. Defaults to "OPTIONS".
     */
    readonly healthcheckMethod?: pulumi.Input<string>;
    /**
     * URL path to use for instance healthchecks. Defaults to "/".
     */
    readonly healthcheckUrl?: pulumi.Input<string>;
    /**
     * Whether to install OS and package updates on each instance when it boots.
     */
    readonly installUpdatesOnBoot?: pulumi.Input<boolean>;
    /**
     * The time, in seconds, that OpsWorks will wait for Chef to complete after triggering the Shutdown event.
     */
    readonly instanceShutdownTimeout?: pulumi.Input<number>;
    /**
     * A human-readable name for the layer.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The id of the stack the layer will belong to.
     */
    readonly stackId: pulumi.Input<string>;
    /**
     * Whether to enable HAProxy stats.
     */
    readonly statsEnabled?: pulumi.Input<boolean>;
    /**
     * The password to use for HAProxy stats.
     */
    readonly statsPassword: pulumi.Input<string>;
    /**
     * The HAProxy stats URL. Defaults to "/haproxy?stats".
     */
    readonly statsUrl?: pulumi.Input<string>;
    /**
     * The username for HAProxy stats. Defaults to "opsworks".
     */
    readonly statsUser?: pulumi.Input<string>;
    /**
     * Names of a set of system packages to install on the layer's instances.
     */
    readonly systemPackages?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Whether to use EBS-optimized instances.
     */
    readonly useEbsOptimizedInstances?: pulumi.Input<boolean>;
}
