import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an OpsWorks RDS DB Instance resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const myInstance = new aws.opsworks.RdsDbInstance("myInstance", {
 *     stackId: aws_opsworks_stack.my_stack.id,
 *     rdsDbInstanceArn: aws_db_instance.my_instance.arn,
 *     dbUser: "someUser",
 *     dbPassword: "somePass",
 * });
 * ```
 */
export declare class RdsDbInstance extends pulumi.CustomResource {
    /**
     * Get an existing RdsDbInstance resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RdsDbInstanceState, opts?: pulumi.CustomResourceOptions): RdsDbInstance;
    /**
     * Returns true if the given object is an instance of RdsDbInstance.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RdsDbInstance;
    /**
     * A db password
     */
    readonly dbPassword: pulumi.Output<string>;
    /**
     * A db username
     */
    readonly dbUser: pulumi.Output<string>;
    /**
     * The db instance to register for this stack. Changing this will force a new resource.
     */
    readonly rdsDbInstanceArn: pulumi.Output<string>;
    /**
     * The stack to register a db instance for. Changing this will force a new resource.
     */
    readonly stackId: pulumi.Output<string>;
    /**
     * Create a RdsDbInstance resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RdsDbInstanceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RdsDbInstance resources.
 */
export interface RdsDbInstanceState {
    /**
     * A db password
     */
    readonly dbPassword?: pulumi.Input<string>;
    /**
     * A db username
     */
    readonly dbUser?: pulumi.Input<string>;
    /**
     * The db instance to register for this stack. Changing this will force a new resource.
     */
    readonly rdsDbInstanceArn?: pulumi.Input<string>;
    /**
     * The stack to register a db instance for. Changing this will force a new resource.
     */
    readonly stackId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a RdsDbInstance resource.
 */
export interface RdsDbInstanceArgs {
    /**
     * A db password
     */
    readonly dbPassword: pulumi.Input<string>;
    /**
     * A db username
     */
    readonly dbUser: pulumi.Input<string>;
    /**
     * The db instance to register for this stack. Changing this will force a new resource.
     */
    readonly rdsDbInstanceArn: pulumi.Input<string>;
    /**
     * The stack to register a db instance for. Changing this will force a new resource.
     */
    readonly stackId: pulumi.Input<string>;
}
