import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an OpsWorks User Profile resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const myProfile = new aws.opsworks.UserProfile("myProfile", {
 *     userArn: aws_iam_user.user.arn,
 *     sshUsername: "my_user",
 * });
 * ```
 */
export declare class UserProfile extends pulumi.CustomResource {
    /**
     * Get an existing UserProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UserProfileState, opts?: pulumi.CustomResourceOptions): UserProfile;
    /**
     * Returns true if the given object is an instance of UserProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UserProfile;
    /**
     * Whether users can specify their own SSH public key through the My Settings page
     */
    readonly allowSelfManagement: pulumi.Output<boolean | undefined>;
    /**
     * The users public key
     */
    readonly sshPublicKey: pulumi.Output<string | undefined>;
    /**
     * The ssh username, with witch this user wants to log in
     */
    readonly sshUsername: pulumi.Output<string>;
    /**
     * The user's IAM ARN
     */
    readonly userArn: pulumi.Output<string>;
    /**
     * Create a UserProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UserProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering UserProfile resources.
 */
export interface UserProfileState {
    /**
     * Whether users can specify their own SSH public key through the My Settings page
     */
    readonly allowSelfManagement?: pulumi.Input<boolean>;
    /**
     * The users public key
     */
    readonly sshPublicKey?: pulumi.Input<string>;
    /**
     * The ssh username, with witch this user wants to log in
     */
    readonly sshUsername?: pulumi.Input<string>;
    /**
     * The user's IAM ARN
     */
    readonly userArn?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a UserProfile resource.
 */
export interface UserProfileArgs {
    /**
     * Whether users can specify their own SSH public key through the My Settings page
     */
    readonly allowSelfManagement?: pulumi.Input<boolean>;
    /**
     * The users public key
     */
    readonly sshPublicKey?: pulumi.Input<string>;
    /**
     * The ssh username, with witch this user wants to log in
     */
    readonly sshUsername: pulumi.Input<string>;
    /**
     * The user's IAM ARN
     */
    readonly userArn: pulumi.Input<string>;
}
