import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a resource to create an organizational unit.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.organizations.OrganizationalUnit("example", {parentId: aws_organizations_organization.example.roots[0].id});
 * ```
 *
 * ## Import
 *
 * AWS Organizations Organizational Units can be imported by using the `id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:organizations/organizationalUnit:OrganizationalUnit example ou-1234567
 * ```
 */
export declare class OrganizationalUnit extends pulumi.CustomResource {
    /**
     * Get an existing OrganizationalUnit resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: OrganizationalUnitState, opts?: pulumi.CustomResourceOptions): OrganizationalUnit;
    /**
     * Returns true if the given object is an instance of OrganizationalUnit.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OrganizationalUnit;
    /**
     * List of child accounts for this Organizational Unit. Does not return account information for child Organizational Units. All elements have these attributes:
     */
    readonly accounts: pulumi.Output<outputs.organizations.OrganizationalUnitAccount[]>;
    /**
     * ARN of the organizational unit
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name for the organizational unit
     */
    readonly name: pulumi.Output<string>;
    /**
     * ID of the parent organizational unit, which may be the root
     */
    readonly parentId: pulumi.Output<string>;
    /**
     * Create a OrganizationalUnit resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: OrganizationalUnitArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering OrganizationalUnit resources.
 */
export interface OrganizationalUnitState {
    /**
     * List of child accounts for this Organizational Unit. Does not return account information for child Organizational Units. All elements have these attributes:
     */
    readonly accounts?: pulumi.Input<pulumi.Input<inputs.organizations.OrganizationalUnitAccount>[]>;
    /**
     * ARN of the organizational unit
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The name for the organizational unit
     */
    readonly name?: pulumi.Input<string>;
    /**
     * ID of the parent organizational unit, which may be the root
     */
    readonly parentId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a OrganizationalUnit resource.
 */
export interface OrganizationalUnitArgs {
    /**
     * The name for the organizational unit
     */
    readonly name?: pulumi.Input<string>;
    /**
     * ID of the parent organizational unit, which may be the root
     */
    readonly parentId: pulumi.Input<string>;
}
