import * as pulumi from "@pulumi/pulumi";
/**
 * Provides details about an Outposts Outpost.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.outposts.getOutpost({
 *     name: "example",
 * }, { async: true }));
 * ```
 */
export declare function getOutpost(args?: GetOutpostArgs, opts?: pulumi.InvokeOptions): Promise<GetOutpostResult>;
/**
 * A collection of arguments for invoking getOutpost.
 */
export interface GetOutpostArgs {
    /**
     * Amazon Resource Name (ARN).
     */
    readonly arn?: string;
    /**
     * Identifier of the Outpost.
     */
    readonly id?: string;
    /**
     * Name of the Outpost.
     */
    readonly name?: string;
}
/**
 * A collection of values returned by getOutpost.
 */
export interface GetOutpostResult {
    readonly arn: string;
    /**
     * Availability Zone name.
     */
    readonly availabilityZone: string;
    /**
     * Availability Zone identifier.
     */
    readonly availabilityZoneId: string;
    /**
     * Description.
     */
    readonly description: string;
    readonly id: string;
    readonly name: string;
    /**
     * AWS Account identifier of the Outpost owner.
     */
    readonly ownerId: string;
    /**
     * Site identifier.
     */
    readonly siteId: string;
}
