import * as pulumi from "@pulumi/pulumi";
/**
 * Provides details about multiple Outposts.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = aws.outposts.getOutposts({
 *     siteId: data.aws_outposts_site.id,
 * });
 * ```
 */
export declare function getOutposts(args?: GetOutpostsArgs, opts?: pulumi.InvokeOptions): Promise<GetOutpostsResult>;
/**
 * A collection of arguments for invoking getOutposts.
 */
export interface GetOutpostsArgs {
    /**
     * Availability Zone name.
     */
    readonly availabilityZone?: string;
    /**
     * Availability Zone identifier.
     */
    readonly availabilityZoneId?: string;
    /**
     * Site identifier.
     */
    readonly siteId?: string;
}
/**
 * A collection of values returned by getOutposts.
 */
export interface GetOutpostsResult {
    /**
     * Set of Amazon Resource Names (ARNs).
     */
    readonly arns: string[];
    readonly availabilityZone: string;
    readonly availabilityZoneId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * Set of identifiers.
     */
    readonly ids: string[];
    readonly siteId: string;
}
