import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a Pinpoint App resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.pinpoint.App("example", {
 *     limits: {
 *         maximumDuration: 600,
 *     },
 *     quietTime: {
 *         end: "06:00",
 *         start: "00:00",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * Pinpoint App can be imported using the `application-id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:pinpoint/app:App name application-id
 * ```
 */
export declare class App extends pulumi.CustomResource {
    /**
     * Get an existing App resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AppState, opts?: pulumi.CustomResourceOptions): App;
    /**
     * Returns true if the given object is an instance of App.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is App;
    /**
     * The Application ID of the Pinpoint App.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * Amazon Resource Name (ARN) of the PinPoint Application
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The default campaign limits for the app. These limits apply to each campaign for the app, unless the campaign overrides the default with limits of its own
     */
    readonly campaignHook: pulumi.Output<outputs.pinpoint.AppCampaignHook | undefined>;
    /**
     * The default campaign limits for the app. These limits apply to each campaign for the app, unless the campaign overrides the default with limits of its own
     */
    readonly limits: pulumi.Output<outputs.pinpoint.AppLimits | undefined>;
    /**
     * The application name. By default generated by this provider
     */
    readonly name: pulumi.Output<string>;
    /**
     * The name of the Pinpoint application. Conflicts with `name`
     */
    readonly namePrefix: pulumi.Output<string | undefined>;
    /**
     * The default quiet time for the app. Each campaign for this app sends no messages during this time unless the campaign overrides the default with a quiet time of its own
     */
    readonly quietTime: pulumi.Output<outputs.pinpoint.AppQuietTime | undefined>;
    /**
     * Key-value map of resource tags
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a App resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AppArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering App resources.
 */
export interface AppState {
    /**
     * The Application ID of the Pinpoint App.
     */
    readonly applicationId?: pulumi.Input<string>;
    /**
     * Amazon Resource Name (ARN) of the PinPoint Application
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The default campaign limits for the app. These limits apply to each campaign for the app, unless the campaign overrides the default with limits of its own
     */
    readonly campaignHook?: pulumi.Input<inputs.pinpoint.AppCampaignHook>;
    /**
     * The default campaign limits for the app. These limits apply to each campaign for the app, unless the campaign overrides the default with limits of its own
     */
    readonly limits?: pulumi.Input<inputs.pinpoint.AppLimits>;
    /**
     * The application name. By default generated by this provider
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The name of the Pinpoint application. Conflicts with `name`
     */
    readonly namePrefix?: pulumi.Input<string>;
    /**
     * The default quiet time for the app. Each campaign for this app sends no messages during this time unless the campaign overrides the default with a quiet time of its own
     */
    readonly quietTime?: pulumi.Input<inputs.pinpoint.AppQuietTime>;
    /**
     * Key-value map of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a App resource.
 */
export interface AppArgs {
    /**
     * The default campaign limits for the app. These limits apply to each campaign for the app, unless the campaign overrides the default with limits of its own
     */
    readonly campaignHook?: pulumi.Input<inputs.pinpoint.AppCampaignHook>;
    /**
     * The default campaign limits for the app. These limits apply to each campaign for the app, unless the campaign overrides the default with limits of its own
     */
    readonly limits?: pulumi.Input<inputs.pinpoint.AppLimits>;
    /**
     * The application name. By default generated by this provider
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The name of the Pinpoint application. Conflicts with `name`
     */
    readonly namePrefix?: pulumi.Input<string>;
    /**
     * The default quiet time for the app. Each campaign for this app sends no messages during this time unless the campaign overrides the default with a quiet time of its own
     */
    readonly quietTime?: pulumi.Input<inputs.pinpoint.AppQuietTime>;
    /**
     * Key-value map of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
