import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Pinpoint SMS Channel resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const app = new aws.pinpoint.App("app", {});
 * const sms = new aws.pinpoint.SmsChannel("sms", {applicationId: app.applicationId});
 * ```
 *
 * ## Import
 *
 * Pinpoint SMS Channel can be imported using the `application-id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:pinpoint/smsChannel:SmsChannel sms application-id
 * ```
 */
export declare class SmsChannel extends pulumi.CustomResource {
    /**
     * Get an existing SmsChannel resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SmsChannelState, opts?: pulumi.CustomResourceOptions): SmsChannel;
    /**
     * Returns true if the given object is an instance of SmsChannel.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SmsChannel;
    /**
     * The application ID.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * Whether the channel is enabled or disabled. Defaults to `true`.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * Promotional messages per second that can be sent.
     */
    readonly promotionalMessagesPerSecond: pulumi.Output<number>;
    /**
     * Sender identifier of your messages.
     */
    readonly senderId: pulumi.Output<string | undefined>;
    /**
     * The Short Code registered with the phone provider.
     */
    readonly shortCode: pulumi.Output<string | undefined>;
    /**
     * Transactional messages per second that can be sent.
     */
    readonly transactionalMessagesPerSecond: pulumi.Output<number>;
    /**
     * Create a SmsChannel resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SmsChannelArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SmsChannel resources.
 */
export interface SmsChannelState {
    /**
     * The application ID.
     */
    readonly applicationId?: pulumi.Input<string>;
    /**
     * Whether the channel is enabled or disabled. Defaults to `true`.
     */
    readonly enabled?: pulumi.Input<boolean>;
    /**
     * Promotional messages per second that can be sent.
     */
    readonly promotionalMessagesPerSecond?: pulumi.Input<number>;
    /**
     * Sender identifier of your messages.
     */
    readonly senderId?: pulumi.Input<string>;
    /**
     * The Short Code registered with the phone provider.
     */
    readonly shortCode?: pulumi.Input<string>;
    /**
     * Transactional messages per second that can be sent.
     */
    readonly transactionalMessagesPerSecond?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a SmsChannel resource.
 */
export interface SmsChannelArgs {
    /**
     * The application ID.
     */
    readonly applicationId: pulumi.Input<string>;
    /**
     * Whether the channel is enabled or disabled. Defaults to `true`.
     */
    readonly enabled?: pulumi.Input<boolean>;
    /**
     * Sender identifier of your messages.
     */
    readonly senderId?: pulumi.Input<string>;
    /**
     * The Short Code registered with the phone provider.
     */
    readonly shortCode?: pulumi.Input<string>;
}
