import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to fetch information about a Quantum Ledger Database.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.qldb.getLedger({
 *     name: "an_example_ledger",
 * }, { async: true }));
 * ```
 */
export declare function getLedger(args: GetLedgerArgs, opts?: pulumi.InvokeOptions): Promise<GetLedgerResult>;
/**
 * A collection of arguments for invoking getLedger.
 */
export interface GetLedgerArgs {
    /**
     * The friendly name of the ledger to match.
     */
    readonly name: string;
}
/**
 * A collection of values returned by getLedger.
 */
export interface GetLedgerResult {
    /**
     * Amazon Resource Name (ARN) of the ledger.
     */
    readonly arn: string;
    /**
     * Deletion protection on the QLDB Ledger instance. Set to `true` by default.
     */
    readonly deletionProtection: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
}
