import * as pulumi from "@pulumi/pulumi";
/**
 * Resource for managing QuickSight Group
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.quicksight.Group("example", {
 *     groupName: "tf-example",
 * });
 * ```
 *
 * ## Import
 *
 * QuickSight Group can be imported using the aws account id, namespace and group name separated by `/`.
 *
 * ```sh
 *  $ pulumi import aws:quicksight/group:Group example 123456789123/default/tf-example
 * ```
 */
export declare class Group extends pulumi.CustomResource {
    /**
     * Get an existing Group resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: GroupState, opts?: pulumi.CustomResourceOptions): Group;
    /**
     * Returns true if the given object is an instance of Group.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Group;
    /**
     * Amazon Resource Name (ARN) of group
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
     */
    readonly awsAccountId: pulumi.Output<string>;
    /**
     * A description for the group.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * A name for the group.
     */
    readonly groupName: pulumi.Output<string>;
    /**
     * The namespace. Currently, you should set this to `default`.
     */
    readonly namespace: pulumi.Output<string | undefined>;
    /**
     * Create a Group resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: GroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Group resources.
 */
export interface GroupState {
    /**
     * Amazon Resource Name (ARN) of group
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
     */
    readonly awsAccountId?: pulumi.Input<string>;
    /**
     * A description for the group.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * A name for the group.
     */
    readonly groupName?: pulumi.Input<string>;
    /**
     * The namespace. Currently, you should set this to `default`.
     */
    readonly namespace?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Group resource.
 */
export interface GroupArgs {
    /**
     * The ID for the AWS account that the group is in. Currently, you use the ID for the AWS account that contains your Amazon QuickSight account.
     */
    readonly awsAccountId?: pulumi.Input<string>;
    /**
     * A description for the group.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * A name for the group.
     */
    readonly groupName: pulumi.Input<string>;
    /**
     * The namespace. Currently, you should set this to `default`.
     */
    readonly namespace?: pulumi.Input<string>;
}
