import * as pulumi from "@pulumi/pulumi";
/**
 * Information about an RDS Certificate.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.rds.getCertificate({
 *     latestValidTill: true,
 * }, { async: true }));
 * ```
 */
export declare function getCertificate(args?: GetCertificateArgs, opts?: pulumi.InvokeOptions): Promise<GetCertificateResult>;
/**
 * A collection of arguments for invoking getCertificate.
 */
export interface GetCertificateArgs {
    /**
     * Certificate identifier. For example, `rds-ca-2019`.
     */
    readonly id?: string;
    /**
     * When enabled, returns the certificate with the latest `ValidTill`.
     */
    readonly latestValidTill?: boolean;
}
/**
 * A collection of values returned by getCertificate.
 */
export interface GetCertificateResult {
    /**
     * Amazon Resource Name (ARN) of the certificate.
     */
    readonly arn: string;
    /**
     * Type of certificate. For example, `CA`.
     */
    readonly certificateType: string;
    /**
     * Boolean whether there is an override for the default certificate identifier.
     */
    readonly customerOverride: boolean;
    /**
     * If there is an override for the default certificate identifier, when the override expires.
     */
    readonly customerOverrideValidTill: string;
    readonly id: string;
    readonly latestValidTill?: boolean;
    /**
     * Thumbprint of the certificate.
     */
    readonly thumbprint: string;
    /**
     * [RFC3339 format](https://tools.ietf.org/html/rfc3339#section-5.8) of certificate starting validity date.
     */
    readonly validFrom: string;
    /**
     * [RFC3339 format](https://tools.ietf.org/html/rfc3339#section-5.8) of certificate ending validity date.
     */
    readonly validTill: string;
}
