import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get information about an RDS subnet group.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const database = pulumi.output(aws.rds.getSubnetGroup({
 *     name: "my-test-database-subnet-group",
 * }, { async: true }));
 * ```
 */
export declare function getSubnetGroup(args: GetSubnetGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetSubnetGroupResult>;
/**
 * A collection of arguments for invoking getSubnetGroup.
 */
export interface GetSubnetGroupArgs {
    /**
     * The name of the RDS database subnet group.
     */
    readonly name: string;
}
/**
 * A collection of values returned by getSubnetGroup.
 */
export interface GetSubnetGroupResult {
    /**
     * The Amazon Resource Name (ARN) for the DB subnet group.
     */
    readonly arn: string;
    /**
     * Provides the description of the DB subnet group.
     */
    readonly description: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
    /**
     * Provides the status of the DB subnet group.
     */
    readonly status: string;
    /**
     * Contains a list of subnet identifiers.
     */
    readonly subnetIds: string[];
    /**
     * Provides the VPC ID of the subnet group.
     */
    readonly vpcId: string;
}
