import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * `aws.route53.ResolverEndpoint` provides details about a specific Route53 Resolver Endpoint.
 *
 * This data source allows to find a list of IPaddresses associated with a specific Route53 Resolver Endpoint.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.route53.getResolverEndpoint({
 *     resolverEndpointId: "rslvr-in-1abc2345ef678g91h",
 * }, { async: true }));
 * ```
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.route53.getResolverEndpoint({
 *     filters: [{
 *         name: "NAME",
 *         values: ["MyResolverExampleName"],
 *     }],
 * }, { async: true }));
 * ```
 */
export declare function getResolverEndpoint(args?: GetResolverEndpointArgs, opts?: pulumi.InvokeOptions): Promise<GetResolverEndpointResult>;
/**
 * A collection of arguments for invoking getResolverEndpoint.
 */
export interface GetResolverEndpointArgs {
    /**
     * One or more name/value pairs to use as filters. There are
     * several valid keys, for a full reference, check out
     * [Route53resolver Filter value in the AWS API reference][1].
     */
    readonly filters?: inputs.route53.GetResolverEndpointFilter[];
    /**
     * The ID of the Route53 Resolver Endpoint.
     */
    readonly resolverEndpointId?: string;
}
/**
 * A collection of values returned by getResolverEndpoint.
 */
export interface GetResolverEndpointResult {
    readonly arn: string;
    readonly direction: string;
    readonly filters?: outputs.route53.GetResolverEndpointFilter[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly ipAddresses: string[];
    readonly name: string;
    readonly resolverEndpointId?: string;
    readonly status: string;
    readonly vpcId: string;
}
