import * as pulumi from "@pulumi/pulumi";
/**
 * `aws.route53.getResolverRules` provides details about a set of Route53 Resolver rules.
 *
 * ## Example Usage
 *
 * Retrieving the default resolver rule.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.route53.getResolverRules({
 *     ownerId: "Route 53 Resolver",
 *     ruleType: "RECURSIVE",
 *     shareStatus: "NOT_SHARED",
 * }, { async: true }));
 * ```
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.route53.getResolverRules({
 *     ruleType: "FORWARD",
 *     shareStatus: "SHARED_WITH_ME",
 * }, { async: true }));
 * ```
 */
export declare function getResolverRules(args?: GetResolverRulesArgs, opts?: pulumi.InvokeOptions): Promise<GetResolverRulesResult>;
/**
 * A collection of arguments for invoking getResolverRules.
 */
export interface GetResolverRulesArgs {
    /**
     * When the desired resolver rules are shared with another AWS account, the account ID of the account that the rules are shared with.
     */
    readonly ownerId?: string;
    /**
     * The ID of the outbound resolver endpoint for the desired resolver rules.
     */
    readonly resolverEndpointId?: string;
    /**
     * The rule type of the desired resolver rules. Valid values are `FORWARD`, `SYSTEM` and `RECURSIVE`.
     */
    readonly ruleType?: string;
    /**
     * Whether the desired resolver rules are shared and, if so, whether the current account is sharing the rules with another account, or another account is sharing the rules with the current account. Valid values are `NOT_SHARED`, `SHARED_BY_ME` or `SHARED_WITH_ME`
     */
    readonly shareStatus?: string;
}
/**
 * A collection of values returned by getResolverRules.
 */
export interface GetResolverRulesResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly ownerId?: string;
    readonly resolverEndpointId?: string;
    /**
     * The IDs of the matched resolver rules.
     */
    readonly resolverRuleIds: string[];
    readonly ruleType?: string;
    readonly shareStatus?: string;
}
