import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Sagemaker Model Package Group resource.
 *
 * ## Example Usage
 * ### Basic usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.sagemaker.ModelPackageGroup("example", {
 *     modelPackageGroupName: "example",
 * });
 * ```
 *
 * ## Import
 *
 * Sagemaker Code Model Package Groups can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:sagemaker/modelPackageGroup:ModelPackageGroup test_model_package_group my-code-repo
 * ```
 */
export declare class ModelPackageGroup extends pulumi.CustomResource {
    /**
     * Get an existing ModelPackageGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ModelPackageGroupState, opts?: pulumi.CustomResourceOptions): ModelPackageGroup;
    /**
     * Returns true if the given object is an instance of ModelPackageGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ModelPackageGroup;
    /**
     * The Amazon Resource Name (ARN) assigned by AWS to this Model Package Group.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A description for the model group.
     */
    readonly modelPackageGroupDescription: pulumi.Output<string | undefined>;
    /**
     * The name of the model group.
     */
    readonly modelPackageGroupName: pulumi.Output<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a ModelPackageGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ModelPackageGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ModelPackageGroup resources.
 */
export interface ModelPackageGroupState {
    /**
     * The Amazon Resource Name (ARN) assigned by AWS to this Model Package Group.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * A description for the model group.
     */
    readonly modelPackageGroupDescription?: pulumi.Input<string>;
    /**
     * The name of the model group.
     */
    readonly modelPackageGroupName?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a ModelPackageGroup resource.
 */
export interface ModelPackageGroupArgs {
    /**
     * A description for the model group.
     */
    readonly modelPackageGroupDescription?: pulumi.Input<string>;
    /**
     * The name of the model group.
     */
    readonly modelPackageGroupName: pulumi.Input<string>;
    /**
     * A map of tags to assign to the resource.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
