import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a lifecycle configuration for SageMaker Notebook Instances.
 *
 * ## Import
 *
 * Models can be imported using the `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:sagemaker/notebookInstanceLifecycleConfiguration:NotebookInstanceLifecycleConfiguration lc foo
 * ```
 */
export declare class NotebookInstanceLifecycleConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing NotebookInstanceLifecycleConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: NotebookInstanceLifecycleConfigurationState, opts?: pulumi.CustomResourceOptions): NotebookInstanceLifecycleConfiguration;
    /**
     * Returns true if the given object is an instance of NotebookInstanceLifecycleConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NotebookInstanceLifecycleConfiguration;
    /**
     * The Amazon Resource Name (ARN) assigned by AWS to this lifecycle configuration.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the lifecycle configuration (must be unique). If omitted, this provider will assign a random, unique name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A shell script (base64-encoded) that runs only once when the SageMaker Notebook Instance is created.
     */
    readonly onCreate: pulumi.Output<string | undefined>;
    /**
     * A shell script (base64-encoded) that runs every time the SageMaker Notebook Instance is started including the time it's created.
     */
    readonly onStart: pulumi.Output<string | undefined>;
    /**
     * Create a NotebookInstanceLifecycleConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: NotebookInstanceLifecycleConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering NotebookInstanceLifecycleConfiguration resources.
 */
export interface NotebookInstanceLifecycleConfigurationState {
    /**
     * The Amazon Resource Name (ARN) assigned by AWS to this lifecycle configuration.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The name of the lifecycle configuration (must be unique). If omitted, this provider will assign a random, unique name.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A shell script (base64-encoded) that runs only once when the SageMaker Notebook Instance is created.
     */
    readonly onCreate?: pulumi.Input<string>;
    /**
     * A shell script (base64-encoded) that runs every time the SageMaker Notebook Instance is started including the time it's created.
     */
    readonly onStart?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a NotebookInstanceLifecycleConfiguration resource.
 */
export interface NotebookInstanceLifecycleConfigurationArgs {
    /**
     * The name of the lifecycle configuration (must be unique). If omitted, this provider will assign a random, unique name.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A shell script (base64-encoded) that runs only once when the SageMaker Notebook Instance is created.
     */
    readonly onCreate?: pulumi.Input<string>;
    /**
     * A shell script (base64-encoded) that runs every time the SageMaker Notebook Instance is started including the time it's created.
     */
    readonly onStart?: pulumi.Input<string>;
}
