import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Retrieve information about a Secrets Manager secret rotation. To retrieve secret metadata, see the `aws.secretsmanager.Secret` data source. To retrieve a secret value, see the `aws.secretsmanager.SecretVersion` data source.
 *
 * ## Example Usage
 * ### Retrieve Secret Rotation Configuration
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = aws.secretsmanager.getSecretRotation({
 *     secretId: data.aws_secretsmanager_secret.example.id,
 * });
 * ```
 */
export declare function getSecretRotation(args: GetSecretRotationArgs, opts?: pulumi.InvokeOptions): Promise<GetSecretRotationResult>;
/**
 * A collection of arguments for invoking getSecretRotation.
 */
export interface GetSecretRotationArgs {
    /**
     * Specifies the secret containing the version that you want to retrieve. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret.
     */
    readonly secretId: string;
}
/**
 * A collection of values returned by getSecretRotation.
 */
export interface GetSecretRotationResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The ARN of the secret.
     */
    readonly rotationEnabled: boolean;
    /**
     * The decrypted part of the protected secret information that was originally provided as a string.
     */
    readonly rotationLambdaArn: string;
    /**
     * The decrypted part of the protected secret information that was originally provided as a binary. Base64 encoded.
     */
    readonly rotationRules: outputs.secretsmanager.GetSecretRotationRotationRule[];
    readonly secretId: string;
}
