import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get information about an AWS Serverless Application Repository application. For example, this can be used to determine the required `capabilities` for an application.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleApplication = aws.serverlessrepository.getApplication({
 *     applicationId: "arn:aws:serverlessrepo:us-east-1:123456789012:applications/ExampleApplication",
 * });
 * const exampleCloudFormationStack = new aws.serverlessrepository.CloudFormationStack("exampleCloudFormationStack", {
 *     applicationId: exampleApplication.then(exampleApplication => exampleApplication.applicationId),
 *     semanticVersion: exampleApplication.then(exampleApplication => exampleApplication.semanticVersion),
 *     capabilities: exampleApplication.then(exampleApplication => exampleApplication.requiredCapabilities),
 * });
 * ```
 */
export declare function getApplication(args: GetApplicationArgs, opts?: pulumi.InvokeOptions): Promise<GetApplicationResult>;
/**
 * A collection of arguments for invoking getApplication.
 */
export interface GetApplicationArgs {
    /**
     * The ARN of the application.
     */
    readonly applicationId: string;
    /**
     * The requested version of the application. By default, retrieves the latest version.
     */
    readonly semanticVersion?: string;
}
/**
 * A collection of values returned by getApplication.
 */
export interface GetApplicationResult {
    /**
     * The ARN of the application.
     */
    readonly applicationId: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The name of the application.
     */
    readonly name: string;
    /**
     * A list of capabilities describing the permissions needed to deploy the application.
     */
    readonly requiredCapabilities: string[];
    readonly semanticVersion: string;
    /**
     * A URL pointing to the source code of the application version.
     */
    readonly sourceCodeUrl: string;
    /**
     * A URL pointing to the Cloud Formation template for the application version.
     */
    readonly templateUrl: string;
}
