import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a resource to create a Service Catalog Portfolio.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const portfolio = new aws.servicecatalog.Portfolio("portfolio", {
 *     description: "List of my organizations apps",
 *     providerName: "Brett",
 * });
 * ```
 *
 * ## Import
 *
 * Service Catalog Portfolios can be imported using the `service catalog portfolio id`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:servicecatalog/portfolio:Portfolio testfolio port-12344321
 * ```
 */
export declare class Portfolio extends pulumi.CustomResource {
    /**
     * Get an existing Portfolio resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: PortfolioState, opts?: pulumi.CustomResourceOptions): Portfolio;
    /**
     * Returns true if the given object is an instance of Portfolio.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Portfolio;
    readonly arn: pulumi.Output<string>;
    readonly createdTime: pulumi.Output<string>;
    /**
     * Description of the portfolio
     */
    readonly description: pulumi.Output<string>;
    /**
     * The name of the portfolio.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Name of the person or organization who owns the portfolio.
     */
    readonly providerName: pulumi.Output<string | undefined>;
    /**
     * Tags to apply to the connection.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Portfolio resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: PortfolioArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Portfolio resources.
 */
export interface PortfolioState {
    readonly arn?: pulumi.Input<string>;
    readonly createdTime?: pulumi.Input<string>;
    /**
     * Description of the portfolio
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The name of the portfolio.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Name of the person or organization who owns the portfolio.
     */
    readonly providerName?: pulumi.Input<string>;
    /**
     * Tags to apply to the connection.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a Portfolio resource.
 */
export interface PortfolioArgs {
    /**
     * Description of the portfolio
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The name of the portfolio.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Name of the person or organization who owns the portfolio.
     */
    readonly providerName?: pulumi.Input<string>;
    /**
     * Tags to apply to the connection.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
