import * as pulumi from "@pulumi/pulumi";
/**
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.servicediscovery.HttpNamespace("example", {
 *     description: "example",
 * });
 * ```
 *
 * ## Import
 *
 * Service Discovery HTTP Namespace can be imported using the namespace ID, e.g.
 *
 * ```sh
 *  $ pulumi import aws:servicediscovery/httpNamespace:HttpNamespace example ns-1234567890
 * ```
 */
export declare class HttpNamespace extends pulumi.CustomResource {
    /**
     * Get an existing HttpNamespace resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: HttpNamespaceState, opts?: pulumi.CustomResourceOptions): HttpNamespace;
    /**
     * Returns true if the given object is an instance of HttpNamespace.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is HttpNamespace;
    /**
     * The ARN that Amazon Route 53 assigns to the namespace when you create it.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The description that you specify for the namespace when you create it.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the http namespace.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A map of tags to assign to the namespace.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a HttpNamespace resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: HttpNamespaceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering HttpNamespace resources.
 */
export interface HttpNamespaceState {
    /**
     * The ARN that Amazon Route 53 assigns to the namespace when you create it.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The description that you specify for the namespace when you create it.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The name of the http namespace.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the namespace.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a HttpNamespace resource.
 */
export interface HttpNamespaceArgs {
    /**
     * The description that you specify for the namespace when you create it.
     */
    readonly description?: pulumi.Input<string>;
    /**
     * The name of the http namespace.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * A map of tags to assign to the namespace.
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
