import * as pulumi from "@pulumi/pulumi";
/**
 * Manages an individual Service Quota.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.servicequotas.ServiceQuota("example", {
 *     quotaCode: "L-F678F1CE",
 *     serviceCode: "vpc",
 *     value: 75,
 * });
 * ```
 *
 * ## Import
 *
 * ~> *NOTE* This resource does not require explicit import and will assume management of an existing service quota on resource creation. `aws_servicequotas_service_quota` can be imported by using the service code and quota code, separated by a front slash (`/`), e.g.
 *
 * ```sh
 *  $ pulumi import aws:servicequotas/serviceQuota:ServiceQuota example vpc/L-F678F1CE
 * ```
 */
export declare class ServiceQuota extends pulumi.CustomResource {
    /**
     * Get an existing ServiceQuota resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ServiceQuotaState, opts?: pulumi.CustomResourceOptions): ServiceQuota;
    /**
     * Returns true if the given object is an instance of ServiceQuota.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceQuota;
    /**
     * Whether the service quota can be increased.
     */
    readonly adjustable: pulumi.Output<boolean>;
    /**
     * Amazon Resource Name (ARN) of the service quota.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Default value of the service quota.
     */
    readonly defaultValue: pulumi.Output<number>;
    /**
     * Code of the service quota to track. For example: `L-F678F1CE`. Available values can be found with the [AWS CLI service-quotas list-service-quotas command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-service-quotas.html).
     */
    readonly quotaCode: pulumi.Output<string>;
    /**
     * Name of the quota.
     */
    readonly quotaName: pulumi.Output<string>;
    readonly requestId: pulumi.Output<string>;
    readonly requestStatus: pulumi.Output<string>;
    /**
     * Code of the service to track. For example: `vpc`. Available values can be found with the [AWS CLI service-quotas list-services command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-services.html).
     */
    readonly serviceCode: pulumi.Output<string>;
    /**
     * Name of the service.
     */
    readonly serviceName: pulumi.Output<string>;
    /**
     * Float specifying the desired value for the service quota. If the desired value is higher than the current value, a quota increase request is submitted. When a known request is submitted and pending, the value reflects the desired value of the pending request.
     */
    readonly value: pulumi.Output<number>;
    /**
     * Create a ServiceQuota resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceQuotaArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ServiceQuota resources.
 */
export interface ServiceQuotaState {
    /**
     * Whether the service quota can be increased.
     */
    readonly adjustable?: pulumi.Input<boolean>;
    /**
     * Amazon Resource Name (ARN) of the service quota.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Default value of the service quota.
     */
    readonly defaultValue?: pulumi.Input<number>;
    /**
     * Code of the service quota to track. For example: `L-F678F1CE`. Available values can be found with the [AWS CLI service-quotas list-service-quotas command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-service-quotas.html).
     */
    readonly quotaCode?: pulumi.Input<string>;
    /**
     * Name of the quota.
     */
    readonly quotaName?: pulumi.Input<string>;
    readonly requestId?: pulumi.Input<string>;
    readonly requestStatus?: pulumi.Input<string>;
    /**
     * Code of the service to track. For example: `vpc`. Available values can be found with the [AWS CLI service-quotas list-services command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-services.html).
     */
    readonly serviceCode?: pulumi.Input<string>;
    /**
     * Name of the service.
     */
    readonly serviceName?: pulumi.Input<string>;
    /**
     * Float specifying the desired value for the service quota. If the desired value is higher than the current value, a quota increase request is submitted. When a known request is submitted and pending, the value reflects the desired value of the pending request.
     */
    readonly value?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a ServiceQuota resource.
 */
export interface ServiceQuotaArgs {
    /**
     * Code of the service quota to track. For example: `L-F678F1CE`. Available values can be found with the [AWS CLI service-quotas list-service-quotas command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-service-quotas.html).
     */
    readonly quotaCode: pulumi.Input<string>;
    /**
     * Code of the service to track. For example: `vpc`. Available values can be found with the [AWS CLI service-quotas list-services command](https://docs.aws.amazon.com/cli/latest/reference/service-quotas/list-services.html).
     */
    readonly serviceCode: pulumi.Input<string>;
    /**
     * Float specifying the desired value for the service quota. If the desired value is higher than the current value, a quota increase request is submitted. When a known request is submitted and pending, the value reflects the desired value of the pending request.
     */
    readonly value: pulumi.Input<number>;
}
