import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a resource to designate the active SES receipt rule set
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const main = new aws.ses.ActiveReceiptRuleSet("main", {
 *     ruleSetName: "primary-rules",
 * });
 * ```
 */
export declare class ActiveReceiptRuleSet extends pulumi.CustomResource {
    /**
     * Get an existing ActiveReceiptRuleSet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ActiveReceiptRuleSetState, opts?: pulumi.CustomResourceOptions): ActiveReceiptRuleSet;
    /**
     * Returns true if the given object is an instance of ActiveReceiptRuleSet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ActiveReceiptRuleSet;
    /**
     * The SES receipt rule set ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the rule set
     */
    readonly ruleSetName: pulumi.Output<string>;
    /**
     * Create a ActiveReceiptRuleSet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ActiveReceiptRuleSetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ActiveReceiptRuleSet resources.
 */
export interface ActiveReceiptRuleSetState {
    /**
     * The SES receipt rule set ARN.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The name of the rule set
     */
    readonly ruleSetName?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ActiveReceiptRuleSet resource.
 */
export interface ActiveReceiptRuleSetArgs {
    /**
     * The name of the rule set
     */
    readonly ruleSetName: pulumi.Input<string>;
}
