import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides an SES configuration set resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = new aws.ses.ConfigurationSet("test", {});
 * ```
 * ### Require TLS Connections
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = new aws.ses.ConfigurationSet("test", {
 *     deliveryOptions: {
 *         tlsPolicy: "Require",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * SES Configuration Sets can be imported using their `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ses/configurationSet:ConfigurationSet test some-configuration-set-test
 * ```
 */
export declare class ConfigurationSet extends pulumi.CustomResource {
    /**
     * Get an existing ConfigurationSet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ConfigurationSetState, opts?: pulumi.CustomResourceOptions): ConfigurationSet;
    /**
     * Returns true if the given object is an instance of ConfigurationSet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ConfigurationSet;
    /**
     * SES configuration set ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Configuration block. Detailed below.
     */
    readonly deliveryOptions: pulumi.Output<outputs.ses.ConfigurationSetDeliveryOptions | undefined>;
    /**
     * Name of the configuration set.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a ConfigurationSet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ConfigurationSetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ConfigurationSet resources.
 */
export interface ConfigurationSetState {
    /**
     * SES configuration set ARN.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * Configuration block. Detailed below.
     */
    readonly deliveryOptions?: pulumi.Input<inputs.ses.ConfigurationSetDeliveryOptions>;
    /**
     * Name of the configuration set.
     */
    readonly name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ConfigurationSet resource.
 */
export interface ConfigurationSetArgs {
    /**
     * Configuration block. Detailed below.
     */
    readonly deliveryOptions?: pulumi.Input<inputs.ses.ConfigurationSetDeliveryOptions>;
    /**
     * Name of the configuration set.
     */
    readonly name?: pulumi.Input<string>;
}
