import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an SES email identity resource
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = new aws.ses.EmailIdentity("example", {
 *     email: "email@example.com",
 * });
 * ```
 *
 * ## Import
 *
 * SES email identities can be imported using the email address.
 *
 * ```sh
 *  $ pulumi import aws:ses/emailIdentity:EmailIdentity example email@example.com
 * ```
 */
export declare class EmailIdentity extends pulumi.CustomResource {
    /**
     * Get an existing EmailIdentity resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: EmailIdentityState, opts?: pulumi.CustomResourceOptions): EmailIdentity;
    /**
     * Returns true if the given object is an instance of EmailIdentity.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EmailIdentity;
    /**
     * The ARN of the email identity.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The email address to assign to SES
     */
    readonly email: pulumi.Output<string>;
    /**
     * Create a EmailIdentity resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EmailIdentityArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering EmailIdentity resources.
 */
export interface EmailIdentityState {
    /**
     * The ARN of the email identity.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The email address to assign to SES
     */
    readonly email?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a EmailIdentity resource.
 */
export interface EmailIdentityArgs {
    /**
     * The email address to assign to SES
     */
    readonly email: pulumi.Input<string>;
}
