import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an SES receipt filter resource
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const filter = new aws.ses.ReceiptFilter("filter", {
 *     cidr: "10.10.10.10",
 *     policy: "Block",
 * });
 * ```
 *
 * ## Import
 *
 * SES Receipt Filter can be imported using their `name`, e.g.
 *
 * ```sh
 *  $ pulumi import aws:ses/receiptFilter:ReceiptFilter test some-filter
 * ```
 */
export declare class ReceiptFilter extends pulumi.CustomResource {
    /**
     * Get an existing ReceiptFilter resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ReceiptFilterState, opts?: pulumi.CustomResourceOptions): ReceiptFilter;
    /**
     * Returns true if the given object is an instance of ReceiptFilter.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ReceiptFilter;
    /**
     * The SES receipt filter ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The IP address or address range to filter, in CIDR notation
     */
    readonly cidr: pulumi.Output<string>;
    /**
     * The name of the filter
     */
    readonly name: pulumi.Output<string>;
    /**
     * Block or Allow
     */
    readonly policy: pulumi.Output<string>;
    /**
     * Create a ReceiptFilter resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ReceiptFilterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ReceiptFilter resources.
 */
export interface ReceiptFilterState {
    /**
     * The SES receipt filter ARN.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * The IP address or address range to filter, in CIDR notation
     */
    readonly cidr?: pulumi.Input<string>;
    /**
     * The name of the filter
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Block or Allow
     */
    readonly policy?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ReceiptFilter resource.
 */
export interface ReceiptFilterArgs {
    /**
     * The IP address or address range to filter, in CIDR notation
     */
    readonly cidr: pulumi.Input<string>;
    /**
     * The name of the filter
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Block or Allow
     */
    readonly policy: pulumi.Input<string>;
}
