import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Step Functions Activity data source
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const sfnActivity = pulumi.output(aws.sfn.getActivity({
 *     name: "my-activity",
 * }, { async: true }));
 * ```
 */
export declare function getActivity(args?: GetActivityArgs, opts?: pulumi.InvokeOptions): Promise<GetActivityResult>;
/**
 * A collection of arguments for invoking getActivity.
 */
export interface GetActivityArgs {
    /**
     * The Amazon Resource Name (ARN) that identifies the activity.
     */
    readonly arn?: string;
    /**
     * The name that identifies the activity.
     */
    readonly name?: string;
}
/**
 * A collection of values returned by getActivity.
 */
export interface GetActivityResult {
    readonly arn: string;
    /**
     * The date the activity was created.
     */
    readonly creationDate: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
}
