import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Provides information about a Signer Signing Job.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const buildSigningJob = pulumi.output(aws.signer.getSigningJob({
 *     jobId: "9ed7e5c3-b8d4-4da0-8459-44e0b068f7ee",
 * }, { async: true }));
 * ```
 */
export declare function getSigningJob(args: GetSigningJobArgs, opts?: pulumi.InvokeOptions): Promise<GetSigningJobResult>;
/**
 * A collection of arguments for invoking getSigningJob.
 */
export interface GetSigningJobArgs {
    /**
     * The ID of the signing job on output.
     */
    readonly jobId: string;
}
/**
 * A collection of values returned by getSigningJob.
 */
export interface GetSigningJobResult {
    /**
     * Date and time in [RFC3339 format](https://tools.ietf.org/html/rfc3339#section-5.8) that the signing job was completed.
     */
    readonly completedAt: string;
    /**
     * Date and time in [RFC3339 format](https://tools.ietf.org/html/rfc3339#section-5.8) that the signing job was created.
     */
    readonly createdAt: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly jobId: string;
    /**
     * The IAM entity that initiated the signing job.
     */
    readonly jobInvoker: string;
    /**
     * The AWS account ID of the job owner.
     */
    readonly jobOwner: string;
    /**
     * A human-readable name for the signing platform associated with the signing job.
     */
    readonly platformDisplayName: string;
    /**
     * The platform to which your signed code image will be distributed.
     */
    readonly platformId: string;
    /**
     * The name of the profile that initiated the signing operation.
     */
    readonly profileName: string;
    /**
     * The version of the signing profile used to initiate the signing job.
     */
    readonly profileVersion: string;
    /**
     * The IAM principal that requested the signing job.
     */
    readonly requestedBy: string;
    /**
     * A revocation record if the signature generated by the signing job has been revoked. Contains a timestamp and the ID of the IAM entity that revoked the signature.
     */
    readonly revocationRecords: outputs.signer.GetSigningJobRevocationRecord[];
    /**
     * The time when the signature of a signing job expires.
     */
    readonly signatureExpiresAt: string;
    /**
     * Name of the S3 bucket where the signed code image is saved by code signing.
     */
    readonly signedObjects: outputs.signer.GetSigningJobSignedObject[];
    /**
     * The object that contains the name of your S3 bucket or your raw code.
     */
    readonly sources: outputs.signer.GetSigningJobSource[];
    /**
     * Status of the signing job.
     */
    readonly status: string;
    /**
     * String value that contains the status reason.
     */
    readonly statusReason: string;
}
