import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get the ARN of a topic in AWS Simple Notification
 * Service (SNS). By using this data source, you can reference SNS topics
 * without having to hard code the ARNs as input.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.sns.getTopic({
 *     name: "an_example_topic",
 * }, { async: true }));
 * ```
 */
export declare function getTopic(args: GetTopicArgs, opts?: pulumi.InvokeOptions): Promise<GetTopicResult>;
/**
 * A collection of arguments for invoking getTopic.
 */
export interface GetTopicArgs {
    /**
     * The friendly name of the topic to match.
     */
    readonly name: string;
}
/**
 * A collection of values returned by getTopic.
 */
export interface GetTopicResult {
    /**
     * Amazon Resource Name (ARN) of the found topic, suitable for referencing in other resources that support SNS topics.
     */
    readonly arn: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
}
