import * as pulumi from "@pulumi/pulumi";
/**
 * Gets the contents of the specified Systems Manager document.
 *
 * ## Example Usage
 *
 * To get the contents of the document owned by AWS.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const foo = aws.ssm.getDocument({
 *     name: "AWS-GatherSoftwareInventory",
 *     documentFormat: "YAML",
 * });
 * export const content = foo.then(foo => foo.content);
 * ```
 *
 * To get the contents of the custom document.
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = aws.ssm.getDocument({
 *     name: aws_ssm_document.test.name,
 *     documentFormat: "JSON",
 * });
 * ```
 */
export declare function getDocument(args: GetDocumentArgs, opts?: pulumi.InvokeOptions): Promise<GetDocumentResult>;
/**
 * A collection of arguments for invoking getDocument.
 */
export interface GetDocumentArgs {
    /**
     * Returns the document in the specified format. The document format can be either JSON or YAML. JSON is the default format.
     */
    readonly documentFormat?: string;
    /**
     * The document version for which you want information.
     */
    readonly documentVersion?: string;
    /**
     * The name of the Systems Manager document.
     */
    readonly name: string;
}
/**
 * A collection of values returned by getDocument.
 */
export interface GetDocumentResult {
    /**
     * The ARN of the document.
     */
    readonly arn: string;
    /**
     * The contents of the document.
     */
    readonly content: string;
    readonly documentFormat?: string;
    /**
     * The type of the document.
     */
    readonly documentType: string;
    readonly documentVersion?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
}
