import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an SSM Patch Group resource
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const production = new aws.ssm.PatchBaseline("production", {approvedPatches: ["KB123456"]});
 * const patchgroup = new aws.ssm.PatchGroup("patchgroup", {
 *     baselineId: production.id,
 *     patchGroup: "patch-group-name",
 * });
 * ```
 */
export declare class PatchGroup extends pulumi.CustomResource {
    /**
     * Get an existing PatchGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: PatchGroupState, opts?: pulumi.CustomResourceOptions): PatchGroup;
    /**
     * Returns true if the given object is an instance of PatchGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PatchGroup;
    /**
     * The ID of the patch baseline to register the patch group with.
     */
    readonly baselineId: pulumi.Output<string>;
    /**
     * The name of the patch group that should be registered with the patch baseline.
     */
    readonly patchGroup: pulumi.Output<string>;
    /**
     * Create a PatchGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PatchGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering PatchGroup resources.
 */
export interface PatchGroupState {
    /**
     * The ID of the patch baseline to register the patch group with.
     */
    readonly baselineId?: pulumi.Input<string>;
    /**
     * The name of the patch group that should be registered with the patch baseline.
     */
    readonly patchGroup?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a PatchGroup resource.
 */
export interface PatchGroupArgs {
    /**
     * The ID of the patch baseline to register the patch group with.
     */
    readonly baselineId: pulumi.Input<string>;
    /**
     * The name of the patch group that should be registered with the patch baseline.
     */
    readonly patchGroup: pulumi.Input<string>;
}
