import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get a Single Sign-On (SSO) Permission Set.
 */
export declare function getPermissionSet(args: GetPermissionSetArgs, opts?: pulumi.InvokeOptions): Promise<GetPermissionSetResult>;
/**
 * A collection of arguments for invoking getPermissionSet.
 */
export interface GetPermissionSetArgs {
    /**
     * The Amazon Resource Name (ARN) of the permission set.
     */
    readonly arn?: string;
    /**
     * The Amazon Resource Name (ARN) of the SSO Instance associated with the permission set.
     */
    readonly instanceArn: string;
    /**
     * The name of the SSO Permission Set.
     */
    readonly name?: string;
    /**
     * Key-value map of resource tags.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * A collection of values returned by getPermissionSet.
 */
export interface GetPermissionSetResult {
    readonly arn: string;
    readonly createdDate: string;
    /**
     * The description of the Permission Set.
     */
    readonly description: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly instanceArn: string;
    readonly name: string;
    /**
     * The relay state URL used to redirect users within the application during the federation authentication process.
     */
    readonly relayState: string;
    /**
     * The length of time that the application user sessions are valid in the ISO-8601 standard.
     */
    readonly sessionDuration: string;
    /**
     * Key-value map of resource tags.
     */
    readonly tags: {
        [key: string]: string;
    };
}
