import * as pulumi from "@pulumi/pulumi";
/**
 * Provides an IAM managed policy for a Single Sign-On (SSO) Permission Set resource
 *
 * > **NOTE:** Creating this resource will automatically [Provision the Permission Set](https://docs.aws.amazon.com/singlesignon/latest/APIReference/API_ProvisionPermissionSet.html) to apply the corresponding updates to all assigned accounts.
 *
 * ## Import
 *
 * SSO Managed Policy Attachments can be imported using the `managed_policy_arn`, `permission_set_arn`, and `instance_arn` separated by a comma (`,`) e.g.
 *
 * ```sh
 *  $ pulumi import aws:ssoadmin/managedPolicyAttachment:ManagedPolicyAttachment example arn:aws:iam::aws:policy/AlexaForBusinessDeviceSetup,arn:aws:sso:::permissionSet/ssoins-2938j0x8920sbj72/ps-80383020jr9302rk,arn:aws:sso:::instance/ssoins-2938j0x8920sbj72
 * ```
 */
export declare class ManagedPolicyAttachment extends pulumi.CustomResource {
    /**
     * Get an existing ManagedPolicyAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ManagedPolicyAttachmentState, opts?: pulumi.CustomResourceOptions): ManagedPolicyAttachment;
    /**
     * Returns true if the given object is an instance of ManagedPolicyAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ManagedPolicyAttachment;
    /**
     * The Amazon Resource Name (ARN) of the SSO Instance under which the operation will be executed.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * The IAM managed policy Amazon Resource Name (ARN) to be attached to the Permission Set.
     */
    readonly managedPolicyArn: pulumi.Output<string>;
    /**
     * The name of the IAM Managed Policy.
     */
    readonly managedPolicyName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the Permission Set.
     */
    readonly permissionSetArn: pulumi.Output<string>;
    /**
     * Create a ManagedPolicyAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ManagedPolicyAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ManagedPolicyAttachment resources.
 */
export interface ManagedPolicyAttachmentState {
    /**
     * The Amazon Resource Name (ARN) of the SSO Instance under which the operation will be executed.
     */
    readonly instanceArn?: pulumi.Input<string>;
    /**
     * The IAM managed policy Amazon Resource Name (ARN) to be attached to the Permission Set.
     */
    readonly managedPolicyArn?: pulumi.Input<string>;
    /**
     * The name of the IAM Managed Policy.
     */
    readonly managedPolicyName?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the Permission Set.
     */
    readonly permissionSetArn?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ManagedPolicyAttachment resource.
 */
export interface ManagedPolicyAttachmentArgs {
    /**
     * The Amazon Resource Name (ARN) of the SSO Instance under which the operation will be executed.
     */
    readonly instanceArn: pulumi.Input<string>;
    /**
     * The IAM managed policy Amazon Resource Name (ARN) to be attached to the Permission Set.
     */
    readonly managedPolicyArn: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the Permission Set.
     */
    readonly permissionSetArn: pulumi.Input<string>;
}
