import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieve information about a Storage Gateway local disk. The disk identifier is useful for adding the disk as a cache or upload buffer to a gateway.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const test = aws.storagegateway.getLocalDisk({
 *     diskPath: aws_volume_attachment.test.device_name,
 *     gatewayArn: aws_storagegateway_gateway.test.arn,
 * });
 * ```
 */
export declare function getLocalDisk(args: GetLocalDiskArgs, opts?: pulumi.InvokeOptions): Promise<GetLocalDiskResult>;
/**
 * A collection of arguments for invoking getLocalDisk.
 */
export interface GetLocalDiskArgs {
    /**
     * The device node of the local disk to retrieve. For example, `/dev/sdb`.
     */
    readonly diskNode?: string;
    /**
     * The device path of the local disk to retrieve. For example, `/dev/xvdb` or `/dev/nvme1n1`.
     */
    readonly diskPath?: string;
    /**
     * The Amazon Resource Name (ARN) of the gateway.
     */
    readonly gatewayArn: string;
}
/**
 * A collection of values returned by getLocalDisk.
 */
export interface GetLocalDiskResult {
    /**
     * The disk identifier. e.g. `pci-0000:03:00.0-scsi-0:0:0:0`
     */
    readonly diskId: string;
    readonly diskNode?: string;
    readonly diskPath?: string;
    readonly gatewayArn: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
}
