import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a WAF Regional Rule Group Resource
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const exampleRule = new aws.wafregional.Rule("exampleRule", {metricName: "example"});
 * const exampleRuleGroup = new aws.wafregional.RuleGroup("exampleRuleGroup", {
 *     metricName: "example",
 *     activatedRules: [{
 *         action: {
 *             type: "COUNT",
 *         },
 *         priority: 50,
 *         ruleId: exampleRule.id,
 *     }],
 * });
 * ```
 *
 * ## Import
 *
 * WAF Regional Rule Group can be imported using the id, e.g.
 *
 * ```sh
 *  $ pulumi import aws:wafregional/ruleGroup:RuleGroup example a1b2c3d4-d5f6-7777-8888-9999aaaabbbbcccc
 * ```
 */
export declare class RuleGroup extends pulumi.CustomResource {
    /**
     * Get an existing RuleGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RuleGroupState, opts?: pulumi.CustomResourceOptions): RuleGroup;
    /**
     * Returns true if the given object is an instance of RuleGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RuleGroup;
    /**
     * A list of activated rules, see below
     */
    readonly activatedRules: pulumi.Output<outputs.wafregional.RuleGroupActivatedRule[] | undefined>;
    /**
     * The ARN of the WAF Regional Rule Group.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A friendly name for the metrics from the rule group
     */
    readonly metricName: pulumi.Output<string>;
    /**
     * A friendly name of the rule group
     */
    readonly name: pulumi.Output<string>;
    /**
     * Key-value map of resource tags
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a RuleGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RuleGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RuleGroup resources.
 */
export interface RuleGroupState {
    /**
     * A list of activated rules, see below
     */
    readonly activatedRules?: pulumi.Input<pulumi.Input<inputs.wafregional.RuleGroupActivatedRule>[]>;
    /**
     * The ARN of the WAF Regional Rule Group.
     */
    readonly arn?: pulumi.Input<string>;
    /**
     * A friendly name for the metrics from the rule group
     */
    readonly metricName?: pulumi.Input<string>;
    /**
     * A friendly name of the rule group
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Key-value map of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a RuleGroup resource.
 */
export interface RuleGroupArgs {
    /**
     * A list of activated rules, see below
     */
    readonly activatedRules?: pulumi.Input<pulumi.Input<inputs.wafregional.RuleGroupActivatedRule>[]>;
    /**
     * A friendly name for the metrics from the rule group
     */
    readonly metricName: pulumi.Input<string>;
    /**
     * A friendly name of the rule group
     */
    readonly name?: pulumi.Input<string>;
    /**
     * Key-value map of resource tags
     */
    readonly tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
