import * as pulumi from "@pulumi/pulumi";
import { input as inputs, output as outputs } from "../types";
/**
 * Provides a WAF Regional SQL Injection Match Set Resource for use with Application Load Balancer.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const sqlInjectionMatchSet = new aws.wafregional.SqlInjectionMatchSet("sql_injection_match_set", {
 *     sqlInjectionMatchTuples: [{
 *         fieldToMatch: {
 *             type: "QUERY_STRING",
 *         },
 *         textTransformation: "URL_DECODE",
 *     }],
 * });
 * ```
 *
 * ## Import
 *
 * WAF Regional Sql Injection Match Set can be imported using the id, e.g.
 *
 * ```sh
 *  $ pulumi import aws:wafregional/sqlInjectionMatchSet:SqlInjectionMatchSet sql_injection_match_set a1b2c3d4-d5f6-7777-8888-9999aaaabbbbcccc
 * ```
 */
export declare class SqlInjectionMatchSet extends pulumi.CustomResource {
    /**
     * Get an existing SqlInjectionMatchSet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SqlInjectionMatchSetState, opts?: pulumi.CustomResourceOptions): SqlInjectionMatchSet;
    /**
     * Returns true if the given object is an instance of SqlInjectionMatchSet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SqlInjectionMatchSet;
    /**
     * The name or description of the SizeConstraintSet.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The parts of web requests that you want AWS WAF to inspect for malicious SQL code and, if you want AWS WAF to inspect a header, the name of the header.
     */
    readonly sqlInjectionMatchTuples: pulumi.Output<outputs.wafregional.SqlInjectionMatchSetSqlInjectionMatchTuple[] | undefined>;
    /**
     * Create a SqlInjectionMatchSet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: SqlInjectionMatchSetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SqlInjectionMatchSet resources.
 */
export interface SqlInjectionMatchSetState {
    /**
     * The name or description of the SizeConstraintSet.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The parts of web requests that you want AWS WAF to inspect for malicious SQL code and, if you want AWS WAF to inspect a header, the name of the header.
     */
    readonly sqlInjectionMatchTuples?: pulumi.Input<pulumi.Input<inputs.wafregional.SqlInjectionMatchSetSqlInjectionMatchTuple>[]>;
}
/**
 * The set of arguments for constructing a SqlInjectionMatchSet resource.
 */
export interface SqlInjectionMatchSetArgs {
    /**
     * The name or description of the SizeConstraintSet.
     */
    readonly name?: pulumi.Input<string>;
    /**
     * The parts of web requests that you want AWS WAF to inspect for malicious SQL code and, if you want AWS WAF to inspect a header, the name of the header.
     */
    readonly sqlInjectionMatchTuples?: pulumi.Input<pulumi.Input<inputs.wafregional.SqlInjectionMatchSetSqlInjectionMatchTuple>[]>;
}
