import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves the summary of a WAFv2 IP Set.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.wafv2.getIpSet({
 *     name: "some-ip-set",
 *     scope: "REGIONAL",
 * }, { async: true }));
 * ```
 */
export declare function getIpSet(args: GetIpSetArgs, opts?: pulumi.InvokeOptions): Promise<GetIpSetResult>;
/**
 * A collection of arguments for invoking getIpSet.
 */
export interface GetIpSetArgs {
    /**
     * The name of the WAFv2 IP Set.
     */
    readonly name: string;
    /**
     * Specifies whether this is for an AWS CloudFront distribution or for a regional application. Valid values are `CLOUDFRONT` or `REGIONAL`. To work with CloudFront, you must also specify the region `us-east-1` (N. Virginia) on the AWS provider.
     */
    readonly scope: string;
}
/**
 * A collection of values returned by getIpSet.
 */
export interface GetIpSetResult {
    /**
     * An array of strings that specify one or more IP addresses or blocks of IP addresses in Classless Inter-Domain Routing (CIDR) notation.
     */
    readonly addresses: string[];
    /**
     * The Amazon Resource Name (ARN) of the entity.
     */
    readonly arn: string;
    /**
     * The description of the set that helps with identification.
     */
    readonly description: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The IP address version of the set.
     */
    readonly ipAddressVersion: string;
    readonly name: string;
    readonly scope: string;
}
