import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves the summary of a WAFv2 Web ACL.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.wafv2.getWebAcl({
 *     name: "some-web-acl",
 *     scope: "REGIONAL",
 * }, { async: true }));
 * ```
 */
export declare function getWebAcl(args: GetWebAclArgs, opts?: pulumi.InvokeOptions): Promise<GetWebAclResult>;
/**
 * A collection of arguments for invoking getWebAcl.
 */
export interface GetWebAclArgs {
    /**
     * The name of the WAFv2 Web ACL.
     */
    readonly name: string;
    /**
     * Specifies whether this is for an AWS CloudFront distribution or for a regional application. Valid values are `CLOUDFRONT` or `REGIONAL`. To work with CloudFront, you must also specify the region `us-east-1` (N. Virginia) on the AWS provider.
     */
    readonly scope: string;
}
/**
 * A collection of values returned by getWebAcl.
 */
export interface GetWebAclResult {
    /**
     * The Amazon Resource Name (ARN) of the entity.
     */
    readonly arn: string;
    /**
     * The description of the WebACL that helps with identification.
     */
    readonly description: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly name: string;
    readonly scope: string;
}
