import * as pulumi from "@pulumi/pulumi";
import { output as outputs } from "../types";
/**
 * Retrieve information about an AWS WorkSpaces bundle.
 *
 * ## Example Usage
 * ### By ID
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.workspaces.getBundle({
 *     bundleId: "wsb-b0s22j3d7",
 * }, { async: true }));
 * ```
 * ### By Owner & Name
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 *
 * const example = pulumi.output(aws.workspaces.getBundle({
 *     name: "Value with Windows 10 and Office 2016",
 *     owner: "AMAZON",
 * }, { async: true }));
 * ```
 */
export declare function getBundle(args?: GetBundleArgs, opts?: pulumi.InvokeOptions): Promise<GetBundleResult>;
/**
 * A collection of arguments for invoking getBundle.
 */
export interface GetBundleArgs {
    /**
     * The ID of the bundle.
     */
    readonly bundleId?: string;
    /**
     * The name of the bundle. You cannot combine this parameter with `bundleId`.
     */
    readonly name?: string;
    /**
     * The owner of the bundles. You have to leave it blank for own bundles. You cannot combine this parameter with `bundleId`.
     */
    readonly owner?: string;
}
/**
 * A collection of values returned by getBundle.
 */
export interface GetBundleResult {
    /**
     * The ID of the bundle.
     */
    readonly bundleId?: string;
    /**
     * The compute type. See supported fields below.
     */
    readonly computeTypes: outputs.workspaces.GetBundleComputeType[];
    /**
     * The description of the bundle.
     */
    readonly description: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The name of the compute type.
     */
    readonly name?: string;
    /**
     * The owner of the bundle.
     */
    readonly owner?: string;
    /**
     * The root volume. See supported fields below.
     */
    readonly rootStorages: outputs.workspaces.GetBundleRootStorage[];
    /**
     * The user storage. See supported fields below.
     */
    readonly userStorages: outputs.workspaces.GetBundleUserStorage[];
}
